
#######################################################################################
################################# 1 - Pre-preparation: ################################
#######################################################################################

#* Before you commence any code in all the syntax in this folder, you need to run the#
#* 'pre preparation' code in this section first. This will set the working directory,
#* download the relevant packages, and change some of the R options to enable analysis
#* with large scale survey designs. 

#* To re-create the dataset, you need to run the R syntax files in the following order:
#* [1] '3.1 - Continuous employment'; 
#* [2] '11.a - Capability Set - merging individual and parental NS-SEC data across waves';
#* [3] The rest of the '0 - Data download' syntax below. You need to run the first two
#* first because I later merge these indicators into the data, below;
#* [4] Then run the rest of the syntax from 1.1 - Earnings sufficiency onwards, making
#* sure to save into the survey design RDS each time you create these indicators
#* [5] The files later marked with letters (a-onwards) then create indicators for 
#* Conversion Factors and the Capability Set, put the data together into an index,
#* impute missing data, etc. Again, it's important to save these back into the RDS 
#* as and when this syntax is run, to avoid having to re-run it. 

#* Once the above has been run and all of the indicators, dimensions and index scores
#* have been created, you then just have to run the syntax in this section alone (section 1) 
#* followed by section 11 at the very bottom to commence analysis of the data. Analysis of 
#* specific parts of the wider 'Dat' file (eg the JQ index specifically) can then be carried
#* out just by filtering 'Dat' to the specific group you're interested in.

#* First set the working directory and install the necessary packages (uninstalled packages should show
#* up automatically in R interface). The data citation is below.[1] For the more obscure packages I 
#* state their purpose below: 

setwd("INSERT UKHLS WORKING DIRECTORY HERE")
library(ggthemes)
library(readr)
library(epiDisplay)
library(gmodels)
library(ggplot2) 
library(scales)
library(tidyr) #* Used for converting data from wide to long format, amongst other things
library(survey)
library(imputeTS)
library(ggpmisc)
library(questionr)
library(gridExtra)
library(sjmisc)
library(haven) #* Needed to read DTAs outside of version 5-12
library(editData)
library(labelled)
library(networkD3) #* Produces Sankey diagrams using R;
library(srvyr) #* To create a survey design
library(dplyr) #* For Sankey plots, data manipulation, and for filter()
library(tidyverse)
library(jtools) #* For presenting social scientific data results and extra survey packages, eg SD; 
library(Hmisc) #* For non survey-based correlation packages;
library(weights) #* Needed for p-value calculations for svycor, according to the documentation;
library(car) #* Contains Levene's test;
library(fmsb) #* Needed for radar plots;
library(remotes)
library(rlang)
library(ggiraph)
library(ggiraphExtra)
library(mice) #* Needed for imputation;
library(VIM) #* Creates an aggregate plot of missing data;
library(tab) #* For calculating medians using a complex survey design;
library(misty) #* For Little's Missing Completely at Random test;
library(svyVGAM) #* For the ordered logit models;
library(pollster) #* For summary stats / time series / cross-tabs when using weights (not survey design objects);
library(purrr) #* For binding lists together;
library(plm) #* For fixed effects regression using panel data;
library(ggcorrplot) #* For visualising correlation plots;
library(dendextend) #* Used for checking if all values in a vector are unique, e.g. a vector of personal identifiers (pidp);
library(datawizard) #* For easily replacing NaN and infinity values with NAs;
library(factoextra) #* For PCA, scree plots, e.t.c.#

#* In some versions of R additional options may need to be adjusted to enable proper presentation of summaries and
#* enable survey design-based calculation of means (these are commented out below):
# options(scipen = 999)
# options(survey.adjust.domain.lonely=TRUE)
# options(survey.lonely.psu="adjust")

#* REFERENCES:
#* [1] Data citation: University of Essex, Institute for Social and Economic Research.
#* (2021). Understanding Society:Waves 1-12, 2009-2021 and Harmonised BHPS: 
#* Waves 1-18, 1991-2009. [data collection]. 17th Edition. UK Data Service. 
#* SN: 6614, DOI: http://doi.org/10.5255/UKDA-SN-6614-18

#######################################################################################
########################## 2 - Read survey data into R: ###############################
#######################################################################################

#* Note that by downloading the Stata versions of the data using the haven package, 
#* the data is downloaded as doubles but with data labels so you can see what each
#* of the values represent.[1] The merging processes in the succeeding code still keep
#* these data labels.

#* Further note that rather than downloading the whole data frame, it's very important 
#* to select which specific variables to download into the data frame because of (a) 
#* processor demands and (b) some variables may appear in both the individual and household
#* datasets, so this could create issues when you merge them unless you select which dataset
#* you want them from below.

#* Finally, note that I use the function read_dta from the haven package, rather than the function read.dta 
#* from the foreign package. This is because the latter only reads version 5-12 .dta files.

#* [1] Individual data:

Wave2 <- read_dta('b_indresp.dta') |> #* Note: no bendis12, pbnft13, btype10, btype11, btype12 in Wave 2.
  select(pidp, b_buno_dv, b_hidp, b_psu, b_indinub_xw, b_indscub_xw, b_strata, b_hhorig, #* Sampling info and identifiers;
         b_age_dv, b_pensioner_dv, #* Demographics;
         b_intdatd_dv, b_intdatm_dv, b_intdaty_dv, b_ff_everint, b_jbbgd, b_jbbgm, b_jbbgy, #* Interview / job start dates;
         b_jbstat, b_empchk, b_jbsamr, b_ff_jbstat, b_ff_ivlolw, b_jbhas, b_jboff, b_retchk, b_jbsemp, b_ff_emplw, #* Job status;
         b_fimnlabgrs_dv, b_fimnlabnet_dv, #* [Dimension 1:] Earnings;
         b_jbpen, b_jbpenm, b_ppen, b_ppreg, b_paytyp, b_ovtpay, b_ovtrate, b_extnsa, b_ovtrest, #* [Dimension 2:] Insurance;
         b_jbterm1, b_jbsec, #* [Dimension 3:] Security; 
         b_wkaut1, b_wkaut2, b_wkaut3, b_wkaut4, b_tujbpl, b_tuin1, #* [Dimension 4:] Autonomy and Voice;
         b_jbflex1, b_jbflex2, b_jbflex3, b_jbflex4, b_jbflex5, b_jbflex6, b_jbflex7, b_jbflex8, b_jbflex96, b_wkaut5, 
         b_jbhrs, b_jshrs, b_j2hrs, b_j2has, b_jbot, #* [Dimension 5:] Work-life Balance;
         b_jbxpcha, b_jbrise, b_jbmngr, b_jstypeb, b_jsboss, b_jblkchc, b_jbxpchc, #* [Dimension 6:] Prospects;
         b_jbsic07_cc, b_jbsoc10_cc, b_jbsoc00_cc, #* [Dimension 7:] Health and Safety;
         b_jbsat, b_sclfsato, b_ethn_dv, b_sex_dv, b_ukborn, b_age_dv, b_citzn1, b_gor_dv, b_jbsect,
         b_jbsectpub, b_jbnssec3_dv, b_jbnssec5_dv, b_jbnssec_dv, b_jbiindb_dv, #* Dependent Variables;
         b_fimnpen_dv, #* Capability Set: Employer Pension; 
         b_fimninvnet_dv, #* Capability Set: Investments and Private Pension;
         b_hiqual_dv, b_qfhigh_dv, b_qfhighfl_dv, #* Capability Set: Qualifications (note no qfhighoth in waves 4 & 6);
         b_save, b_savreg, b_saved, b_savlt, #* Capability Set: Savings;
         b_fimnprben_dv, b_fimnsben_dv, #* Capability Set: Social and Private Benefits;
         b_aidhh, b_aidxhh, #* Conversion Factors: Caring Responsibilities;
         b_ndepchl_dv, #* Conversion Factors: Dependent children;
         b_health, b_scsf3a, b_scsf3b, b_scsf4a, b_scsf4b, b_scsf5, #* Conversion Factors: Disability and Health;
         b_sf12mcs_dv, b_sf12pcs_dv, b_disdif1, b_disdif2, b_disdif3, b_disdif4, b_disdif5, b_disdif6, b_disdif7, b_disdif8,
         b_disdif9, b_disdif10, b_disdif11, b_disdif12, b_disdif96, b_single_dv, b_jbft_dv,  #* Conversion Factors: New variables added on [31.08.23];
         b_fimnmisc_dv, #* Capability Set. New variables added on [03.09.23]
         b_jbsize, b_jbsizechk, b_jssize, #* New auxiliary variables added on [13.10.23]
         b_julk4wk, b_julk4x1, b_julk4x2, b_julk4x3, b_julk4x4, b_julk4x5, b_julk4x6, b_julk4x96,
         b_jubgn, b_julkjb, b_nunmpsp_dv, b_j1none, #* Workless dimension 2: Proximity to paid labour;
         b_bendis1, b_bendis2, b_bendis3, b_bendis4, b_bendis5, b_bendis7, b_bendis8, b_bendis10, b_bendis96, #* Workless dimension 3: Disability;
         b_trainany, b_volfreq, b_volun, b_volhrs, # Workless dimension 4: activity/education;
         b_pbnft1, b_pbnft2, b_pbnft3, b_pbnft4, b_pbnft5, b_pbnft6, b_pbnft7, b_pbnft8, b_pbnft9, b_pbnft10, b_pbnft11,
         b_pbnft12, b_pbnft96, #* Private benefit proxy questions;
         b_bendis6, b_bendis9, b_bendis11, #* Disability benefit questions (Waves 1-5 for first 2, 1-2, 4-5 for other two);
         b_btype1, b_btype2, b_btype3, b_btype4, b_btype5, b_btype6, b_btype7, b_btype8, b_btype9, b_btype96, #* Benefit type variables (Waves 1-5);
         b_scghq1_dv, #* General Health Questionnaire (GHQ) Likert scale of responses;
         b_sclfsat1, b_sclfsat2, b_sclfsat7, #* Satisfaction with health, income, leisure time [12.07.24];
         b_nnmpsp_dv, b_nunmpsp_dv, #* Non-employment and unemployment spells since last interview;
         b_ccare, b_ccwork, #* Childcare use at individual level [19.08.24];
         b_aidhrs) #* Hours spent doing unpaid care/week. [20.08.24].

Wave4 <- read_dta('d_indresp.dta') |> #* Note: no ovtnset variable in waves 4 and 6, and no ff_everint after wave 4.
  select(pidp, d_buno_dv, d_hidp, d_psu, d_indinub_xw, d_indscub_xw, d_strata, d_hhorig, #* Sampling info and identifiers;
         d_age_dv, d_pensioner_dv, #* Demographics;
         d_intdatd_dv, d_intdatm_dv, d_intdaty_dv, d_ff_everint, d_jbbgd, d_jbbgm, d_jbbgy, #* Interview / job start dates;
         d_jbstat, d_empchk, d_jbsamr, d_ff_jbstat, d_ff_ivlolw, d_jbhas, d_jboff, d_retchk, d_jbsemp, d_ff_emplw, #* Job status;
         d_fimnlabgrs_dv, d_fimnlabnet_dv, #* [Dimension 1:] Earnings;
         d_jbpen, d_jbpenm, d_ppen, d_ppreg, d_paytyp, d_ovtpay, d_ovtrate, d_extnsa, d_ovtrest, #* [Dimension 2:] Insurance;
         d_jbterm1, d_jbsec, #* [Dimension 3:] Security; 
         d_wkaut1, d_wkaut2, d_wkaut3, d_wkaut4, d_tujbpl, d_tuin1, #* [Dimension 4:] Autonomy and Voice;
         d_jbflex1, d_jbflex2, d_jbflex3, d_jbflex4, d_jbflex5, d_jbflex6, d_jbflex7, d_jbflex8, d_jbflex96, d_wkaut5, 
         d_jbhrs, d_jshrs, d_j2hrs, d_j2has, d_jbot, #* [Dimension 5:] Work-life Balance;
         d_jbxpcha, d_jbrise, d_jbmngr, d_jstypeb, d_jsboss, d_jblkchc, d_jbxpchc, #* [Dimension 6:] Prospects;
         d_jbsic07_cc, d_jbsoc10_cc, d_jbsoc00_cc, #* [Dimension 7:] Health and Safety;
         d_jbsat, d_sclfsato, d_ethn_dv, d_sex_dv, d_ukborn, d_age_dv, d_citzn1, d_gor_dv, d_jbsect,
         d_jbsectpub, d_jbnssec3_dv, d_jbnssec5_dv, d_jbnssec_dv, d_jbiindb_dv, #* Dependent Variables;
         d_fimnpen_dv, #* Capability Set: Employer Pension; 
         d_fimninvnet_dv, #* Capability Set: Investments and Private Pension;
         d_hiqual_dv, d_qfhigh_dv, d_qfhighfl_dv, #* Capability Set: Qualifications (note no qfhighoth in waves 4 & 6);
         d_save, d_savreg, d_saved, d_savlt, #* Capability Set: Savings;
         d_fimnprben_dv, d_fimnsben_dv, #* Capability Set: Social and Private Benefits;
         d_aidhh, d_aidxhh, #* Conversion Factors: Caring Responsibilities;
         d_ndepchl_dv, #* Conversion Factors: Dependent children;
         d_health, d_scsf3a, d_scsf3b, d_scsf4a, d_scsf4b, d_scsf5, #* Conversion Factors: Disability and Health;
         d_sf12mcs_dv, d_sf12pcs_dv, d_disdif1, d_disdif2, d_disdif3, d_disdif4, d_disdif5, d_disdif6, d_disdif7, d_disdif8,
         d_disdif9, d_disdif10, d_disdif11, d_disdif12, d_disdif96, d_single_dv, d_jbft_dv,  #* Conversion Factors: New variables added on [31.08.23];
         d_fimnmisc_dv, #* Capability Set. New variables added on [03.09.23]
         d_jbsize, d_jbsizechk, d_jssize, #* New auxiliary variables added on [13.10.23]
         d_julk4wk, d_julk4x1, d_julk4x2, d_julk4x3, d_julk4x4, d_julk4x5, d_julk4x6, d_julk4x96,
         d_jubgn, d_julkjb, d_nunmpsp_dv, d_j1none, #* Workless dimension 2: Proximity to paid labour;
         d_bendis1, d_bendis2, d_bendis3, d_bendis4, d_bendis5, d_bendis7, d_bendis8, d_bendis10, d_bendis12, d_bendis96, d_bendis97, #* Workless dimension 3: Disability;
         d_trainany, d_volfreq, d_volun, d_volhrs, # Workless dimension 4: activity/education;
         d_pbnft1, d_pbnft2, d_pbnft3, d_pbnft4, d_pbnft5, d_pbnft6, d_pbnft7, d_pbnft8, d_pbnft9, d_pbnft10, d_pbnft11,
         d_pbnft12, d_pbnft13, d_pbnft96, #* Private benefit proxy questions;
         d_bendis6, d_bendis9, d_bendis11, #* Disability benefit questions (Waves 1-5 for first 2, 1-2, 4-5 for other two);
         d_btype1, d_btype2, d_btype3, d_btype4, d_btype5, d_btype6, d_btype7, d_btype8, d_btype9, d_btype96, #* Benefit type variables (Waves 1-5);
         d_btype10, d_btype11, d_btype12, d_btype13, d_btype14, #* Benefit type variables (waves 3-5 for first; waves 3-4 for rest);
         d_scghq1_dv, #* General Health Questionnaire (GHQ) Likert scale of responses;
         d_sclfsat1, d_sclfsat2, d_sclfsat7, #* Satisfaction with health, income, leisure time [12.07.24];
         d_nnmpsp_dv, d_nunmpsp_dv, #* Non-employment and unemployment spells since last interview;
         d_ccare, d_ccwork, #* Childcare use at individual level [19.08.24];
         d_aidhrs) #* Hours spent doing unpaid care/week. [20.08.24].
         
Wave6 <- read_dta('f_indresp.dta') |> 
  select(pidp, f_buno_dv, f_hidp, f_psu, f_indinui_xw, f_indscui_xw, f_strata, f_hhorig, #* Sampling info and identifiers;
         f_age_dv, f_pensioner_dv, #* Demographics;
         f_intdatd_dv, f_intdatm_dv, f_intdaty_dv, f_jbbgd, f_jbbgm, f_jbbgy, #* Interview / job start dates;
         f_jbstat, f_empchk, f_jbsamr, f_ff_jbstat, f_ff_ivlolw, f_jbhas, f_jboff, f_retchk, f_jbsemp, f_ff_emplw, #* Job status;
         f_fimnlabgrs_dv, f_fimnlabnet_dv, #* [Dimension 1:] Earnings;
         f_jbpen, f_jbpenm, f_ppen, f_ppreg, f_paytyp, f_ovtpay, f_ovtrate, f_extnsa, f_ovtrest, #* [Dimension 2:] Insurance;
         f_jbterm1, f_jbsec, #* [Dimension 3:] Security; 
         f_wkaut1, f_wkaut2, f_wkaut3, f_wkaut4, f_tujbpl, f_tuin1, #* [Dimension 4:] Autonomy and Voice;
         f_jbflex1, f_jbflex2, f_jbflex3, f_jbflex4, f_jbflex5, f_jbflex6, f_jbflex7, f_jbflex8, f_jbflex96, f_wkaut5, 
         f_jbhrs, f_jshrs, f_j2hrs, f_j2has, f_jbot, #* [Dimension 5:] Work-life Balance 
         f_jbxpcha, f_jbrise, f_jbmngr, f_jstypeb, f_jsboss, f_jblkchc, f_jbxpchc, #* [Dimension 6:] Prospects;
         f_jbsic07_cc, f_jbsoc10_cc, f_jbsoc00_cc, #* [Dimension 7:] Health and Safety;
         f_jbsat, f_sclfsato, f_ethn_dv, f_sex_dv, f_ukborn, f_age_dv, f_citzn1, f_gor_dv, f_jbsect,
         f_jbsectpub, f_jbnssec3_dv, f_jbnssec5_dv, f_jbnssec_dv, f_jbiindb_dv, f_pensioner_dv, #* Dependent Variables;
         f_fimnpen_dv, #* Capability Set: Employer Pension; 
         f_fimninvnet_dv, #* Capability Set: Investments and Private Pension;
         f_hiqual_dv, f_qfhigh_dv, f_qfhighfl_dv, #* Capability Set: Qualifications (note no qfhighoth in waves 4 & 6);
         f_save, f_savreg, f_saved, f_savlt, #* Capability Set: Savings;
         f_fimnprben_dv, f_fimnsben_dv, #* Capability Set: Social and Private Benefits;
         f_aidhh, f_aidxhh, #* Conversion Factors: Caring Responsibilities;
         f_ndepchl_dv, #* Conversion Factors: Dependent Children;
         f_health, f_scsf3a, f_scsf3b, f_scsf4a, f_scsf4b, f_scsf5, #* Conversion Factors: Disability and Health;
         f_sf12mcs_dv, f_sf12pcs_dv, f_disdif1, f_disdif2, f_disdif3, f_disdif4, f_disdif5, f_disdif6, f_disdif7, f_disdif8,
         f_disdif9, f_disdif10, f_disdif11, f_disdif12, f_disdif96, f_single_dv, f_jbft_dv,  #* Conversion Factors: New variables added on [31.08.23];
         f_fimnmisc_dv, #* Capability Set. New variables added on [03.09.23]
         f_jbsize, f_jbsizechk, f_jssize, #* New auxiliary variables added on [13.10.23]
         f_benbase1, f_benbase2, f_benbase3, f_benbase4, f_benbase96,
         f_julk4wk, f_julk4x1, f_julk4x2, f_julk4x3, f_julk4x4, f_julk4x5, f_julk4x6, f_julk4x96,
         f_jubgn, f_julkjb, f_nunmpsp_dv, f_j1none, #* Workless dimension 2: Proximity to paid labour;
         f_bendis1, f_bendis2, f_bendis3, f_bendis4, f_bendis5, f_bendis7, f_bendis8, f_bendis10, f_bendis12, f_bendis96, f_bendis97, #* Workless dimension 3: Disability;
         f_trainany, f_volfreq, f_volun, f_volhrs, # Workless dimension 4: activity/education;
         f_pbnft1, f_pbnft2, f_pbnft3, f_pbnft4, f_pbnft5, f_pbnft6, f_pbnft7, f_pbnft8, f_pbnft9, f_pbnft10, f_pbnft11,
         f_pbnft12, f_pbnft13, f_pbnft96, #* Private benefit proxy questions;
         f_org, f_orga1, f_orga2, f_orga3, f_orga4, f_orga5, f_orga6, f_orga7,
         f_orga8, f_orga9, f_orga10, f_orga11, f_orga12, f_orga13, f_orga14, f_orga15, f_orga16,
         f_orga96, #* Civil society organisation participation in-person/web interview (Wave 6 and 12 only);
         f_orgat1, f_orgat2, f_orgat3, f_orgat4, f_orgat5, f_orgat6, f_orgat7, f_orgat8, 
         f_orgat9, f_orgat10, f_orgat11, f_orgat12, f_orgat13, f_orgat14, f_orgat15, f_orgat16,
         f_orgat96, #* Civil society organisation participation telephone interview (Wave 6 and 12 only);
         f_scghq1_dv, #* General Health Questionnaire (GHQ) Likert scale of responses;
         f_sclfsat1, f_sclfsat2, f_sclfsat7, #* Satisfaction with health, income, leisure time [12.07.24];
         f_nnmpsp_dv, f_nunmpsp_dv, #* Non-employment and unemployment spells since last interview;
         f_ccare, f_ccwork, #* Childcare use at individual level [19.08.24];
         f_aidhrs) #* Hours spent doing unpaid care/week. [20.08.24].
        
Wave8 <- read_dta('h_indresp.dta') |> #* Note, no extnsa variable from wave 8, but ovtnset available from wave 8.
  select(pidp, h_buno_dv, h_hidp, h_psu, h_indinui_xw, h_indscui_xw, h_strata, h_hhorig, #* Sampling info and identifiers;
         h_age_dv, h_pensioner_dv, #* Demographics;
         h_intdatd_dv, h_intdatm_dv, h_intdaty_dv, h_jbbgd, h_jbbgm, h_jbbgy, #* Interview / job start dates;
         h_jbstat, h_empchk, h_jbsamr, h_ff_jbstat, h_ff_ivlolw, h_jbhas, h_jboff, h_retchk, h_jbsemp, h_ff_emplw, #* Job status;
         h_fimnlabgrs_dv, h_fimnlabnet_dv, #* [Dimension 1:] Earnings;
         h_jbpen, h_jbpenm, h_ppen, h_ppreg, h_paytyp, h_ovtpay, h_ovtrate, h_ovtnset, h_ovtrest, #* [Dimension 2:] Insurance;
         h_jbterm1, h_jbsec, #* [Dimension 3:] Security; 
         h_wkaut1, h_wkaut2, h_wkaut3, h_wkaut4, h_tujbpl, h_tuin1, #* [Dimension 4:] Autonomy and Voice;
         h_jbflex1, h_jbflex2, h_jbflex3, h_jbflex4, h_jbflex5, h_jbflex6, h_jbflex7, h_jbflex8, h_jbflex96, h_wkaut5, 
         h_jbhrs, h_jshrs, h_j2hrs, h_j2has, h_jbot, #* [Dimension 5:] Work-life Balance 
         h_jbxpcha, h_jbrise, h_jbmngr, h_jstypeb, h_jsboss, h_jblkchc, h_jbxpchc, #* [Dimension 6:] Prospects;
         h_jbsat, h_sclfsato, h_ethn_dv, h_sex_dv, h_ukborn, h_age_dv, h_citzn1, h_gor_dv, h_jbsect,
         h_jbsic07_cc, h_jbsoc10_cc, h_jbsoc00_cc, #* [Dimension 7:] Health and Safety;
         h_jbsectpub, h_jbnssec3_dv, h_jbnssec5_dv, h_jbnssec_dv, h_jbiindb_dv, h_pensioner_dv, #* Dependent Variables;
         h_fimnpen_dv, #* Capability Set: Employer Pension; 
         h_fimninvnet_dv, #* Capability Set: Investments and Private Pension;
         h_hiqual_dv, h_qfhigh_dv, h_qfhighfl_dv, #* Capability Set: Qualifications (note no qfhighoth in waves 4 & 6);
         h_save, h_savreg, h_saved, h_savlt, #* Capability Set: Savings;
         h_fimnprben_dv, h_fimnsben_dv, #* Capability Set: Social and Private Benefits;
         h_aidhh, h_aidxhh, #* Conversion Factors: Caring Responsibilities;
         h_ndepchl_dv, #* Conversion Factors: Dependent Children;
         h_health, h_scsf3a, h_scsf3b, h_scsf4a, h_scsf4b, h_scsf5, #* Conversion Factors: Disability and Health;
         h_sf12mcs_dv, h_sf12pcs_dv, h_disdif1, h_disdif2, h_disdif3, h_disdif4, h_disdif5, h_disdif6, h_disdif7, h_disdif8,
         h_disdif9, h_disdif10, h_disdif11, h_disdif12, h_disdif96, 
         h_dissev1, h_dissev2, h_dissev3, h_dissev4, h_dissev5, h_dissev6, h_dissev7, h_dissev8, h_dissev9, h_dissev10,
         h_dissev11, h_dissev12, h_single_dv, h_jbft_dv,  #* Conversion Factors: New variables added on [31.08.23];
         h_fimnmisc_dv, #* Capability Set. New variables added on [03.09.23]
         h_jbsize, h_jbsizechk, h_jssize, #* New auxiliary variables added on [13.10.23]
         h_jbflex9, h_jbfxuse9, #* Gig economy / zero hours, new data [23.09.23]
         h_benbase1, h_benbase2, h_benbase3, h_benbase4, h_benbase96,
         h_julk4wk, h_julk4x1, h_julk4x2, h_julk4x3, h_julk4x4, h_julk4x5, h_julk4x6, h_julk4x96,
         h_jubgn, h_julkjb, h_nunmpsp_dv, h_j1none, #* Workless dimension 2: Proximity to paid labour;
         h_bendis1, h_bendis2, h_bendis3, h_bendis4, h_bendis5, h_bendis7, h_bendis8, h_bendis10, h_bendis12, h_bendis96, h_bendis97, #* Workless dimension 3: Disability;
         h_trainany, h_volfreq, h_volun, h_volhrs, # Workless dimension 4: activity/education;
         h_pbnft1, h_pbnft2, h_pbnft3, h_pbnft4, h_pbnft5, h_pbnft6, h_pbnft7, h_pbnft8, h_pbnft9, h_pbnft10, h_pbnft11,
         h_pbnft12, h_pbnft13, h_pbnft96, #* Private benefit proxy questions;
         h_scghq1_dv, #* General Health Questionnaire (GHQ) Likert scale of responses;
         h_sclfsat1, h_sclfsat2, h_sclfsat7, #* Satisfaction with health, income, leisure time [12.07.24];
         h_nnmpsp_dv, h_nunmpsp_dv, #* Non-employment and unemployment spells since last interview;
         h_ccare, h_ccwork, #* Childcare use at individual level [19.08.24];
         h_aidhrs) #* Hours spent doing unpaid care/week. [20.08.24].

Wave10 <- read_dta('j_indresp.dta') |>
  select(pidp, j_buno_dv, j_hidp, j_psu, j_indinui_xw, j_indscui_xw, j_strata, j_hhorig, #* Sampling info and identifiers;
         j_age_dv, j_pensioner_dv, #* Demographics;
         j_intdatd_dv, j_intdatm_dv, j_intdaty_dv, j_jbbgd, j_jbbgm, j_jbbgy, #* Interview / job start dates;
         j_jbstat, j_empchk, j_jbsamr, j_ff_jbstat, j_ff_ivlolw, j_jbhas, j_jboff, j_retchk, j_jbsemp, j_ff_emplw, #* Job status;
         j_fimnlabgrs_dv, j_fimnlabnet_dv, #* [Dimension 1:] Earnings;
         j_jbpen, j_jbpenm, j_ppen, j_ppreg, j_paytyp, j_ovtpay, j_ovtrate, j_ovtnset, j_ovtrest, #* [Dimension 2:] Insurance;
         j_jbterm1, j_jbsec, #* [Dimension 3:] Security; 
         j_wkaut1, j_wkaut2, j_wkaut3, j_wkaut4, j_tujbpl, j_tuin1, #* [Dimension 4:] Autonomy and Voice;
         j_jbflex1, j_jbflex2, j_jbflex3, j_jbflex4, j_jbflex5, j_jbflex6, j_jbflex7, j_jbflex8, j_jbflex96, j_wkaut5, 
         j_jbhrs, j_jshrs, j_j2hrs, j_j2has, j_jbot, #* [Dimension 6:] Work-life Balance; 
         j_jbxpcha, j_jbrise, j_jbmngr, j_jstypeb, j_jsboss, j_jblkchc, j_jbxpchc, #* [Dimension 6:] Prospects;
         j_jbsic07_cc, j_jbsoc10_cc, j_jbsoc00_cc, #* [Dimension 7:] Health and Safety;
         j_jbsat, j_sclfsato, j_ethn_dv, j_sex_dv, j_ukborn, j_age_dv, j_citzn1, j_gor_dv, j_jbsect,
         j_jbsectpub, j_jbnssec3_dv, j_jbnssec5_dv, j_jbnssec_dv, j_jbiindb_dv, j_pensioner_dv, #* Dependent Variables;
         j_fimnpen_dv, #* Capability Set: Employer Pension; 
         j_fimninvnet_dv, #* Capability Set: Investments and Private Pension;
         j_hiqual_dv, j_qfhigh_dv, j_qfhighfl_dv, #* Capability Set: Qualifications (note no qfhighoth in waves 4 & 6);
         j_save, j_savreg, j_saved, j_savlt, #* Capability Set: Savings;
         j_fimnprben_dv, j_fimnsben_dv, #* Capability Set: Social and Private Benefits;
         j_aidhh, j_aidxhh, #* Conversion Factors: Caring Responsibilities;
         j_ndepchl_dv, #* Conversion Factors: Dependent Children;
         j_health, j_scsf3a, j_scsf3b, j_scsf4a, j_scsf4b, j_scsf5, #* Conversion Factors: Disability and Health;
         j_sf12mcs_dv, j_sf12pcs_dv, j_disdif1, j_disdif2, j_disdif3, j_disdif4, j_disdif5, j_disdif6, j_disdif7, j_disdif8,
         j_disdif9, j_disdif10, j_disdif11, j_disdif12, j_disdif96, 
         j_dissev1, j_dissev2, j_dissev3, j_dissev4, j_dissev5, j_dissev6, j_dissev7, j_dissev8, j_dissev9, j_dissev10,
         j_dissev11, j_dissev12, j_single_dv, j_jbft_dv,  #* Conversion Factors: New variables added on [31.08.23];
         j_fimnmisc_dv, #* Capability Set. New variables added on [03.09.23]
         j_jbsize, j_jbsizechk, j_jssize, #* New auxiliary variables added on [13.10.23]
         j_jbflex9, j_jbfxuse9, #* Gig economy / zero hours, new data [23.09.23]
         j_benbase1, j_benbase2, j_benbase3, j_benbase4, j_benbase96,
         j_julk4wk, j_julk4x1, j_julk4x2, j_julk4x3, j_julk4x4, j_julk4x5, j_julk4x6, j_julk4x96,
         j_jubgn, j_julkjb, j_nunmpsp_dv, j_j1none, #* Workless dimension 2: Proximity to paid labour;
         j_bendis1, j_bendis2, j_bendis3, j_bendis4, j_bendis5, j_bendis7, j_bendis8, j_bendis10, j_bendis12, j_bendis96, j_bendis97, #* Workless dimension 3: Disability;
         j_trainany, j_volfreq, j_volun, j_volhrs, # Workless dimension 4: activity/education;
         j_pbnft1, j_pbnft2, j_pbnft3, j_pbnft4, j_pbnft5, j_pbnft6, j_pbnft7, j_pbnft8, j_pbnft9, j_pbnft10, j_pbnft11,
         j_pbnft12, j_pbnft13, j_pbnft96, #* Private benefit proxy questions;
         j_scghq1_dv, #* General Health Questionnaire (GHQ) Likert scale of responses;
         j_sclfsat1, j_sclfsat2, j_sclfsat7, #* Satisfaction with health, income, leisure time [12.07.24];
         j_nnmpsp_dv, j_nunmpsp_dv, #* Non-employment and unemployment spells since last interview;
         j_ccare, j_ccwork, #* Childcare use at individual level [19.08.24];
         j_aidhrs) #* Hours spent doing unpaid care/week. [20.08.24].

Wave12 <- read_dta('l_indresp.dta') |>
  select(pidp, l_buno_dv, l_hidp, l_psu, l_indinui_xw, l_indscui_xw, l_strata, l_hhorig, #* Sampling info and identifiers;
         l_age_dv, l_pensioner_dv, #* Demographics;
         l_intdatd_dv, l_intdatm_dv, l_intdaty_dv, l_jbbgd, l_jbbgm, l_jbbgy, #* Interview / job start dates;
         l_jbstat, l_empchk, l_jbsamr, l_ff_jbstat, l_ff_ivlolw, l_jbhas, l_jboff, l_jbsemp, l_ff_emplw, #* Job status;
         l_fimnlabgrs_dv, l_fimnlabnet_dv, #* [Dimension 1:] Earnings;
         l_jbpen, l_jbpenm, l_paytyp, l_ovtpay, l_ovtrate, l_ovtnset, l_ovtrest, #* [Dimension 2:] Insurance;
         l_jbterm1, l_jbsec, #* [Dimension 3:] Security; 
         l_wkaut1, l_wkaut2, l_wkaut3, l_wkaut4, l_tujbpl, l_tuin1, #* [Dimension 4:] Autonomy and Voice;
         l_jbflex1, l_jbflex2, l_jbflex3, l_jbflex4, l_jbflex5, l_jbflex6, l_jbflex7, l_jbflex8, l_jbflex96, l_wkaut5, 
         l_jbhrs, l_jshrs, l_j2hrs, l_j2has, l_jbot, #* [Dimension 6:] Work-life Balance; 
         l_jbxpcha, l_jbrise, l_jbmngr, l_jstypeb, l_jsboss, l_jblkchc, l_jbxpchc, #* [Dimension 6:] Prospects;
         l_jbsic07_cc, l_jbsoc10_cc, l_jbsoc00_cc, #* [Dimension 7:] Health and Safety;
         l_jbsat, l_sclfsato, l_ethn_dv, l_sex_dv, l_ukborn, l_age_dv, l_citzn1, l_gor_dv, l_jbsect,
         l_jbsectpub, l_jbnssec3_dv, l_jbnssec5_dv, l_jbnssec_dv, l_jbiindb_dv, l_pensioner_dv, #* Dependent Variables;
         l_fimnpen_dv, #* Capability Set: Employer Pension; 
         l_fimninvnet_dv, #* Capability Set: Investments and Private Pension;
         l_hiqual_dv, l_qfhigh_dv, l_qfhighfl_dv, #* Capability Set: Qualifications (note no qfhighoth in waves 4 & 6);
         l_fimnprben_dv, l_fimnsben_dv, #* Capability Set: Social and Private Benefits;
         l_aidhh, l_aidxhh, #* Conversion Factors: Caring Responsibilities;
         l_ndepchl_dv, #* Conversion Factors: Dependent Children;
         l_health, l_scsf3a, l_scsf3b, l_scsf4a, l_scsf4b, l_scsf5, #* Conversion Factors: Disability and Health;
         l_sf12mcs_dv, l_sf12pcs_dv, l_disdif1, l_disdif2, l_disdif3, l_disdif4, l_disdif5, l_disdif6, l_disdif7, l_disdif8,
         l_disdif9, l_disdif10, l_disdif11, l_disdif12, l_disdif96, 
         l_dissev1, l_dissev2, l_dissev3, l_dissev4, l_dissev5, l_dissev6, l_dissev7, l_dissev8, l_dissev9, l_dissev10,
         l_dissev11, l_dissev12, l_single_dv, l_jbft_dv,  #* Conversion Factors: New variables added on [31.08.23];
         l_fimnmisc_dv, #* Capability Set. New variables added on [03.09.23]
         l_jbsize, l_jbsizechk, l_jssize, #* New auxiliary variables added on [13.10.23]
         l_jbflex9, l_jbfxuse9, l_gehrs, l_gelist1, l_gelist2, 
         l_gelist3, l_gelist4, l_gelist5, l_gelist96, #* Gig economy / zero hours, new data [23.09.23]
         l_benbase1, l_benbase2, l_benbase3, l_benbase4, l_benbase96,
         l_julk4wk, l_julk4x1, l_julk4x2, l_julk4x3, l_julk4x4, l_julk4x5, l_julk4x6, l_julk4x96,
         l_jubgn, l_julkjb, l_nunmpsp_dv, l_j1none, #* Workless dimension 2: Proximity to paid labour;
         l_bendis1, l_bendis2, l_bendis3, l_bendis4, l_bendis5, l_bendis7, l_bendis8, l_bendis10, l_bendis12, l_bendis96, l_bendis97, #* Workless dimension 3: Disability;
         l_trainany, # Workless dimension 4: activity/education;
         l_pbnft1, l_pbnft2, l_pbnft3, l_pbnft4, l_pbnft5, l_pbnft6, l_pbnft7, l_pbnft8, l_pbnft9, l_pbnft10, l_pbnft11,
         l_pbnft12, l_pbnft13, l_pbnft96, #* Private benefit proxy questions;
         l_org, l_orga1, l_orga2, l_orga3, l_orga4, l_orga5, l_orga6, l_orga7,
         l_orga8, l_orga9, l_orga10, l_orga11, l_orga12, l_orga13, l_orga14, l_orga15, l_orga16,
         l_orga96, #* Civil society organisations in-person/web interview (Wave 6 and 12 only);
         l_orgat1, l_orgat2, l_orgat3, l_orgat4, l_orgat5, l_orgat6, l_orgat7, l_orgat8, 
         l_orgat9, l_orgat10, l_orgat11, l_orgat12, l_orgat13, l_orgat14, l_orgat15, l_orgat16,
         l_orgat96, #* Civil society organisation participation telephone interview (Wave 6 and 12 only);
         l_scghq1_dv, #* General Health Questionnaire (GHQ) Likert scale of responses;
         l_sclfsat1, l_sclfsat2, l_sclfsat7, #* Satisfaction with health, income, leisure time [12.07.24];
         l_nnmpsp_dv, l_nunmpsp_dv, #* Non-employment and unemployment spells since last interview;
         l_ccare, l_ccwork, #* Childcare use at individual level [19.08.24];
         l_aidhrs) #* Hours spent doing unpaid care/week. [20.08.24].

#* [2] Household data:
Wave2_H <- read_dta('b_hhresp.dta') |> #* Note: no nkids05 before Wave 4.
  select(b_hidp, b_hhdenub_xw, b_psu, b_strata, #* Sampling info and identifiers;
         b_hsownd, b_hsowndchk, #* Capability Set: Housing Assets;
         b_fihhmnnet1_dv, b_fihhmngrs_dv, b_fihhmnlabgrs_dv, #* Capability Set: Other Household Income;
         b_ieqmoecd_dv, b_nadoecd_dv, b_nchoecd_dv, b_nkids_dv, #* Conversion Factors: Other household members
         b_agechy_dv, #* Conversion Factors: Age of youngest child;
         b_tenure_dv, b_npens_dv, b_nwage_dv, b_ncouple_dv, b_nemp_dv, b_nue_dv,
         b_nonepar_dv, #* Number of lone parents in household [12.07.24]; 
         b_fihhmnlabnet_dv, b_fihhmnsben_dv, b_hhsize, #* New data added as of [10.10.23];
         b_nkids015) #* Number of 0-15 year-old kids in household. [13.07.24]

Wave4_H <- read_dta('d_hhresp.dta') |>
  select(d_hidp, d_hhdenub_xw, d_psu, d_strata, #* Sampling info and identifiers;
         d_hsownd, d_hsowndchk, #* Capability Set: Housing Assets;
         d_fihhmnnet1_dv, d_fihhmngrs_dv, d_fihhmnlabgrs_dv, #* Capability Set: Other Household Income;
         d_ieqmoecd_dv, d_nadoecd_dv, d_nchoecd_dv, d_nkids_dv, d_nkids05, #* Conversion Factors: Other household members
         d_agechy_dv, #* Conversion Factors: Age of youngest child;
         d_tenure_dv, d_npens_dv, d_nwage_dv, d_ncouple_dv, d_nemp_dv, d_nue_dv,
         d_nonepar_dv, #* Number of lone parents in household [12.07.24]; 
         d_fihhmnlabnet_dv, d_fihhmnsben_dv, d_hhsize, #* New data added as of [10.10.23];
         d_nkids015) #* Number of 0-15 year-old kids in household. [13.07.24]

Wave6_H <- read_dta('f_hhresp.dta') |>
  select(f_hidp, d_hhdenui_xw, d_psu, d_strata, #* Sampling info and identifiers;
         f_hsownd, f_hsowndchk, #* Capability Set: Housing Assets;
         f_fihhmnnet1_dv, f_fihhmngrs_dv, f_fihhmnlabgrs_dv, #* Capability Set: Other Household Income;
         f_ieqmoecd_dv, f_nadoecd_dv, f_nchoecd_dv, f_nkids_dv, f_nkids05, #* Conversion Factors: Other household members
         f_agechy_dv, #* Conversion Factors: Age of youngest child;
         f_tenure_dv, f_npens_dv, f_nwage_dv, f_ncouple_dv, f_nemp_dv, f_nue_dv,
         f_nonepar_dv, #* Number of lone parents in household [12.07.24]
         f_fihhmnlabnet_dv, f_fihhmnsben_dv, f_hhsize, #* New data added as of [10.10.23];
         f_nkids015) #* Number of 0-15 year-old kids in household. [13.07.24]

Wave8_H <- read_dta('h_hhresp.dta') |>
  select(h_hidp, h_hhdenui_xw, h_psu, h_strata, #* Sampling info and identifiers;
         h_hsownd, h_hsowndchk, #* Capability Set: Housing Assets;
         h_fihhmnnet1_dv, h_fihhmngrs_dv, h_fihhmnlabgrs_dv, #* Capability Set: Other Household Income;
         h_ieqmoecd_dv, h_nadoecd_dv, h_nchoecd_dv, h_nkids_dv, h_nkids05, #* Conversion Factors: Other household members
         h_agechy_dv, #* Conversion Factors: Age of youngest child;
         h_tenure_dv, h_npens_dv, h_nwage_dv, h_ncouple_dv, h_nemp_dv, h_nue_dv,
         h_nonepar_dv, #* Number of lone parents in household [12.07.24]
         h_fihhmnlabnet_dv, h_fihhmnsben_dv, h_hhsize, #* New data added as of [10.10.23];
         h_nkids015) #* Number of 0-15 year-old kids in household. [13.07.24]

Wave10_H <- read_dta('j_hhresp.dta') |>
  select(j_hidp, j_hhdenui_xw, j_psu, j_strata, #* Sampling info and identifiers;
         j_hsownd, j_hsowndchk, #* Capability Set: Housing Assets;
         j_fihhmnnet1_dv, j_fihhmngrs_dv, j_fihhmnlabgrs_dv, #* Capability Set: Other Household Income;
         j_ieqmoecd_dv, j_nadoecd_dv, j_nchoecd_dv, j_nkids_dv, j_nkids05, #* Conversion Factors: Other household members
         j_agechy_dv, #* Conversion Factors: Age of youngest child;
         j_tenure_dv, j_npens_dv, j_nwage_dv, j_ncouple_dv, j_nemp_dv, j_nue_dv,
         j_nonepar_dv, #* Number of lone parents in household [12.07.24]
         j_fihhmnlabnet_dv, j_fihhmnsben_dv, j_hhsize, #* New data added as of [10.10.23];
         j_nkids015) #* Number of 0-15 year-old kids in household. [13.07.24]

Wave12_H <- read_dta('l_hhresp.dta') |>
  select(l_hidp, l_hhdenui_xw, l_psu, l_strata, #* Sampling info and identifiers;
         l_hsownd, l_hsowndchk, #* Capability Set: Housing Assets;
         l_fihhmnnet1_dv, l_fihhmngrs_dv, l_fihhmnlabgrs_dv, #* Capability Set: Other Household Income;
         l_ieqmoecd_dv, l_nadoecd_dv, l_nchoecd_dv, l_nkids_dv, l_nkids05, #* Conversion Factors: Other household members
         l_agechy_dv, #* Conversion Factors: Age of youngest child;
         l_tenure_dv, l_npens_dv, l_nwage_dv, l_ncouple_dv, l_nemp_dv, l_nue_dv,
         l_nonepar_dv, #* Number of lone parents in household [12.07.24]
         l_fihhmnlabnet_dv, l_fihhmnsben_dv, l_hhsize, #* New data added as of [10.10.23];
         l_nbrcoh_dv, #* Neighbourhood social cohesion (Wave 12 only);
         l_nkids015) #* Number of 0-15 year-old kids in household. [13.07.24]

#* [3] Rename weights:

#* It's easier to do this at this point, rather than match the weight data after
#* the dataframes have all been merged. Note that this function will only 
#* work once on the same dataset: 
Wave4 <- Wave4 |> rename(d_indscubui_xw = d_indscub_xw)
Wave6 <- Wave6 |> rename(f_indscubui_xw = f_indscui_xw)
Wave8 <- Wave8 |> rename(h_indscubui_xw = h_indscui_xw)
Wave10 <- Wave10 |> rename(j_indscubui_xw = j_indscui_xw)
Wave12 <- Wave12 |> rename(l_indscubui_xw = l_indscui_xw)

#* Note that at the moment [19.08.24] I don't actually turn the household data into a survey design per se, so the above household weights are 
#* redundant. I only do this in later papers (e.g. Paper 4) where I then go and re-create a household-level dataset for analysis. 

# Wave4$d_indinubui_xw
# Wave6$f_indinubui_xw
# Wave8$h_indinubui_xw
# Wave10$j_indinubui_xw
# Wave12$l_indinubui_xw

#* REFERENCES:
#* [1] Stackoverflow, 'Exporting labelled double <dbl + lbl> data type,  
#* https://beta.ukdataservice.ac.uk/datacatalogue/studies/study?id=6614

#######################################################################################
###################### 3 - Merge in continuous employment data: #######################
#######################################################################################

#* Download files from the working directory if needed:
Wave4ContinuousEmployment <- read_dta('0 - Wave4ContinuousEmployment.dta')
Wave6ContinuousEmployment <- read_dta('0 - Wave6ContinuousEmployment.dta')
Wave8ContinuousEmployment <- read_dta('0 - Wave8ContinuousEmployment.dta')
Wave10ContinuousEmployment <- read_dta('0 - Wave10ContinuousEmployment.dta')
Wave12ContinuousEmployment <- read_dta('0 - Wave12ContinuousEmployment.dta')

#* Note that *the below code won't work if I use it more than once on the same data set.* It 
#* will have the effect of just duplicating the d_Ind_ContinuousEmployment variable but adding 
#* suffixes at the end of each of them. Future formulas then won't work, as they'll not be
#* able to find a column with that name:
Wave4 <- inner_join(Wave4, Wave4ContinuousEmployment, by = "pidp")
Wave6 <- inner_join(Wave6, Wave6ContinuousEmployment, by = "pidp")
Wave8 <- inner_join(Wave8, Wave8ContinuousEmployment, by = "pidp")
Wave10 <- inner_join(Wave10, Wave10ContinuousEmployment, by = "pidp")
Wave12 <- inner_join(Wave12, Wave12ContinuousEmployment, by = "pidp")

#* Note that full_join isn't the appropriate function to use to merge these datasets. 
#* This function merges all rows which appear in either dataset, and marks any which don't
#* match as N/A. Because the longitudinal data merges two waves this will result in creating 
#* a lot of new N/As in my merged Wave 4 data. To  only merge data which is in both waves, 
#* I need to use inner_join. This will lead to cross-tabs which have a lower number of "missing or
#* inapplicable" values. All the other values will stay exactly the same. The below code demonstrates
#* this (and also tracks for any N/As which are created, of which there are zero). Passes the above
#* test as of [25.02.23]:

# table(Wave4$d_Ind_ContinuousEmployment, exclude=FALSE, deparse.level = 2)
# table(Wave4ContinuousEmployment$d_Ind_ContinuousEmployment, exclude=FALSE, deparse.level = 2)
# table(Wave6$f_Ind_ContinuousEmployment, exclude=FALSE, deparse.level = 2)
# table(Wave6ContinuousEmployment$f_Ind_ContinuousEmployment, exclude=FALSE, deparse.level = 2)
# table(Wave8$h_Ind_ContinuousEmployment, exclude=FALSE, deparse.level = 2)
# table(Wave8ContinuousEmployment$h_Ind_ContinuousEmployment, exclude=FALSE, deparse.level = 2)
# table(Wave10$j_Ind_ContinuousEmployment, exclude=FALSE, deparse.level = 2)
# table(Wave10ContinuousEmployment$j_Ind_ContinuousEmployment, exclude=FALSE, deparse.level = 2)
# table(Wave12$l_Ind_ContinuousEmployment, exclude=FALSE, deparse.level = 2)
# table(Wave12ContinuousEmployment$l_Ind_ContinuousEmployment, exclude=FALSE, deparse.level = 2)

#* The below code shows [17.07.23] that the exact correct values have been ported over from the merging
#* process: 
# xtabs(~Wave4$d_Ind_ContinuousEmployment + Wave4$d_QoW_Index_Member)
# xtabs(~Wave6$f_Ind_ContinuousEmployment + Wave6$f_QoW_Index_Member)
# xtabs(~Wave8$h_Ind_ContinuousEmployment + Wave8$h_QoW_Index_Member)
# xtabs(~Wave10$j_Ind_ContinuousEmployment + Wave10$j_QoW_Index_Member)
# xtabs(~Wave12$l_Ind_ContinuousEmployment + Wave12$l_QoW_Index_Member)

#######################################################################################
#################### 4 - Create filters for populations of interest: ##################
#######################################################################################

#* I create filters for the individual data since this then enables me to later create
#* data labels based on these filters, before then re-merging the data in step 3. I don't
#* need to create filters for the household-level data.

#* For the Workless index, a choice needs to be made about whether to exclude the retired 
#* and/or students from the index. Once one has filtered out jbhas[1] and jboff,[2] the index is
#* already mutually exclusive from the QoW index. But it can be further distinguished by using
#* variables for those who describe retirement (jbstat = 4) or being a student (jbstat = 8)[3] 
#* as their current work situation. Up to Wave 12, a further prompt was asked for those aged 
#* 71 but not classed as retired to double-check whether they are actually retured (retchk)[4]. 
#* This latter variable was discontinued from Wave 12, presumably because so few respondents 
#* were filtered out this way.  

#* The choice one makes re. the above depends on the research interest. For my index, I include
#* the retired and students. I then differentiate them later on through dimensions in the index: 
#* making use of jbstat at that point rather than before. The code at the bottom of the next subsection
#* demonstrates that despite not using jbstat, my workless index is still mutually exclusive from the
#* QoW index. It further demonstrates that virtually all respondents in Understanding Society are either
#* in the QoW index or the Workless index.

#* Finally, note that when creating the workless index, it's important not to exclude those who are inapplicable
#* in the question on whether they did no paid work last week (jboff = -8). This would exclude those who said they
#* had no paid job (jbhas = 2). The syntax below adopts a negative exclusion criteria: including everyone who is 
#* *not* away from a paid job (= 1), don't know (-1) or refusing to answer (-2) in jboff. Note that this means people
#* waiting to take up a paid job (jboff = 3), but not currently in paid work, are included in the Workless index. Again,
#* as with the retired and students, this will be used to differentiate them at a later date.

#* [1] Quality of Work (QoW) index:
Wave4JQ <- filter(Wave4, (d_jbhas == 1 | d_jboff == 1))
Wave6JQ <- filter(Wave6, (f_jbhas == 1 | f_jboff == 1))
Wave8JQ <- filter(Wave8, (h_jbhas == 1 | h_jboff == 1))
Wave10JQ <- filter(Wave10, (j_jbhas == 1 | j_jboff == 1))
Wave12JQ <- filter(Wave12, (l_jbhas == 1 | l_jboff == 1))

#* [2] Workless index:
Wave4LW  <- filter(Wave4, (d_jbhas == 2 &! (d_jboff == -2 | d_jboff == -1 | d_jboff == 1)))
Wave6LW  <- filter(Wave6, (f_jbhas == 2 &! (f_jboff == -2 | f_jboff == -1 | f_jboff == 1)))
Wave8LW  <- filter(Wave8, (h_jbhas == 2 &! (h_jboff == -2 | h_jboff == -1 | h_jboff == 1)))
Wave10LW  <- filter(Wave10, (j_jbhas == 2 &! (j_jboff == -2 | j_jboff == -1 | j_jboff == 1)))
Wave12LW  <- filter(Wave12, (l_jbhas == 2 &! (l_jboff == -2 | l_jboff == -1 | l_jboff == 1)))

#* REFERENCES:
#* [1] Understanding Society, 'jbhas: did paid work last week', 
#* https://www.understandingsociety.ac.uk/documentation/mainstage/dataset-documentation/variable/jbhas
#* [2] Understanding Society, 'jboff: no work last week but has paid job', 
#* https://www.understandingsociety.ac.uk/documentation/mainstage/dataset-documentation/variable/jboff
#* [3] Understanding Society, 'jbstat: current labour force status', 
#* https://www.understandingsociety.ac.uk/documentation/mainstage/dataset-documentation/variable/jbstat
#* [4] Understanding Society, 'retchk: retired check', 
#* https://www.understandingsociety.ac.uk/documentation/mainstage/dataset-documentation/variable/retchk

#######################################################################################
###################### 5 - Merge to a single data frame: ##############################
#######################################################################################

#* First I create some new columns for my individual-level data, to specify what index
#* they're in, what wave they're from and what year they belong to. This is so I don't
#* lose this info once I download the data. Then I create two new variables to identify
#* where each variable comes from: indresp or hhresp.

#* [1] Add some data labels:

#* ------ Job quality:
Wave4JQ$index = "Quality of Work"
Wave4JQ$wave = "4"
Wave4JQ$year = "2012-13"

Wave6JQ$index = "Quality of Work"
Wave6JQ$wave = "6"
Wave6JQ$year = "2014-15"

Wave8JQ$index = "Quality of Work"
Wave8JQ$wave = "8"
Wave8JQ$year = "2016-17"

Wave10JQ$index = "Quality of Work"
Wave10JQ$wave = "10"
Wave10JQ$year = "2018-19"

Wave12JQ$index = "Quality of Work"
Wave12JQ$wave = "12"
Wave12JQ$year = "2020-21"

#* ------ Workless:
Wave4LW$index = "Workless"
Wave4LW$wave = "4"
Wave4LW$year = "2012-13"

Wave6LW$index = "Workless"
Wave6LW$wave = "6"
Wave6LW$year = "2014-15"

Wave8LW$index = "Workless"
Wave8LW$wave = "8"
Wave8LW$year = "2016-17"

Wave10LW$index = "Workless"
Wave10LW$wave = "10"
Wave10LW$year = "2018-19"

Wave12LW$index = "Workless"
Wave12LW$wave = "12"
Wave12LW$year = "2020-21"

#* [2] Create household vs. individual data identifier:

#* At this stage I also bind the LQ and JQ indices back together to each other, as I've
#* already done all that's necessary on the unmerged data. Note that *from this point onwards*,
#* *the variable sums won't add up to those on the UKHLS website.* This is because they are filtered
#* down specifically to those who are in either the JQ or the LW indices. 
Wave4_I <- bind_rows(Wave4JQ, Wave4LW)
Wave6_I <- bind_rows(Wave6JQ, Wave6LW)
Wave8_I <- bind_rows(Wave8JQ, Wave8LW)
Wave10_I <- bind_rows(Wave10JQ, Wave10LW)
Wave12_I <- bind_rows(Wave12JQ, Wave12LW)

Wave4_H$from_hh <- 1
Wave6_H$from_hh <- 1
Wave8_H$from_hh <- 1
Wave10_H$from_hh <- 1
Wave12_H$from_hh <- 1

Wave4_I$from_ind <- 1
Wave6_I$from_ind <- 1 
Wave8_I$from_ind <- 1
Wave10_I$from_ind <- 1
Wave12_I$from_ind <- 1

#* [3] Make the variable names consistent:

#* There is a function called gsub in the base R package which can remove the
#* prefixes b_, d_, etc from all the variables.

#* Note that once I merge the data, there is no identifier in R which tells you
#* whether the variable itself is individual-Level or household-level (the code immediately
#* above is only to get rid of people without matching individual/household data at stage
#* 5 below). I could get around this by substituting d_ for in_ and hh_ but this would 
#* unnecessarily lengthen all the future syntax - and the source of the data is available
#* online anyway. 

#* Note that any variables which don't already start with the b_, d_ etc prefix won't have
#* this attribute: 

#* ------ Individual:
names(Wave4_I) <- sub('d_', '', names(Wave4_I))
names(Wave6_I) <- sub('f_', '', names(Wave6_I))
names(Wave8_I) <- sub('h_', '', names(Wave8_I))
names(Wave10_I) <- sub('j_', '', names(Wave10_I))
names(Wave12_I) <- sub('l_', '', names(Wave12_I))

#* ------ Household:
names(Wave4_H) <- sub('d_', '', names(Wave4_H))
names(Wave6_H) <- sub('f_', '', names(Wave6_H))
names(Wave8_H) <- sub('h_', '', names(Wave8_H))
names(Wave10_H) <- sub('j_', '', names(Wave10_H))
names(Wave12_H) <- sub('l_', '', names(Wave12_H))

#* [4] Combine the data frames:

#* Now I merge the individual and household datasets:
Wave4_IH <- full_join(Wave4_I, Wave4_H, by = "hidp")
Wave6_IH <- full_join(Wave6_I, Wave6_H, by = "hidp")
Wave8_IH <- full_join(Wave8_I, Wave8_H, by = "hidp")
Wave10_IH <- full_join(Wave10_I, Wave10_H, by = "hidp")
Wave12_IH <- full_join(Wave12_I, Wave12_H, by = "hidp")

#* [5] Filter to only individuals with matched household data for each given year:

#* I now need to exclude any individual who doesn't have matched household data 
#* from my dataset:
Wave4_IH_F <- filter(Wave4_IH, from_hh==1 & from_ind==1)
Wave6_IH_F <- filter(Wave6_IH, from_hh==1 & from_ind==1)
Wave8_IH_F <- filter(Wave8_IH, from_hh==1 & from_ind==1)
Wave10_IH_F <- filter(Wave10_IH, from_hh==1 & from_ind==1)
Wave12_IH_F <- filter(Wave12_IH, from_hh==1 & from_ind==1)

#* Note that we lose a few hundred respondents in waves 6, 8 and 10 as a result of this. 
#* We lose 0 respondents in wave 4 (we only lose households with no matching individual data,
#* which isn't a problem for us). The below code shows how much I lose in each wave:
# table(Wave4_IH$from_hh, Wave4_IH$from_ind, exclude=FALSE, deparse.level = 2)
# table(Wave6_IH$from_hh, Wave6_IH$from_ind, exclude=FALSE, deparse.level = 2)
# table(Wave8_IH$from_hh, Wave8_IH$from_ind, exclude=FALSE, deparse.level = 2)
# table(Wave10_IH$from_hh, Wave10_IH$from_ind, exclude=FALSE, deparse.level = 2)
# table(Wave12_IH$from_hh, Wave12_IH$from_ind, exclude=FALSE, deparse.level = 2)

#* [6] Merge all data:

#* Note that were I to merge the full data across both the household and individual datasets,
#* the bind_rows process will take an extremely long time. 
Data <- bind_rows(Wave4_IH_F, Wave6_IH_F, Wave8_IH_F, Wave10_IH_F, Wave12_IH_F)

#* Note that the bind_rows function returns 21 conflicts because the names of the variables 
#* aren't consistent across all waves. This doesn't create any issues with the summed up data.
#* However, in waves 6, 8 and 10, there is a conflict between the filtered and unfiltered _IH
#* data. This is because in these waves, as noted earlier, a small number (a few hundred) of
#* people with individual data don't have matching household data. The below code checks against 
#* all these and shows the (very small) mismatch. As you can see, there is no mismatch for wave 
#* 4, consistent with the code above showing matching data for wave 4 [26.09.23]: 
# xtabs(~ jboff + year, data = Data)
# xtabs(~ jboff + year, data = Wave4_I)
# xtabs(~ jboff + year, data = Wave4_IH)
# xtabs(~ jboff + year, data = Wave4_IH_F)
# xtabs(~ jboff + year, data = Wave6_I)
# xtabs(~ jboff + year, data = Wave6_IH)
# xtabs(~ jboff + year, data = Wave6_IH_F)
# xtabs(~ jboff + year, data = Wave8_I)
# xtabs(~ jboff + year, data = Wave8_IH)
# xtabs(~ jboff + year, data = Wave8_IH_F)
# xtabs(~ jboff + year, data = Wave10_I)
# xtabs(~ jboff + year, data = Wave10_IH)
# xtabs(~ jboff + year, data = Wave10_IH_F)
# xtabs(~ jboff + year, data = Wave12_I)
# xtabs(~ jboff + year, data = Wave12_IH)
# xtabs(~ jboff + year, data = Wave12_IH_F)

#######################################################################################
####################### 6 - Merge in parental NS-SEC data: ############################
#######################################################################################

#* Separate out by wave (optional):
# Wave4 <- filter(Dat$variables, year == "2012-13")
# Wave6 <- filter(Dat$variables, year == "2014-15")
# Wave8 <- filter(Dat$variables, year == "2016-17")
# Wave10 <- filter(Dat$variables, year == "2018-19")
# Wave12 <- filter(Dat$variables, year == "2020-21")

#* Download data:
# AllWavesNSSEC <- read_dta('0 - All Waves - NSSEC.dta')

#* Similar process as with continuous employment to merge it:
# Wave4 <- inner_join(Wave4, AllWavesNSSEC, by = "pidp")
# Wave6 <- inner_join(Wave6, AllWavesNSSEC, by = "pidp")
# Wave8 <- inner_join(Wave8, AllWavesNSSEC, by = "pidp")
# Wave10 <- inner_join(Wave10, AllWavesNSSEC, by = "pidp")
# Wave12 <- inner_join(Wave12, AllWavesNSSEC, by = "pidp")

#* Filter out respondents who don't respond to either individual or household survey (optional):
# Wave4_IH_F <- filter(Wave4, from_hh==1 & from_ind==1)
# Wave6_IH_F <- filter(Wave6, from_hh==1 & from_ind==1)
# Wave8_IH_F <- filter(Wave8, from_hh==1 & from_ind==1)
# Wave10_IH_F <- filter(Wave10, from_hh==1 & from_ind==1)
# Wave12_IH_F <- filter(Wave12, from_hh==1 & from_ind==1)

#* Merge into the dataset:
# Dat$variables <- bind_rows(Wave4_IH_F, Wave6_IH_F, Wave8_IH_F, Wave10_IH_F, Wave12_IH_F)

#######################################################################################
############################### 7 - Export the data: ##################################
#######################################################################################

#* This is to prevent me having to spend the time to go through all these steps
#* every time:
# write_dta(Data, file.path(getwd(), "0 - Data.dta"))

#######################################################################################
############################## 8 - Apply weights: #####################################
#######################################################################################

#* ------------- Remove existing survey design [optional]:

#* Optional. This will overwrite any existing survey design if you want to change
#* to a different weight later on:
# Data <- Dat$variables

#* ------------- Confirm Weight:

#* UKHLS have confirmed only one weight is needed for my analysis, but with rebasing for
#* any pooled data (in practice I don't carry out analysis using pooled data, however):[1]

#* [a] l_ -- I'm analysing up to wave 12 (l_), but because I'm using the cross-sectional 
#*     weights for each year I can remove this prefix (see further detail below). I'll
#*     be analysing from wave 12, but this won't change the prefix;
#* [b] [ind] -- I'm analysing individual-level data (aged 16+), from the indresp data set;
#* [c] ind[sc] -- The lowest level of analysis is the self-completion questionnaire due to the use
#* of some health self-completion questions in the Conversion Factors dataset;
#* [d] indsc[ub_/ui] -- Analysis is for wave 4-onwards, so I use UB_ (covering any start point between 
#* waves 2 and waves 5). But after Wave 6, as per UKHLS forum advice[2], I switch to ui_;
#* [e] indscub_[xw] -- Although I'm analysing more than one wave, I'm doing a cross-sectional 
#* time series analysis - so I need the cross-sectional (_xw) variable. 

#* Understanding Society documentation advises to use the cross-sectional weight for 
#* weighted cross-sectional time series analysis. To do this, the harmonised user 
#* guide states that "the key take-home point is that the variable names for the 
#* respective studies' cross  sectional population weights for the UK need to be aligned."[1] 
#* When read alongside the forum guidance[2], this means two things:
#* [a] You have to delete the prefix for each cross-sectional weight. I already 
#* did this during stage 3.3 above, when I aligned the names of all the variables; 
#* [b] You have to align the name of the appropriate cross-sectional weight - as the forum guidance
#* says, "After wave 6 it will be ui instead of ub." I also did this above. 

#* The below code shows that indscubui_xw exists in all waves, with no N/As:
Data$indscubui_xw_NAs <- na_replace(Data$indscubui_xw, -1)
Data$indscubui_xw_factor <- case_when(Data$indscubui_xw_NAs == 0 ~ "Zero",
                                      Data$indscubui_xw_NAs < 0 ~ "Below Zero",
                                      Data$indscubui_xw_NAs > 0 ~ "Above Zero")
xtabs(~indscubui_xw_factor + year, data=Data)


#* ------------- Create survey design:

#* I can therefore use the following R syntax to apply the weights. In addition to specifying
#* the weight (indinub_xw), I need to specify the strata (strata)[2] and id (primary sampling unit
#* , or psu)[3]:
Weighted_Data <- svydesign(id      = ~ psu,
                           strata  = ~ strata,
                           weights = ~ indscubui_xw,
                           nest    = TRUE,
                           data    = Data)

#* REFERENCES:
#* [1] Understanding Society, 'Weighting and Sample Representation: Frequently Asked Questions', 
#* https://www.understandingsociety.ac.uk/sites/default/files/downloads/documentation/user-guides/mainstage/weighting_faqs.pdf
#* [2] Understanding Society User Support Forum, Support #1868: Use of weights for analysing job quality in UKHLS, 
#* Waves 4, 6, 8 and 10, https://iserredex.essex.ac.uk/support/issues/1868#change-7667
#* [3] Harmonised BHPS user guide, p. 25, 
#* https://www.understandingsociety.ac.uk/sites/default/files/downloads/documentation/mainstage/user-guides/bhps-harmonised-user-guide.pdf
#* [4] Understanding Society Strata variable, 
#* https://www.understandingsociety.ac.uk/documentation/mainstage/dataset-documentation/variable/strata
#* [5] Understanding Society Primary Sampling Unit variable, 
#* https://www.understandingsociety.ac.uk/documentation/mainstage/dataset-documentation/variable/psu

#######################################################################################
#################### 9 - Turn data into a full survey design: #########################
#######################################################################################

#* Using the srvyr package, I need to turn my large survey design into a survey design
#* that will work with tidyverse packages too:[1]  
Dat <- as_survey_design(Weighted_Data)

#* Finally we'll remove all remaining data frames and clear the R memory again.

#* The code gc() at the end also frees up memory used up during the session (will be needed for
#* when there are a very large number of variables in the dataset):

rm(Wave4, Wave6, Wave8, Wave10, Wave12)
rm(Wave4ContinuousEmployment, Wave6ContinuousEmployment, Wave8ContinuousEmployment, Wave10ContinuousEmployment, Wave12ContinuousEmployment)
rm(Wave4JQ, Wave6JQ, Wave8JQ, Wave10JQ, Wave12JQ)
rm(Wave4LW, Wave6LW, Wave8LW, Wave10LW, Wave12LW)
rm(Wave4_I, Wave6_I, Wave8_I, Wave10_I, Wave12_I)
rm(Wave4_H, Wave6_H, Wave8_H, Wave10_H, Wave12_H)
rm(Wave4_IH, Wave6_IH, Wave8_IH, Wave10_IH, Wave12_IH)
rm(Wave4_IH_F, Wave6_IH_F, Wave8_IH_F, Wave10_IH_F, Wave12_IH_F)
rm(Data, Weighted_Data)
gc()

#* REFERENCES:
#* [1] R for Political Science, 'Add weights to survey data with survey package
#* in R: Part 2',
#* https://rforpoliticalscience.com/2021/01/15/add-weights-to-survey-data-with-survey-package-in-r-part-2/

#######################################################################################
################## 10 - Merge new data into the survey (Optional): ####################
#######################################################################################

#* In cases where you want to add additional data other than what I've specified at the beginning, it is usually easier
#* to do this in the below section - adding the relevant data below - rather than re-doing the entire data download. For
#* now the below are commented out:

#* -------------- [a - Individual data:]

# #* [1] Download data:
# Wave4 <- read_dta('d_indresp.dta') |> 
#   select(pidp, d_aidhrs) 
# Wave6 <- read_dta('f_indresp.dta') |> 
#   select(pidp, f_aidhrs) 
# Wave8 <- read_dta('h_indresp.dta') |> 
#   select(pidp, h_aidhrs)
# Wave10 <- read_dta('j_indresp.dta') |> 
#   select(pidp, j_aidhrs)
# Wave12 <- read_dta('l_indresp.dta') |> 
#   select(pidp, l_aidhrs)
# 
# #* [2] Remove prefixes from the data:
# names(Wave4) <- sub('d_', '', names(Wave4))
# names(Wave6) <- sub('f_', '', names(Wave6))
# names(Wave8) <- sub('h_', '', names(Wave8))
# names(Wave10) <- sub('j_', '', names(Wave10))
# names(Wave12) <- sub('l_', '', names(Wave12))
# 
# #* [3] Rename weights (optional; only do when you're adding a weight):
# # Wave4 <- Wave4 |> rename(indscubui_xw = indscub_xw)
# # Wave6 <- Wave6 |> rename(indscubui_xw = indscui_xw)
# # Wave8 <- Wave8 |> rename(indscubui_xw = indscui_xw)
# # Wave10 <- Wave10 |> rename(indscubui_xw = indscui_xw)
# # Wave12 <- Wave12 |> rename(indscubui_xw = indscui_xw)
# 
# #* [4] Separate out by year:
# Dat_W4 <- filter(Dat$variables, year == "2012-13")
# Dat_W6 <- filter(Dat$variables, year == "2014-15")
# Dat_W8 <- filter(Dat$variables, year == "2016-17")
# Dat_W10 <- filter(Dat$variables, year == "2018-19")
# Dat_W12 <- filter(Dat$variables, year == "2020-21")
# gc() 
# 
# #* [5] Merge both dataframes together by pidp:
# Dat_W4_I <- full_join(Dat_W4, Wave4, by = "pidp")
# Dat_W6_I <- full_join(Dat_W6, Wave6, by = "pidp")
# Dat_W8_I <- full_join(Dat_W8, Wave8, by = "pidp")
# Dat_W10_I <- full_join(Dat_W10, Wave10, by = "pidp")
# Dat_W12_I <- full_join(Dat_W12, Wave12, by = "pidp")
# rm(Dat_W4, Dat_W6, Dat_W8, Dat_W10, Dat_W12)
# rm(Wave4, Wave6, Wave8, Wave10, Wave12)
# gc()
# 
# #* Filter out respondents who don't respond to either individual or household survey:
# Wave4_IH_F <- filter(Dat_W4_I, from_hh==1 & from_ind==1)
# Wave6_IH_F <- filter(Dat_W6_I, from_hh==1 & from_ind==1)
# Wave8_IH_F <- filter(Dat_W8_I, from_hh==1 & from_ind==1)
# Wave10_IH_F <- filter(Dat_W10_I, from_hh==1 & from_ind==1)
# Wave12_IH_F <- filter(Dat_W12_I, from_hh==1 & from_ind==1)
# rm(Dat_W4_I, Dat_W6_I, Dat_W8_I, Dat_W10_I, Dat_W12_I)
# gc()
# 
# #* [6] Merge into the dataset:
# #* Occasionally, depending on the variable, this may return the error 'have conflicting 
# #* value labels.' This is usually nothing to worry about; it just means that the labels 
# #* used for the data (ie not the data itself) conflicts between different waves. This can 
# #* happen when the variable is the same but some of the value labels were slightly tweaked
# #* by Understanding Society:
# Dat$variables <- bind_rows(Wave4_IH_F, Wave6_IH_F, Wave8_IH_F, Wave10_IH_F, Wave12_IH_F)
# rm(Wave4_IH_F, Wave6_IH_F, Wave8_IH_F, Wave10_IH_F, Wave12_IH_F)
# gc()
# 
# #* Test [10.04.24] for identical data. Returns true when you order it by that data. 
# #* Shows exact same time series for both individual indicators and household data:
# Test <- bind_rows(Wave4_IH_F, Wave6_IH_F, Wave8_IH_F, Wave10_IH_F, Wave12_IH_F)
# 
# Test2 <- Dat$variables
# Test1 <- Test[order(Test$indscubui_xw),]
# Test2 <- Test2[order(Test2$indscubui_xw),]
# identical(Test1$indscubui_xw, Test2$indscubui_xw)
# 
# xtabs(~scsf3a + year, data = Test)
# xtabs(~scsf3a + year, data = Dat)
# xtabs(~scsf3b + year, data = Test)
# xtabs(~scsf3b + year, data = Dat)
# xtabs(~scsf4a + year, data = Test)
# xtabs(~scsf4a + year, data = Dat)
# xtabs(~scsf4b + year, data = Test)
# xtabs(~scsf4b + year, data = Dat)
# 
# svytable(~Ind_EarningsSufficiency + year, Dat) |> prop.table(2)
# 
# xtabs(~Ind_Pension_Imp + year, data = Test)
# xtabs(~Ind_Pension_Imp + year, data = Dat)
# svytable(~Ind_Pension_Imp + year, Dat)
# 
# xtabs(~ccwork + year, Dat)
# xtabs(~ccare + year, Dat)
# 
# xtabs(~ccwork + nkids05, Dat)
# xtabs(~ccare + nkids05, Dat)
# 
# xtabs(~Ind_Pension_NAs + year, data = Dat)
# xtabs(~Ind_Pension_Imp + year, data = Test2)
# xtabs(~ieqmoecd_dv + year, data = Dat)
# 
# xtabs(~scghq1_dv + year, Dat)
# xtabs(~orga1 + year, Dat)
# xtabs(~scghq1_dv + year, Dat)
# 
# xtabs(~sclfsat1 + year, Dat)
# xtabs(~sclfsat2 + year, Dat)
# xtabs(~sclfsat7 + year, Dat)
# 
# #* [6] Save the updated data:
# 
# #* Saved the above as of [20.08.24]:
# # saveRDS(Dat, file = "0 - Dat.RData")

#* -------------- [b - Household Data:]

#* When I downloaded the data into R at the beginning of this R file, rather than downloading 
#* the entire dataset I deliberately selected the specific variables I wanted downloading.
#* This was to save on processing demands: the whole dataset causes a massive drain on even
#* computers with a large amount of memory. 

#* From time to time, there is a need to add data ex post facto. Sadly, because of the way I've
#* written the code, adding this in can be quite a complicated process. In order to do this without
#* having to re-do all of the above code, add in indicators, do imputation, etc, I have created
#* the below code. This works for adding new household data; the process for adding individual-level
#* data is in the next section.

# #* [1] Download new data which needs merging:
# Wave4_H <- read_dta('d_hhresp.dta') |>
#   select(d_hidp, d_nkids015)
# Wave6_H <- read_dta('f_hhresp.dta') |>
#   select(f_hidp, f_nkids015)
# Wave8_H <- read_dta('h_hhresp.dta') |>
#   select(h_hidp, h_nkids015)
# Wave10_H <- read_dta('j_hhresp.dta') |>
#   select(j_hidp, j_nkids015)
# Wave12_H <- read_dta('l_hhresp.dta') |>
#   select(l_hidp, l_nkids015)
# 
# #* [2] Remove prefixes from the household data:
# names(Wave4_H) <- sub('d_', '', names(Wave4_H))
# names(Wave6_H) <- sub('f_', '', names(Wave6_H))
# names(Wave8_H) <- sub('h_', '', names(Wave8_H))
# names(Wave10_H) <- sub('j_', '', names(Wave10_H))
# names(Wave12_H) <- sub('l_', '', names(Wave12_H))
# 
# #* [3] Temporarily separate out Dat by year:
# Dat_W4 <- filter(Dat$variables, year == "2012-13")
# Dat_W6 <- filter(Dat$variables, year == "2014-15")
# Dat_W8 <- filter(Dat$variables, year == "2016-17")
# Dat_W10 <- filter(Dat$variables, year == "2018-19")
# Dat_W12 <- filter(Dat$variables, year == "2020-21")
# 
# #* [4] Merge both dataframes together by hidp:
# Dat_W4_IH <- full_join(Dat_W4, Wave4_H, by = "hidp")
# Dat_W6_IH <- full_join(Dat_W6, Wave6_H, by = "hidp")
# Dat_W8_IH <- full_join(Dat_W8, Wave8_H, by = "hidp")
# Dat_W10_IH <- full_join(Dat_W10, Wave10_H, by = "hidp")
# Dat_W12_IH <- full_join(Dat_W12, Wave12_H, by = "hidp")
# rm(Wave4_H, Wave6_H, Wave8_H, Wave10_H, Wave12_H)
# rm(Dat_W4, Dat_W6, Dat_W8, Dat_W10, Dat_W12)
# gc()
# 
# #* Filter out respondents who don't respond to either individual or household survey:
# Wave4_IH_F <- filter(Dat_W4_IH, from_hh==1 & from_ind==1)
# Wave6_IH_F <- filter(Dat_W6_IH, from_hh==1 & from_ind==1)
# Wave8_IH_F <- filter(Dat_W8_IH, from_hh==1 & from_ind==1)
# Wave10_IH_F <- filter(Dat_W10_IH, from_hh==1 & from_ind==1)
# Wave12_IH_F <- filter(Dat_W12_IH, from_hh==1 & from_ind==1)
# rm(Dat_W4_IH, Dat_W6_IH, Dat_W8_IH, Dat_W10_IH, Dat_W12_IH)
# gc()
# 
# #* [5] Merge into the dataset:
# Dat$variables <- bind_rows(Wave4_IH_F, Wave6_IH_F, Wave8_IH_F, Wave10_IH_F, Wave12_IH_F)
# 
# #* Test [12.07.24] for identical data. Returns true when you order it by that data. 
# #* Shows exact same time series for both individual indicators and household data:
# # Test <- bind_rows(Wave4_IH_F, Wave6_IH_F, Wave8_IH_F, Wave10_IH_F, Wave12_IH_F)
# # Test2 <- Dat$variables
# # Test1 <- Test[order(Test$fimnlabgrs_dv),]
# # Test2 <- Test2[order(Test2$fimnlabgrs_dv),]
# # identical(Test1$fimnlabgrs_dv, Test2$fimnlabgrs_dv)
# 
# # xtabs(~Ind_Pension_Imp + year, data = Test1)
# # xtabs(~Ind_Pension_Imp + year, data = Test2)
# # 
# # xtabs(~ieqmoecd_dv + year, data = Test1)
# # xtabs(~ieqmoecd_dv + year, data = Dat)
# 
# # xtabs(~Ind_Pension_Imp + year, data = Test2)
# # xtabs(~nbrcoh_dv + year, Dat)
# 
# xtabs(~Ind_Pension_Imp + year, Dat)
# xtabs(~nonepar_dv + year, Dat)
# svytable(~Ind_Pension_Imp + year, Dat)
# 
# xtabs(~nonepar_dv + year, Dat)
# xtabs(~nkids015 + year, Dat) |> prop.table(2) |> round(3)
# 
# #* Note [29.08.23] that through this process we appear to lose 53 additional responses due 
# #* to a lack of matching data, over and above those we lost in the original household merge
# #* before I added these new variables:
# # table(Dat_W4_IH$from_hh, Dat_W4_IH$from_ind, exclude=FALSE, deparse.level = 2)
# # table(Dat_W4_IH$from_hh, Dat_W4_IH$from_ind, exclude=FALSE, deparse.level = 2)
# # table(Dat_W4_IH$from_hh, Dat_W4_IH$from_ind, exclude=FALSE, deparse.level = 2)
# # table(Dat_W4_IH$from_hh, Dat_W4_IH$from_ind, exclude=FALSE, deparse.level = 2)
# # table(Dat_W4_IH$from_hh, Dat_W4_IH$from_ind, exclude=FALSE, deparse.level = 2)
# 
# #* [6] Save the updated data:
# 
# #* Saved the above as of [13.07.24]:
# # saveRDS(Dat, file = "0 - Dat.RData")
# 
# #* -------------- [c - Childcare data:] [TBC - 20.08.24]
# 
# #* When I downloaded the data into R at the beginning of this R file, rather than downloading 
# #* the entire dataset I deliberately selected the specific variables I wanted downloading.
# #* This was to save on processing demands: the whole dataset causes a massive drain on even
# #* computers with a large amount of memory. 
# 
# #* From time to time, there is a need to add data ex post facto. Sadly, because of the way I've
# #* written the code, adding this in can be quite a complicated process. In order to do this without
# #* having to re-do all of the above code, add in indicators, do imputation, etc, I have created
# #* the below code. This works for adding new household data; the process for adding individual-level
# #* data is in the next section.
# 
# #* [1] Download new data which needs merging:
# Wave4_C <- read_dta('d_child.dta') |>
#   select(d_hidp, d_pidp, d_childpno, d_psu, d_strata,
#          d_dvage)
# 
# Wave6_C <- read_dta('f_child.dta') |>
#   select(f_hidp, f_pidp, f_childpno, f_psu, f_strata,
#          f_dvage)
# 
# Wave8_C <- read_dta('h_child.dta') |>
#   select(h_hidp, h_pidp, h_childpno, h_psu, h_strata,
#          h_dvage)
# 
# Wave10_C <- read_dta('j_child.dta') |>
#   select(j_hidp, j_pidp, j_childpno, j_psu, j_strata,
#          j_dvage)
# 
# Wave12_C <- read_dta('l_child.dta') |>
#   select(l_hidp, l_pidp, l_childpno, l_psu, l_strata,
#          l_dvage)

#######################################################################################
############################### 11 - Download the survey data: ########################
#######################################################################################

#* From now on [19.7.23], the below code alone is sufficient to download the latest dataset.
#* Further note that as of [29.08.23], the Dat and JQ outputs from the JQ index should be 
#* the same again because I've ported over the _Imp data. After a further check, I therefore
#* use the filter() command to create the JQ data, so it's downloaded from the exact same
#* file:
Dat <- readRDS("0 - Dat.RData")
# Wave12_H <- readRDS("0 - Wave 12 - Households.RData")
# Wave12_HHAnalysis <- readRDS("0 - Wave 12 - Individuals for HH analysis.RData")

JQ <- filter(Dat, QoW_Index_Member == 1)
Wave12 <- JQ |> filter(DV_Time_Wave12 == 1)
Wave12_Dat <- Dat |> filter(DV_Time_Wave12 == 1)

#* Check if weight applied [20.12.23]. Note that most of the weighting difference is in the 
#* reported proportion of missing values (if you exclude just to NAs, or use the imputed data,
#* that narrows the difference quite a bit):
xtabs(~Ind_ContinuousEmployment + year, JQ) |> prop.table(2) |> round(3)
svytable(~Ind_ContinuousEmployment + year, JQ) |> prop.table(2) |> round(3)
xtabs(~Ind_ContinuousEmployment_NAs + year, JQ) |> prop.table(2) |> round(3)
svytable(~Ind_ContinuousEmployment_NAs + year, JQ) |> prop.table(2) |> round(3)
xtabs(~Ind_ContinuousEmployment_Imp + year, JQ) |> prop.table(2) |> round(3)
svytable(~Ind_ContinuousEmployment_Imp + year, JQ) |> prop.table(2) |> round(3)

xtabs(~Ind_Pension + year, JQ) |> prop.table(2) |> round(3)
svytable(~Ind_Pension + year, JQ) |> prop.table(2) |> round(3)
xtabs(~Ind_Pension_NAs + year, JQ) |> prop.table(2) |> round(3)
svytable(~Ind_Pension_NAs + year, JQ) |> prop.table(2) |> round(3)
xtabs(~Ind_Pension_Imp + year, JQ) |> prop.table(2) |> round(3)
svytable(~Ind_Pension_Imp + year, JQ) |> prop.table(2) |> round(3)

#* The below are filters from additional independent variables which are created in the 
#* 'a - Imputation' stage. They will only work after these dependent variables have 
#* been created. Updated as of [05.10.23]:

#* Employees and self-employed
Employees <- filter(JQ, DV_Employee == 1)
SelfEmployed <- filter(JQ, DV_SelfEmployed == 1)

#* Time (JQ version):
Wave4 <- JQ |> filter(DV_Time_Wave4 == 1)
Wave6 <- JQ |> filter(DV_Time_Wave6 == 1)
Wave8 <- JQ |> filter(DV_Time_Wave8 == 1)
Wave10 <- JQ |> filter(DV_Time_Wave10 == 1)
Wave12 <- JQ |> filter(DV_Time_Wave12 == 1)

#* Time (full sample version):
# Wave4 <- Dat |> filter(DV_Time_Wave4 == 1)
# Wave6 <- Dat |> filter(DV_Time_Wave6 == 1)
# Wave8 <- Dat |> filter(DV_Time_Wave8 == 1)
# Wave10 <- Dat |> filter(DV_Time_Wave10 == 1)
# Wave12 <- Dat |> filter(DV_Time_Wave12 == 1)

#* Wave comparisons:
# Wave4vs12 <- JQ |> filter(JQ$variables$DV_Time_Wave4 == 1 | JQ$variables$DV_Time_Wave12 == 1)
# Wave4vs12_Employees <- Employees |> filter(Employees$variables$DV_Time_Wave4 == 1 | Employees$variables$DV_Time_Wave12 == 1)
# Wave4vs12_SelfEmployed <- SelfEmployed |> filter(SelfEmployed$variables$DV_Time_Wave4 == 1 | SelfEmployed$variables$DV_Time_Wave12 == 1)
