
#######################################################################################
################################# 1 - Pre-Preparation: ################################
#######################################################################################

#* Note that [1] Understanding Society top-codes income variables at £100,000 per annum. 
#* This doesn't at all affect my Earnings Sufficiency indicator, but it will affect my 
#* Earnings Equity data. 

#* [1] *Create calendar year of interview variable:* 

#* I start by creating an interview date variable for each respondent, and then taking 
#* the year of the interview date:
Dat$variables$intdate <- as.Date(with(Dat$variables, paste(intdaty_dv, intdatm_dv, intdatd_dv,sep="-")),
                                 "%Y-%m-%d") 
Dat$variables$calendar_year <- as.numeric(format(Dat$variables$intdate,'%Y'))

#* The data shows that in each wave, people are interviewed across 3 years but with a skew towards
#* the earlier year: 
svytable(~ Dat$variables$calendar_year + Dat$variables$year, design = Dat)

#* [2] *Remove missing/DK/etc from net earnings variable:* 

#* There are a very small number of DKs/missings from the data (unsurprisingly given I'm working
#* with a derived variable). There are more negatives. As the Understanding Society user support
#* forums show this is self-employed people reporting a negative income. The missings are converted
#* to NA to ensure they don't play a part in subsequent calulations, but the other negative values
#* are retained:

Dat$variables$fimnlabnet_dv_removed_NAs <- replace(Dat$variables$fimnlabnet_dv,
                                                   Dat$variables$fimnlabnet_dv %in% c(-1, -9), NA)
length(which(Dat$variables$fimnlabnet_dv <0))
length(which(Dat$variables$fimnlabnet_dv == -1))
length(which(Dat$variables$fimnlabnet_dv == -9))

#* [3] *Create an annual net earnings variable:* 

#* I need to align with the JRF's published (weekly) MIS data. There's obviously a lot of flexibility
#* with how to do this, but I judge that the most intelligible comparison figure is of annual earnings,
#* so I use that benchmark (note though that it's net rather than the even more intelligible gross 
#* earnings). 

#* Regardless of the choice of how to align them, it's important to bear in mind what the actual indicator
#* is telling us: it is about whether a respondent's *monthly* earnings are below the *monthly* versions of the
#* minimum income standards, with monthly = (weekly MIS * 52)/12. Converting the monthly net labour income to
#* annual, and then converting the MIS to annual, is the same thing: 
. 
Dat$variables$fimnlabnet_dv_annual <- Dat$variables$fimnlabnet_dv_removed_NAs * 12

#* REFERENCES:
#* [1] Understanding Society, 'Imputation flags and top-coding of income variables',
#* https://www.understandingsociety.ac.uk/documentation/mainstage/user-guides/main-survey-user-guide/imputation-flags-and-top-coding-of-income-variables

#######################################################################################
############################## 2 - Create the Indicator: ##############################
#######################################################################################

#* Note that unlike the sunsetted LW/LLW indicator, I don't need to use an hours variable for this.
#* We can instead simply apply annualised MIS cut-offs to annualised net earnings data: 

Dat$variables$Ind_EarningsSufficiency <- case_when (Dat$variables$fimnlabnet_dv_annual < 13637 & #* 2012
                                           Dat$variables$calendar_year == 2012 ~ 
                                           0, 
                                         Dat$variables$fimnlabnet_dv_annual < 17811.04 &
                                           Dat$variables$calendar_year == 2012 ~ 
                                           1,
                                         Dat$variables$fimnlabnet_dv_annual > 17811.04 &
                                           Dat$variables$calendar_year == 2012 ~ 
                                           2,
                                         Dat$variables$fimnlabnet_dv_annual < 14240.72 & #* 2013
                                           Dat$variables$calendar_year == 2013 ~ 
                                           0, 
                                         Dat$variables$fimnlabnet_dv_annual < 18579.86 &
                                           Dat$variables$calendar_year == 2013 ~ 
                                           1,
                                         Dat$variables$fimnlabnet_dv_annual > 18579.86 &
                                           Dat$variables$calendar_year == 2013 ~ 
                                           2, 
                                         Dat$variables$fimnlabnet_dv_annual < 14526.20 & #* 2014
                                           Dat$variables$calendar_year == 2014 ~ 
                                           0, 
                                         Dat$variables$fimnlabnet_dv_annual < 19119.36 &
                                           Dat$variables$calendar_year == 2014 ~ 
                                           1,
                                         Dat$variables$fimnlabnet_dv_annual > 19119.36 &
                                           Dat$variables$calendar_year == 2014 ~ 
                                           2, 
                                         Dat$variables$fimnlabnet_dv_annual < 14679.08 & #* 2015
                                           Dat$variables$calendar_year == 2015 ~ 
                                           0, 
                                         Dat$variables$fimnlabnet_dv_annual < 19305.78 &
                                           Dat$variables$calendar_year == 2015 ~ 
                                           1,
                                         Dat$variables$fimnlabnet_dv_annual > 19305.78 &
                                           Dat$variables$calendar_year == 2015 ~ 
                                           2,
                                         Dat$variables$fimnlabnet_dv_annual < 14899.56 & #* 2016
                                           Dat$variables$calendar_year == 2016 ~ 
                                           0, 
                                         Dat$variables$fimnlabnet_dv_annual < 20183.28 &
                                           Dat$variables$calendar_year == 2016 ~ 
                                           1,
                                         Dat$variables$fimnlabnet_dv_annual > 20183.28 &
                                           Dat$variables$calendar_year == 2016 ~ 
                                           2,
                                         Dat$variables$fimnlabnet_dv_annual < 15434.64 & #* 2017
                                           Dat$variables$calendar_year == 2017 ~ 
                                           0,  
                                         Dat$variables$fimnlabnet_dv_annual < 20804.42 &
                                           Dat$variables$calendar_year == 2017 ~ 
                                           1,
                                         Dat$variables$fimnlabnet_dv_annual > 20804.42 &
                                           Dat$variables$calendar_year == 2017 ~ 
                                           2,
                                         Dat$variables$fimnlabnet_dv_annual < 15844.92 & #* 2018
                                           Dat$variables$calendar_year == 2018 ~ 
                                           0, 
                                         Dat$variables$fimnlabnet_dv_annual < 20087.86 &
                                           Dat$variables$calendar_year == 2018 ~ 
                                           1,
                                         Dat$variables$fimnlabnet_dv_annual > 20087.86 &
                                           Dat$variables$calendar_year == 2018 ~ 
                                           2,
                                         Dat$variables$fimnlabnet_dv_annual < 16311.36 & #* 2019
                                           Dat$variables$calendar_year == 2019 ~ 
                                           0, 
                                         Dat$variables$fimnlabnet_dv_annual < 20513.74 &
                                           Dat$variables$calendar_year == 2019 ~ 
                                           1,
                                         Dat$variables$fimnlabnet_dv_annual > 20513.74 &
                                           Dat$variables$calendar_year == 2019 ~ 
                                           2,
                                         Dat$variables$fimnlabnet_dv_annual < 16675.88 & #* 2020
                                           Dat$variables$calendar_year == 2020 ~ 
                                           0, 
                                         Dat$variables$fimnlabnet_dv_annual < 20960.42 &
                                           Dat$variables$calendar_year == 2020 ~ 
                                           1,
                                         Dat$variables$fimnlabnet_dv_annual > 20960.42 &
                                           Dat$variables$calendar_year == 2020 ~ 
                                           2,
                                         Dat$variables$fimnlabnet_dv_annual < 16913.52 & #* 2021
                                           Dat$variables$calendar_year == 2021 ~ 
                                           0, 
                                         Dat$variables$fimnlabnet_dv_annual < 21574.80 &
                                           Dat$variables$calendar_year == 2021 ~ 
                                           1,
                                         Dat$variables$fimnlabnet_dv_annual > 21574.80 &
                                           Dat$variables$calendar_year == 2021 ~ 
                                           2,
                                         Dat$variables$fimnlabnet_dv_annual < 20382.96 & #* 2022
                                           Dat$variables$calendar_year == 2022 ~ 
                                           0, 
                                         Dat$variables$fimnlabnet_dv_annual < 24351.34 &
                                           Dat$variables$calendar_year == 2022 ~ 
                                           1,
                                         Dat$variables$fimnlabnet_dv_annual > 24351.34 &
                                           Dat$variables$calendar_year == 2022 ~ 
                                           2,
                                         TRUE ~ -1)

#* To check the effectiveness of the case_when function, I compare a cross-tab of the 
#* unweighted data with the length of the unweighted data (note that it's best to use the 
#* unweighted data for this):
xtabs(~ Dat$variables$Ind_EarningsSufficiency + Dat$variables$calendar_year)

#* The below random checks show the code has worked:
length(which(Dat$variables$fimnlabnet_dv_annual < 13637 & Dat$variables$calendar_year == 2012))
length(which(Dat$variables$fimnlabnet_dv_annual < 17811.04 & Dat$variables$fimnlabnet_dv_annual > 13637 & Dat$variables$calendar_year == 2012))
length(which(Dat$variables$fimnlabnet_dv_annual > 17811.04 & Dat$variables$calendar_year == 2012))
length(which(Dat$variables$fimnlabnet_dv_annual < 15434.64 & Dat$variables$calendar_year == 2017))
length(which(Dat$variables$fimnlabnet_dv_annual < 20804.42 & Dat$variables$fimnlabnet_dv_annual > 15434.64 & Dat$variables$calendar_year == 2017))
length(which(Dat$variables$fimnlabnet_dv_annual > 20804.42 & Dat$variables$calendar_year == 2017))
length(which(Dat$variables$fimnlabnet_dv_annual < 16913.52 & Dat$variables$calendar_year == 2021))
length(which(Dat$variables$fimnlabnet_dv_annual < 21574.80 & Dat$variables$fimnlabnet_dv_annual > 16913.52 & Dat$variables$calendar_year == 2021))
length(which(Dat$variables$fimnlabnet_dv_annual > 21574.80 & Dat$variables$calendar_year == 2021))

#* Time series proportional table:
prop.table(svytable((~Ind_EarningsSufficiency + year),JQ), margin=2)

#######################################################################################
############## 3 - Visualise data and compare with living wage (optional): ############
#######################################################################################

#* Note that for the current time series (stopping at 2020), the single person MIS ranges
#* from 73.8%-79.6% of half the couple MIS. In the latest year (April 2022) it shoots up
#* considerably to 83.7% of half the couple MIS, doubtless due to a greater relative rise
#* of household costs which aren't as strongly associated with the number of children you 
#* have (eg heating bills). I don't consider this a limitation of the data vis-a-vis other
#* cut-offs, eg LW/LLW, because there is a clear and justifiable reason for this inconsistency
#* based on calculated costs of the various baskets of goods.

#* Generate filters:

# JQ <- Dat |> filter(Dat$variables$index == "Quality of Work")
# Employees <- Dat |> filter(Dat$variables$jbsemp == 1)
# SelfEmployed <- Dat |> filter(Dat$variables$jbsemp == 2)

#* Generate weighted data for the .csv table (saved in Index). Note that *there are a lot more*
#* *missing/NAs for Ind_LW,* but still only a relatively small number once you only 
#* filter to those in the JQ index (I believe this discrepancy is due to the use of the hours
#* variable for Ind_LW): 

# write.csv((svytable(~ JQ$variables$Ind_LW + JQ$variables$wave, design = JQ)), "JQ - Ind_LW by year - adjusted for calendar year.csv")
# write.csv((svytable(~ JQ$variables$Ind_EarningsSufficiency + JQ$variables$year, design = JQ)), "JQ - Ind_EarningsSufficiency by year - adjusted for calendar year.csv")
# 
# write.csv((svytable(~ Employees$variables$Ind_EarningsSufficiency + Employees$variables$year, design = Employees)), "Employees - Ind_EarningsSufficiency by year - adjusted for calendar year.csv")
# write.csv((svytable(~ SelfEmployed$variables$Ind_EarningsSufficiency + SelfEmployed$variables$year, design = SelfEmployed)), "SelfEmployed - Ind_EarningsSufficiency by year - adjusted for calendar year.csv")

#* Run through a ggplot:

# MIS_LW_Compare <- read.csv('Ind_LW vs Ind_EarningsSufficiency by Wave.csv')
# 
# ggplot(MIS_LW_Compare, aes(x = Wave, y = Worst.Double, colour = Method, group = Method)) +
#   geom_line() +
#   geom_point() +
#   scale_y_continuous(limits=c(0.0, 0.5), labels = percent) +
#   scale_x_continuous(breaks = seq(2, 10, by = 2)) +
#   geom_text(aes(label = paste(round(Worst.Double*100, 2), "%")), vjust = 1.5) +
#   labs(y = "% of JQ Index",
#        fill = "",
#        x = "",
#        title = "") +
#   theme_economist()
# 
# ggplot(MIS_LW_Compare, aes(x = Wave, y = Middle.Double, colour = Method, group = Method)) +
#   geom_line() +
#   geom_point() +
#   scale_y_continuous(limits=c(0.0, 0.5), labels = percent) +
#   scale_x_continuous(breaks = seq(2, 10, by = 2)) +
#   geom_text(aes(label = paste(round(Middle.Double*100, 2), "%")), vjust = 1.5) +
#   labs(y = "% of JQ Index",
#        fill = "",
#        x = "",
#        title = "") +
#   theme_economist()
# 
# ggplot(MIS_LW_Compare, aes(x = Wave, y = Highest.Double, colour = Method, group = Method)) +
#   geom_line() +
#   geom_point() +
#   scale_y_continuous(limits=c(0.0, 0.5), labels = percent) +
#   scale_x_continuous(breaks = seq(2, 10, by = 2)) +
#   geom_text(aes(label = paste(round(Highest.Double*100, 2), "%")), vjust = 1.5) +
#   labs(y = "% of JQ Index",
#        fill = "",
#        x = "",
#        title = "") +
#   theme_economist()

#######################################################################################
################## 7 - SAVE THE INDICATOR INTO THE SURVEY: ############################
#######################################################################################

#* Saved as of [26.09.23]:
# saveRDS(Dat, file = "0 - Dat.RData")

readRDS("0 - Dat.RData")
Dat$variables$Ind_EarningsSufficiency
