
#######################################################################################
################### 1 - Prepare the gross hourly wage variable: #######################
#######################################################################################

#* I calculate earnings equity using net hourly wages. So I replicate parts of the same
#* process as for Earnings Sufficiency, although with some important differences - esp.
#* around the need to consider hours worked.

#* Note that for the purposes of this variable I'm interested in *usual* hours worked 
#* per week in their main job (jbhrs), or their self-employed main job (jshrs), or
#* any second jobs (j2hrs). This is because the derived net earnings variable refer to
#* usual pay, not any overtime pay, so I need to align with this.  

#* An alternative would be to look at overtime hours worked (jbot) and then number of hours 
#* worked as paid overtime (jbotpd), and compare these with the hourly rates they give
#* if paid overtime (extrate and extrest). However I decide against this, chiefly because
#* usual pay seems the most appropriate way of looking at earnings equity. There may also
#* be recall issues with the overtime variables which are less likely to happen with 
#* usual pay.  

#* ----------------- [1] Recode missing, inapplicable, etc: 
 
#* First I need to work out what to do where people don't provide hours data. There are two
#* types of data here:
#* [a] Data which needs re-coding into 0, because it isn't actually "missing." I 
#* code inapplicable [-8] and proxy [-7] into this category. The proxy decision is 
#* because a large number of j2hhrs respondents have "proxy" assigned next to them. 
#* [b] Data which needs marking NA. For example if someone says don't know for any 
#* *one* of the hours variables, this means I can't do calculations on any of the 
#* rest of the data.  

#* Code for part [a] of above:

Dat$variables$jbhrs_adj <- case_when (Dat$variables$jbhrs == -7 ~ 0,
                                      Dat$variables$jbhrs == -8 ~ 0,
                                      TRUE ~ as.numeric(as.character(Dat$variables$jbhrs)))

Dat$variables$jshrs_adj <- case_when (Dat$variables$jshrs == -7 ~ 0,
                                      Dat$variables$jshrs == -8 ~ 0,
                                      TRUE ~ as.numeric(as.character(Dat$variables$jshrs)))

Dat$variables$j2hrs_adj <- case_when (Dat$variables$j2hrs == -7 ~ 0,
                                      Dat$variables$j2hrs == -8 ~ 0,
                                      TRUE ~ as.numeric(as.character(Dat$variables$j2hrs)))

#* Code for part [b] of above. Note that the IEMB variables [-10, -11] are only 
#* included for completeness: they don't actually affect any variables below:

Dat$variables$jbhrs_adj <- replace(Dat$variables$jbhrs_adj,
                                   Dat$variables$jbhrs_adj %in% c(-1, -2, -9, -10, -11), NA)

Dat$variables$jshrs_adj <- replace(Dat$variables$jshrs_adj,
                                   Dat$variables$jshrs_adj %in% c(-1, -2, -9, -10, -11), NA)

Dat$variables$j2hrs_adj <- replace(Dat$variables$j2hrs_adj,
                                   Dat$variables$j2hrs_adj %in% c(-1, -2, -9, -10, -11), NA)

#* The below code [18.07.23] shows that this decision to recode DKs, refusals, etc as NA affects
#* a few hundred respondents each across the whole sample (most of these won't be mutually 
#* exclusive). They also show that jshrs and j2hrs are mutually exclusive, but that j2hrs is
#* used for both of them to report earnings from any second jobs:

# length(which(Dat$variables$jbhrs == -1))
# length(which(Dat$variables$jbhrs == -2))
# length(which(Dat$variables$jbhrs == -7))
# length(which(Dat$variables$jbhrs == -8))
# length(which(Dat$variables$jbhrs == -9))
# length(which(Dat$variables$jbhrs == -10))
# length(which(Dat$variables$jbhrs == -11))
# 
# length(which(Dat$variables$jshrs == -1))
# length(which(Dat$variables$jshrs == -2))
# length(which(Dat$variables$jshrs == -7))
# length(which(Dat$variables$jshrs == -8))
# length(which(Dat$variables$jshrs == -9))
# length(which(Dat$variables$jshrs == -10))
# length(which(Dat$variables$jshrs == -11))
# 
# length(which(Dat$variables$j2hrs == -1))
# length(which(Dat$variables$j2hrs == -2))
# length(which(Dat$variables$j2hrs == -7))
# length(which(Dat$variables$j2hrs == -8))
# length(which(Dat$variables$j2hrs == -9))
# length(which(Dat$variables$j2hrs == -10))
# length(which(Dat$variables$j2hrs == -11))
# 
# xtabs(~Dat$variables$jbhrs + Dat$variables$index)
# xtabs(~Dat$variables$j2hrs + Dat$variables$index)
# xtabs(~Dat$variables$jshrs + Dat$variables$jbsemp)
# 
# xtabs(~Dat$variables$jbhrs + Dat$variables$jshrs)
# xtabs(~Dat$variables$jbhrs + Dat$variables$j2hrs)
# xtabs(~Dat$variables$jshrs + Dat$variables$j2hrs)

#* ----------------- [2] Create a monthly jbhrs and jshrs variable: 

#* Then I need to create a monthly jbhrs and jshrs variable, to align it with the monthly
#* gross labour income variable. Note that j2hrs is already reported on a monthly basis, and
#* so I don't need to make any adjustment. This is the converse of what I do with the 
#* Excessive Hours indicator (where I adjust j2hrs for monthly to align with the weekly 
#* hours variable):

Dat$variables$jbhrs_adj <- (Dat$variables$jbhrs_adj * 52) / 12 
Dat$variables$jshrs_adj <- (Dat$variables$jshrs_adj * 52) / 12

max(Dat$variables$jbhrs_adj, na.rm = TRUE) #* 97.9 weekly, 424 monthly
max(Dat$variables$jshrs_adj, na.rm = TRUE) #* 120 weekly, 520 monthly
max(Dat$variables$j2hrs_adj, na.rm = TRUE) #* 160 monthly;

#* ----------------- [3] Create a combined labour hours variable: 

Dat$variables$labhrs <- Dat$variables$jbhrs_adj + Dat$variables$jshrs_adj + Dat$variables$j2hrs_adj

#* All of the data returned is valid / reasonable. There are 168 hours
#* in a week and thus 728 in a month. A max of 126 hours means 42 spare 
#* hours in a week / ie 6 per day. A very extreme case of excessive hours,
#* but still a feasible one [18.07.23]:

max(Dat$variables$labhrs, na.rm = TRUE) #* 126 weekly; 545 monthly;  

#* ----------------- [4] Recode some NAs for gross wage: 

#* First I remove missing / inapplicable / don't knows from the gross monthly income 
#* variable by converting them into NAs. As with net labour income, there are exactly 
#* 194 respondents across all waves who report net earnings below ?0.00. Only a tiny 
#* handful of people report -1 or -9, making the below process something of a formality. 
#* Note that at this stage I don't quite want to remove all zeros, since some will be self-
#* employed people working a set number of hours and reporting zero income. I thus
#* need to keep them and deal with zeros only after filtering for JQ:

Dat$variables$fimnlabgrs_dv_adj <- replace(Dat$variables$fimnlabgrs_dv,
                                                   Dat$variables$fimnlabgrs_dv %in% c(-1, -2, -9), NA)

# length(which(Dat$variables$fimnlabgrs_dv <0))
# length(which(Dat$variables$fimnlabgrs_dv == -1))
# length(which(Dat$variables$fimnlabgrs_dv == -2))
# length(which(Dat$variables$fimnlabgrs_dv == -8))
# length(which(Dat$variables$fimnlabgrs_dv == -9))
# length(which(Dat$variables$fimnlabgrs_dv == 0))

#* ----------------- [4] Recode zero hours into NA:

#* Before I divide monthly income by monthly hours to get monthly wage, we 
#* need to ensure that we don't end up dividing income by 0 hours, as that will 
#* return a result of infinity and will prevent us from doing any stats eg mean. 
#* So I now recode the zeros into NAs: 
Dat$variables$labhrs_adj <- set_na(Dat$variables$labhrs, na = 0)
length(which(Dat$variables$labhrs == 0))
length(which(Dat$variables$labhrs_adj == 0))

#* ----------------- [5] Create the wage variable:

#* I then just divide monthly gross income by monthly hours worked (including N/As). Note that
#* from this point it is possible to have a negative value, since people can report a negative
#* income in one year. Also note that dividing two monthly variables by each other ends up creating
#* an hourly wage (I'd end up with the same result if I converted to a daily wage):
Dat$variables$fimnlabgrs_wage <- Dat$variables$fimnlabgrs_dv_adj / Dat$variables$labhrs_adj

#* Note that across the sample, the mean hourly wage is 16.27 - a reasonable figure: 
svymean(Dat$variables$fimnlabgrs_wage, design = Dat, na.rm = TRUE)
summary(Dat$variables$fimnlabgrs_wage) #(*Nb this one isn't weighted)
gc()

#######################################################################################
############################### 2 - Exclude outliers: #################################
#######################################################################################

#* ----------------- [1] Create outlier exclusion:

#* The above process creates some extreme outliers in two later waves. This is despite
#* the fact that each element which makes up the data (gross wages, employee hours, self-employed
#* hours) has fairly consistent values across waves (see the wave-by-wave descriptives in the next 
#* section). This can therefore only be explained by calculations being done on v. large incomes and
#* v. small hours within certain waves. This might suggest coding errors (eg mis-coding someone as normally
#* working v few hours), or it might be a result of a discrepancy between the reference periods: the hours
#* questions are about hours "usually" worked per week, whereas fimnlabgrs_dv is about actual monthly income.
#* So someone taking a break who is self-employed would report very different incomes.

#* Either way, these outliers need to be excluded as they don't reflect a genuine change in wage inequality,
#* and left in there they significantly change the SDs across each wave. I recode any wages above £500
#* an hour as N/A. This brings the maximum values in the dataset much closer together, all around 
#* £500, and aligns the SDs across each wave:

length(which(Dat$variables$fimnlabgrs_wage > 500))
Dat$variables$fimnlabgrs_wage <- replace(Dat$variables$fimnlabgrs_wage,
                                           Dat$variables$fimnlabgrs_wage > 500, NA)

#* ----------------- [2] Calculate effect of all the above ajdustments on the number of NAs:

#* As an aside [27.09.23] it should be noted that, as you'll see from the supplementary data tables 
#* (see Table A.11 here[1]), the distribution of missing values across years differs for the Earnings 
#* Equity vs. Excessive Hours indicators. At first sight this might seem odd, as - since the fimnlabgrs 
#* data has very few missings - missing values are clearly determined by hours variables, and both use 
#* almost the same hours variables.

#* Both indicators in fact have a similar number of missing values, and there is a lot of crossover between
#* them. The weighted proportion of missing values is also almost identical acros the time series (with just one
#* decimal point difference). It is simply that the people who are missing across both indicators is slightly
#* different, and this therefore leads to a different distribution of missingness across the time series: 
xtabs(~Ind_ExcessiveHours + Ind_EarningsEquity, JQ)
length(which(JQ$variables$Ind_EarningsEquity == -1))
length(which(JQ$variables$Ind_ExcessiveHours == -1))
xtabs(~Ind_EarningsEquity + year, JQ)
xtabs(~Ind_ExcessiveHours + year, JQ)
prop.table(svytable((~Ind_EarningsEquity + year),JQ), margin=2)
prop.table(svytable((~Ind_ExcessiveHours + year),JQ), margin=2)
prop.table(xtabs((~Ind_EarningsEquity + year),JQ), margin=2)
prop.table(xtabs((~Ind_ExcessiveHours + year),JQ), margin=2)

#* This difference is determined by three main things. These are deliberate and not unintentional differences. They
#* reflect normative judgements about the two rather different aspects of job quality these two indicators are 
#* aimed at measuring:
#* [1] I use employee usual weekly overtime hours (jbot) for excessive hours. This isn't used to 
#* calculate wages, because it's worded very differently to the other hours questions and therefore likely
#* isn't reflected in the gross usual pay data. This adds some missings to the Excessive Hours which are not
#* missing in the Earnings Equity indicator;
#* [2] People who report working no hours at all are re-coded as missing for the purposes of the Earnings Equity
#* indicator. Since otherwise, the earnings they make will be divided by zero, and the result will be infinity. 
#* Meaning no summary statistics at all could be produced from the indicator or associated data. However, I keep
#* these respondents in the Excessive Hours indicator, since they do say they are working and are thus in the JQ
#* index: it is simply that they don't report any hours in the period studied. So in the converse to point 1 above:
#* this creates missings for Earnings Equity who aren't missing for Excessive Hours;
#* [3] In common with many approaches to measuring earnings, I exclude some extreme outliers for the earnings data
#* which appear in some individual waves. There are not many at all, but this also pushes the Earnings Equity 
#* missingness up and creates missings which don't appear in Excessive Hours. Taken together, all this means that
#* whilst there is a strong correlation between missingness between both indicators, a good deal of respondents 
#* are missing in one indicator but not another.

sum(is.na(JQ$variables$jbhrs_adj))
sum(is.na(JQ$variables$jshrs_adj))
sum(is.na(JQ$variables$j2hrs_adj))
sum(is.na(JQ$variables$jbot_adj))
sum(is.na(JQ$variables$labhrs_adj_weekly_NAs))
sum(is.na(JQ$variables$fimnlabgrs_dv_adj))
sum(is.na(JQ$variables$fimnlabgrs_wage))
sum(is.na(JQ$variables$labhrs_adj))
sum(is.na(JQ$variables$fimnlabgrs_wage))

#* REFERENCES:
#* [1] Thomas C. Stephens (2023), 'Change, stagnation and polarisation in UK job quality, 2012-21: Evidence from
#* a new Quality of Work index', Centre for Analysis of Social Exclusion, CASEPaper 230, Appendix, Table A.11,
#* https://sticerd.lse.ac.uk/CASE/_NEW/PUBLICATIONS/abstract/?index=10360

#######################################################################################
############# 3 - Calculate percentiles at the first wave (Wave T): ###################
#######################################################################################

#* I'll start by filtering into a new survey design consisting only of Wave 4 data. I'll
#* also use this opportunity to produce filters for the other waves, since this will be
#* needed for the standard deviation calculations later:
Wave4 <- Dat |> filter(Dat$variables$wave == "4")
Wave6 <- Dat |> filter(Dat$variables$wave == "6")
Wave8 <- Dat |> filter(Dat$variables$wave == "8")
Wave10 <- Dat |> filter(Dat$variables$wave == "10")
Wave12 <- Dat |> filter(Dat$variables$wave == "12")

#* I then create a new wage variable, presenting Wave 4's data as standard units.
#* It's easiest (and clearest) to do this manually. As above, I do this for every wave
#* and not just Wave 4: 
Wave4WageMean <- svymean(Wave4$variables$fimnlabgrs_wage, design = Wave4, na.rm = TRUE)
Wave6WageMean <- svymean(Wave6$variables$fimnlabgrs_wage, design = Wave6, na.rm = TRUE)
Wave8WageMean <- svymean(Wave8$variables$fimnlabgrs_wage, design = Wave8, na.rm = TRUE)
Wave10WageMean <- svymean(Wave10$variables$fimnlabgrs_wage, design = Wave10, na.rm = TRUE)
Wave12WageMean <- svymean(Wave12$variables$fimnlabgrs_wage, design = Wave12, na.rm = TRUE)

Wave4WageSD <- svysd(~ Wave4$variables$fimnlabgrs_wage, design = Wave4, na.rm = TRUE)
Wave6WageSD <- svysd(~ Wave6$variables$fimnlabgrs_wage, design = Wave6, na.rm = TRUE)
Wave8WageSD <- svysd(~ Wave8$variables$fimnlabgrs_wage, design = Wave8, na.rm = TRUE)
Wave10WageSD <- svysd(~ Wave10$variables$fimnlabgrs_wage, design = Wave10, na.rm = TRUE)
Wave12WageSD <- svysd(~ Wave12$variables$fimnlabgrs_wage, design = Wave12, na.rm = TRUE)

#* Quality checks: The standard deviation for the wage data seems quite high, but this 
#* stacks up. The unweighted SD in the base R package is similar, so this isn't an issue
#* with the package I'm deriving the svysd function from. The distribution is also non-normal
#* and left-skewed, with lots of outliers. An SD higher than the mean is possible for data
#* with negative values, as we have here: 
sd(Wave4$variables$fimnlabgrs_wage, na.rm = TRUE)
sd(Wave6$variables$fimnlabgrs_wage, na.rm = TRUE)
sd(Wave8$variables$fimnlabgrs_wage, na.rm = TRUE)
sd(Wave10$variables$fimnlabgrs_wage, na.rm = TRUE)
sd(Wave12$variables$fimnlabgrs_wage, na.rm = TRUE)

# ggsurvey(Wave4, aes(x = Wave4$variables$fimnlabgrs_wage)) +
#   geom_histogram (binwidth=0.5, fill = '#174950') + 
#   xlim(-2.5,100) +
#   theme_economist()
# 
#   ggsurvey(Wave6, aes(x = Wave6$variables$fimnlabgrs_wage)) +
#     geom_histogram (binwidth=0.5, fill = '#174950')+ 
#     xlim(-2.5,100) + 
#   theme_economist()
#   
#   ggsurvey(Wave8, aes(x = Wave8$variables$fimnlabgrs_wage)) +
#     geom_histogram (binwidth=0.5, fill = '#174950') + 
#     xlim(-2.5,100) + 
#   theme_economist()
#   
#   ggsurvey(Wave10, aes(x = Wave10$variables$fimnlabgrs_wage)) +
#     geom_histogram (binwidth=0.5, fill = '#174950') +
#     xlim(-2.5,100) +
#   theme_economist()
  
#* Then convert to standard units:
Wave4$variables$WageStandardUnits <- (Wave4$variables$fimnlabgrs_wage - Wave4WageMean) / Wave4WageSD
Wave6$variables$WageStandardUnits <- (Wave6$variables$fimnlabgrs_wage - Wave6WageMean) / Wave6WageSD
Wave8$variables$WageStandardUnits <- (Wave8$variables$fimnlabgrs_wage - Wave8WageMean) / Wave8WageSD
Wave10$variables$WageStandardUnits <- (Wave10$variables$fimnlabgrs_wage - Wave10WageMean) / Wave10WageSD
Wave12$variables$WageStandardUnits <- (Wave12$variables$fimnlabgrs_wage - Wave12WageMean) / Wave12WageSD

#* Note that conversion to standard units makes the data much more similar, with
#* similar (unweighted) means across the dataset (although Wave 12 has a positive 
#* mean whereas the others are negative). I also cross-tabulate the data:
summary(Wave4$variables$WageStandardUnits)
summary(Wave6$variables$WageStandardUnits)
summary(Wave8$variables$WageStandardUnits)
summary(Wave10$variables$WageStandardUnits)
summary(Wave12$variables$WageStandardUnits)

# ggsurvey(Wave4, aes(x = Wave4$variables$fimnlabgrs_wage, y = Wave4$variables$WageStandardUnits)) +
#       geom_point () +
#     theme_economist()

#* Then merge the standard units data into both the Wave 4-12 datasets:

Dat$variables$WageStandardUnits <- c(Wave4$variables$WageStandardUnits, 
                                     Wave6$variables$WageStandardUnits,
                                     Wave8$variables$WageStandardUnits,
                                     Wave10$variables$WageStandardUnits,
                                     Wave12$variables$WageStandardUnits)

#* In order to test if this works, I re-do the filter above. The data are
#* exactly the same. I also re-do the survey cross-tab to check if the SU
#* data corresponding to people has changed (it hasn't) [26.09.23]:
# Wave4 <- Dat |> filter(Dat$variables$wave == "4")
# Wave6 <- Dat |> filter(Dat$variables$wave == "6")
# Wave8 <- Dat |> filter(Dat$variables$wave == "8")
# Wave10 <- Dat |> filter(Dat$variables$wave == "10")
# Wave12 <- Dat |> filter(Dat$variables$wave == "12")
# 
# summary(Wave4$variables$WageStandardUnits)
# summary(Wave6$variables$WageStandardUnits)
# summary(Wave8$variables$WageStandardUnits)
# summary(Wave10$variables$WageStandardUnits)
# summary(Wave12$variables$WageStandardUnits)
# ggsurvey(Wave4, aes(x = Wave4$variables$fimnlabgrs_wage, y = Wave4$variables$WageStandardUnits)) +
#       geom_point () +
#     theme_economist()

#* Some descriptives:
# 
# length(which(Wave4$variables$fimnlabgrs_dv > 0))
# length(which(Wave4$variables$fimnlabgrs_dv_NAs > 0))
# length(which(Wave4$variables$fimnlabgrs_wage > 0))
# 
# length(which(Wave6$variables$fimnlabgrs_dv > 0))
# length(which(Wave6$variables$fimnlabgrs_dv_NAs > 0))
# length(which(Wave6$variables$fimnlabgrs_wage > 0))
# 
# length(which(Wave8$variables$fimnlabgrs_dv > 0))
# length(which(Wave8$variables$fimnlabgrs_dv_NAs > 0))
# length(which(Wave8$variables$fimnlabgrs_wage > 0))
# 
# length(which(Wave10$variables$fimnlabgrs_dv > 0))
# length(which(Wave10$variables$fimnlabgrs_dv_NAs > 0))
# length(which(Wave10$variables$fimnlabgrs_wage > 0))
# 
# summary(Wave4$variables$fimnlabgrs_dv)
# summary(Wave6$variables$fimnlabgrs_dv)
# summary(Wave8$variables$fimnlabgrs_dv)
# summary(Wave10$variables$fimnlabgrs_dv)
# 
# summary(Wave4$variables$jbhrs_NAs) #* Note that once you exclude -8s etc, there 
# summary(Wave6$variables$jbhrs_NAs) #* is nobody reporting working 0 hours as employees;
# summary(Wave8$variables$jbhrs_NAs)
# summary(Wave10$variables$jbhrs_NAs)
# 
# summary(Wave4$variables$jshrs_NAs)#* Note that once you exclude -8s etc, there 
# summary(Wave6$variables$jshrs_NAs)#* is nobody reporting working 0 hours as self-employed;
# summary(Wave8$variables$jshrs_NAs)
# summary(Wave10$variables$jshrs_NAs)
# 
# summary(Wave4$variables$fimnlabgrs_wage)
# summary(Wave6$variables$fimnlabgrs_wage)
# summary(Wave8$variables$fimnlabgrs_wage)
# summary(Wave10$variables$fimnlabgrs_wage)

#######################################################################################
############################## 4 - Create the indicator: ##############################
#######################################################################################

#* I can then create the indicator, using the Wave 4 standard errors as a cut-off. I
#* start by identifying the percentile cut-offs for the Wave 4 data, in Standard Units.
#* For info, I present the same percentile cut-offs in wages: 

svyquantile(~ Wave4$variables$WageStandardUnits, 
            Wave4, 
            quantiles = c(.20, .50, .60),
            interval.type = "mean",
            na.rm = TRUE,
            qrule = "math") 

svyquantile(~ Wave4$variables$fimnlabgrs_wage, 
            Wave4, 
            quantiles = c(.20, .50, .60),
            interval.type = "mean",
            na.rm = TRUE,
            qrule = "math")

#* Note [26.09.23] that the wage thresholds at the 20th percentile are below the Govt's 
#* published National Living Wage rates, let alone the Living Wage Foundation's higher
#* living wage. This is because I divide labour earnings by all hours worked, including 
#* overtime, second jobs, etc. It is noteworthy and interesting in itself that this pushes
#* those at the bottom of the distribution below statutory minimum hours. This is true for
#* all waves and not just wave 4. 

#* This yields the following cut-offs in Standard Units:
#* Lower cut-off (0.2) - bottom fifth of wage distribution: < -0.52276098
#* Middle cut-off (0.2-0.6) - bottom 20%-60% of wage distribution: < -0.08376399 
#*  Higher cut-off (>0.6) - top 40% of wage distribution: > -0.08376399

Dat$variables$Ind_EarningsEquity <- case_when(Dat$variables$WageStandardUnits <= -0.52276098 ~ 0,
                                                    (Dat$variables$WageStandardUnits > -0.52276098) & (Dat$variables$WageStandardUnits < -0.08376399) ~ 1,
                                                     Dat$variables$WageStandardUnits >= -0.08376399  ~ 2,
                                                    TRUE ~ -1)

#######################################################################################
####################### 5 - Analysis and visualisation: ###############################
#######################################################################################

#* Start by creating the filters:
JQ <- Dat |> filter(Dat$variables$index == "Quality of Work")
LW <- Dat |> filter(Dat$variables$index == "Lack Work")
Employees <- Dat |> filter(Dat$variables$jbsemp == 1)
SelfEmployed <- Dat |> filter(Dat$variables$jbsemp == 2)

#* Data check [26.09.23]. Confirms same trends as published in the CASE working
#* paper:
prop.table(svytable((~Ind_EarningsEquity + year),JQ), margin=2)

#######################################################################################
################## 7 - Save the indicator into the survey: ############################
#######################################################################################

#* Saved the above as of [26.09.23]. Note that this reflects the slightly amended
#* survey design using the self-completion questionnaire weighting. This is important,
#* because the standard units and other thresholds are slightly different using this
#* weighting (though not in a way that would ever affect the results):
saveRDS(Dat, file = "0 - Dat.RData")

readRDS("0 - Dat.RData")
Dat$variables$Ind_EarningsEquity
