
#######################################################################################
############################## 1 - Hedonic weighting: #################################
#######################################################################################

#* -----------------------------------------------
#* -----------------------------------------------
#* [a] Prepare satisfaction variables
#* -----------------------------------------------
#* -----------------------------------------------

#* Missingness is quite high for life satisfaction for some of the earlier waves,
#* especialy waves 4 and 6. It drops down markedly afterwards (likely due to 
#* panel attrition of these non-respondents more than anything):

Dat$variables$sclfsato_adj <- case_when(Dat$variables$sclfsato <= 0 ~ -1,
                                        TRUE ~ as.numeric(as.character(Dat$variables$sclfsato)))
prop.table(xtabs(~sclfsato_adj + year, JQ),2)

#* After ascertaining this, I create a life satisfaction variable which converts the missing
#* values to NA:

Dat$variables$DV_LifeSatisfaction <- case_when(Dat$variables$sclfsato == 1 ~ 1,
                                               Dat$variables$sclfsato == 2 ~ 2,
                                               Dat$variables$sclfsato == 3 ~ 3,
                                               Dat$variables$sclfsato == 4 ~ 4,
                                               Dat$variables$sclfsato == 5 ~ 5,
                                               Dat$variables$sclfsato == 6 ~ 6,
                                               Dat$variables$sclfsato == 7 ~ 7)

#* The job satisfaction variable is structured in exactly the same way as the life satisfation
#* variable, with the same (1-7) scale on satisfaction from 1 (completely dissatisfied) to 
#* 4 (neither satisfied nor dissatisified) through to 7 (completely satisfied). The distribution
#* in both is also similar with a skewness towards the higher end, with mostly satisfied (6) 
#* being the modal score in both indicators. Despite this similarity, it is striking that
#* the correlation between the scores, especially at the lower end of the distribution, is
#* not as strong as might be assumed. Fewer people score poorly on job satisfaction, so 
#* even at the lower end of the distribution the most common life safistaction score is 
#* in fact the highest:

Dat$variables$jbsat_adj <- case_when(Dat$variables$jbsat <= 0 ~ -1,
                                        TRUE ~ as.numeric(as.character(Dat$variables$jbsat)))
prop.table(xtabs(~jbsat_adj + year, JQ),2)

Dat$variables$DV_JobSatisfaction <- case_when(Dat$variables$jbsat == 1 ~ 1,
                                               Dat$variables$jbsat == 2 ~ 2,
                                               Dat$variables$jbsat == 3 ~ 3,
                                               Dat$variables$jbsat == 4 ~ 4,
                                               Dat$variables$jbsat == 5 ~ 5,
                                               Dat$variables$jbsat == 6 ~ 6,
                                               Dat$variables$jbsat == 7 ~ 7)

prop.table(svytable(~DV_JobSatisfaction + DV_LifeSatisfaction, JQ),2) |> round(2)

#* -----------------------------------------------
#* -----------------------------------------------
#* [b] Make panel and standardise regression outputs
#* -----------------------------------------------
#* -----------------------------------------------

#* First I make a panel, standardise regression outputs within that panel, and 
#* then make the panel balanced. This is important because I won't be able to 
#* interpret the coefficients of the regression properly if I don't do this, 
#* as they will be affected by the different nature of the predictor variables:

Panel_JQ <- JQ$variables
Panel_JQ <- make.pbalanced(Panel_JQ, balance.type = "shared.individuals")
Panel_JQ <- make.pconsecutive(Panel_JQ)

#* I then filter only to the variables I need and remove all NAs. This should 
#* make the panel completely balanced:

Panel_JQ_Filtered <- Panel_JQ |> select(pidp, year, 
                                        DV_LifeSatisfaction, DV_JobSatisfaction,
                                        DV_Age_All_Num, DV_Region_All,
                                        CF_DependentChildren_Desc, CF_NonWorkingHHMembers_Desc,
                                        CF_CaringResponsibilities_Desc, 
                                        Ind_EarningsSufficiency, Ind_EarningsEquity_Imp,
                                        Ind_Pension_Imp,
                                        Ind_ContinuousEmployment_Imp, Ind_CompositeSecurity_Imp,
                                        Ind_Autonomy_Imp, Ind_CollectiveVoice_Imp,
                                        Ind_Flexibility_Imp, Ind_ExcessiveHours_Imp,
                                        Ind_ManagerialDuties_Imp, Ind_ShortTermProspects_Imp, Ind_LongTermProspects,
                                        Ind_WorkFatalities, Ind_WorkAccidents, Ind_WorkIllness)
Panel_JQ_Filtered <- na.omit(Panel_JQ_Filtered)

#* Standardise the variables I'm interested in:
Panel_JQ_Filtered$DV_LifeSatisfaction <- standardize(Panel_JQ_Filtered$DV_LifeSatisfaction)
Panel_JQ_Filtered$DV_JobSatisfaction <- standardize(Panel_JQ_Filtered$DV_JobSatisfaction)
Panel_JQ_Filtered$Ind_EarningsSufficiency <- standardize(Panel_JQ_Filtered$Ind_EarningsSufficiency)
Panel_JQ_Filtered$Ind_EarningsEquity_Imp <- standardize(Panel_JQ_Filtered$Ind_EarningsEquity_Imp)
Panel_JQ_Filtered$Ind_Pension_Imp <- standardize(Panel_JQ_Filtered$Ind_Pension_Imp)
Panel_JQ_Filtered$Ind_ContinuousEmployment_Imp <- standardize(Panel_JQ_Filtered$Ind_ContinuousEmployment_Imp)
Panel_JQ_Filtered$Ind_CompositeSecurity_Imp <- standardize(Panel_JQ_Filtered$Ind_CompositeSecurity_Imp)
Panel_JQ_Filtered$Ind_Autonomy_Imp <- standardize(Panel_JQ_Filtered$Ind_Autonomy_Imp)
Panel_JQ_Filtered$Ind_CollectiveVoice_Imp <- standardize(Panel_JQ_Filtered$Ind_CollectiveVoice_Imp)
Panel_JQ_Filtered$Ind_Flexibility_Imp <- standardize(Panel_JQ_Filtered$Ind_Flexibility_Imp)
Panel_JQ_Filtered$Ind_ExcessiveHours_Imp <- standardize(Panel_JQ_Filtered$Ind_ExcessiveHours_Imp)
Panel_JQ_Filtered$Ind_ManagerialDuties_Imp <- standardize(Panel_JQ_Filtered$Ind_ManagerialDuties_Imp)
Panel_JQ_Filtered$Ind_ShortTermProspects_Imp <- standardize(Panel_JQ_Filtered$Ind_ShortTermProspects_Imp)
Panel_JQ_Filtered$Ind_LongTermProspects <- standardize(Panel_JQ_Filtered$Ind_LongTermProspects)
Panel_JQ_Filtered$Ind_WorkFatalities <- standardize(Panel_JQ_Filtered$Ind_WorkFatalities)
Panel_JQ_Filtered$Ind_WorkAccidents <- standardize(Panel_JQ_Filtered$Ind_WorkAccidents)
Panel_JQ_Filtered$Ind_WorkIllness <- standardize(Panel_JQ_Filtered$Ind_WorkIllness)

#* Tests show that despite the above, the panel is still slightly imbalanced. However the model
#* is now fully consecutive. However the test of panel unbalancedness based on Ahrens/Pincus (1981)
#* shows it's quite highly balanced anyway:
is.pbalanced(Panel_JQ_Filtered)
xtabs(~Ind_Pension_Imp + year, Panel_JQ_Filtered)
punbalancedness(Panel_JQ_Filtered)

Test <- is.pconsecutive(Fe_Model)
Test1 <- as.data.frame(Test)

#* -----------------------------------------------
#* -----------------------------------------------
#* [b] Identify whether to use fixed effects or random effects model:
#* -----------------------------------------------
#* -----------------------------------------------

#* I first carry out some tests on the models introduced in part c below, to try
#* to establish and justify the kind of model to build. First I carry out a Breusch and
#* Pagan (1980) (BP) Langrange multiplier test for unbalanced panels. This shows, quite
#* obviously, that the nature of the data is 

plmtest(Re_Model, effect = "individual", type = c("bp"))
plmtest(Fe_Model, effect = "individual", type = c("bp"))

#* Do a Hausman test. This shows one model is inconsistent so there's therefore a strong
#* case to use a fixed effects model:
phtest(Fe_Model, Re_Model)
pbgtest(Fe_Model)

#* -----------------------------------------------
#* -----------------------------------------------
#* [c] Regress life satisfaction and QoW index indicators:
#* -----------------------------------------------
#* -----------------------------------------------

Panel_JQ_Filtered$pidp <- as.character(Panel_JQ_Filtered$pidp)
Panel_JQ_Filtered$pidp <- as.factor(Panel_JQ_Filtered$pidp)

Fe_Model <- plm(DV_LifeSatisfaction ~ factor(year) + DV_Age_All_Num + factor(DV_Region_All) +
                  CF_DependentChildren_Desc + CF_NonWorkingHHMembers_Desc + 
                  CF_CaringResponsibilities_Desc +
                  Ind_EarningsSufficiency + Ind_EarningsEquity_Imp + 
                  Ind_Pension_Imp + 
                  Ind_ContinuousEmployment_Imp + Ind_CompositeSecurity_Imp + 
                  Ind_Autonomy_Imp + Ind_CollectiveVoice_Imp + 
                  Ind_Flexibility_Imp + Ind_ExcessiveHours_Imp + 
                  Ind_ManagerialDuties_Imp + Ind_ShortTermProspects_Imp + Ind_LongTermProspects +
                  Ind_WorkFatalities + Ind_WorkAccidents + Ind_WorkIllness, 
                data = Panel_JQ_Filtered, index = c("pidp", "year"), 
                effect = "individual", model = "fd")
summary(Fe_Model)

#* Note that forcing the intercept to zero has no effect on the estimates here, because the
#* intercept is already close to zero. It does change the estimates for job satisfaction. I
#* judge not to set the intercepts at zero.

#* Save data into table:
Tab1 <- Fe_Model |> broom::tidy()  |> print (n = 40) |> clipr::write_clip()

#* Then do for each individual variable w/o controls:
Fe_Model <- plm(DV_LifeSatisfaction ~ factor(year) + DV_Age_All_Num + factor(DV_Region_All) +
                  CF_DependentChildren_Desc + CF_NonWorkingHHMembers_Desc + 
                  CF_CaringResponsibilities_Desc +
                  Ind_WorkIllness, 
                data = Panel_JQ_Filtered, index = c("pidp", "year"), 
                effect = "individual", model = "fd")
summary(Fe_Model)

#* The random effects version of this model reports a higher R-squared and more significant
#* results. A broadly similar picture emerges as to the importance of particular elements,
#* such as autonomy, but much higher coefficients are recorded for some other variables - notably
#* workplace fatalities. There are reasons to reject this model because it is likely picking
#* up variation in individuals' valuations of :

# Re_Model <- plm(DV_LifeSatisfaction ~ factor(year) + DV_Age_All_Num + factor(DV_Region_All) +
#                   Ind_EarningsSufficiency + Ind_EarningsEquity_Imp + 
#                   Ind_Pension_Imp + 
#                   Ind_ContinuousEmployment_Imp + Ind_CompositeSecurity_Imp + 
#                   Ind_Autonomy_Imp + Ind_CollectiveVoice_Imp + 
#                   Ind_Flexibility_Imp + Ind_ExcessiveHours_Imp + 
#                   Ind_ManagerialDuties_Imp + Ind_ShortTermProspects_Imp + Ind_LongTermProspects +
#                   Ind_WorkFatalities + Ind_WorkAccidents + Ind_WorkIllness, 
#                 data = Panel_JQ, index = c("pidp", "year"), 
#                 effect = "individual", model = "random")
# summary(Re_Model)

#* -----------------------------------------------
#* -----------------------------------------------
#* [d] Regress job satisfaction and QoW index indicators:
#* -----------------------------------------------
#* -----------------------------------------------

Fe_Model <- plm(DV_JobSatisfaction ~ factor(year) + DV_Age_All + factor(DV_Region_All) +
                  CF_DependentChildren_Desc + CF_NonWorkingHHMembers_Desc + 
                  CF_CaringResponsibilities_Desc +
                  Ind_EarningsSufficiency + Ind_EarningsEquity_Imp + 
                  Ind_Pension_Imp + 
                  Ind_ContinuousEmployment_Imp + Ind_CompositeSecurity_Imp + 
                  Ind_Autonomy_Imp + Ind_CollectiveVoice_Imp + 
                  Ind_Flexibility_Imp + Ind_ExcessiveHours_Imp + 
                  Ind_ManagerialDuties_Imp + Ind_ShortTermProspects_Imp + Ind_LongTermProspects +
                  Ind_WorkFatalities + Ind_WorkAccidents + Ind_WorkIllness, 
                data = Panel_JQ, index = c("pidp", "year"), 
                effect = "individual", model = "fd")
summary(Fe_Model)

Tab1 <- Fe_Model |> broom::tidy()  |> print (n = 40) |> clipr::write_clip()

#* Then do for each individual variable w/o controls:
Fe_Model <- plm(DV_JobSatisfaction ~ factor(year) + DV_Age_All_Num + factor(DV_Region_All) +
                  CF_DependentChildren_Desc + CF_NonWorkingHHMembers_Desc + 
                  CF_CaringResponsibilities_Desc +
                  Ind_WorkIllness, 
                data = Panel_JQ_Filtered, index = c("pidp", "year"), 
                effect = "individual", model = "fd")
summary(Fe_Model)

#* -----------------------------------------------
#* -----------------------------------------------
#* [e] Apply hedonic weight 
#* -----------------------------------------------
#* -----------------------------------------------

#* To do this I just need to divide by 100 and times by the percentage weight. Note that consistent with
#* the equal weighting approach in the QoW index, :
Dat$variables$Ind_EarningsSufficiency_HE <- (Dat$variables$Ind_EarningsSufficiency_NAs / 100) * 6.49
Dat$variables$Ind_EarningsEquity_HE <- (Dat$variables$Ind_EarningsEquity_Imp / 100) * 7.61
Dat$variables$Ind_CompositeSecurity_HE <- (Dat$variables$Ind_CompositeSecurity_Imp / 100) * 32.06
Dat$variables$Ind_Autonomy_HE <- (Dat$variables$Ind_Autonomy_Imp / 100) * 31.75
Dat$variables$Ind_Flexibility_HE <- case_when(Dat$variables$DV_SelfEmployed == 0 ~ (Dat$variables$Ind_Flexibility_Imp / 100) * 9.36,
                                              Dat$variables$DV_SelfEmployed == 1 ~ 0)
Dat$variables$Ind_ExcessiveHours_HE <- case_when(Dat$variables$DV_SelfEmployed == 0 ~ (Dat$variables$Ind_ExcessiveHours_Imp / 100) * 9.86,
                                                 (Dat$variables$DV_SelfEmployed == 1 ~ (Dat$variables$Ind_ExcessiveHours_Imp / 100) * (9.36 + 9.86)))
Dat$variables$Ind_WorkAccidents_HE <- (Dat$variables$Ind_WorkAccidents / 100) * 2.87

#* Then add everything together:
Dat$variables$JQ_Index_HE_Score <- Dat$variables$Ind_EarningsSufficiency_HE + Dat$variables$Ind_EarningsEquity_HE + 
  Dat$variables$Ind_CompositeSecurity_HE + Dat$variables$Ind_Autonomy_HE + 
  Dat$variables$Ind_Flexibility_HE + Dat$variables$Ind_ExcessiveHours_HE + Dat$variables$Ind_WorkAccidents_HE

#* Make it the same size as the whole JQ index:
Dat$variables$JQ_Index_HE_Score <- Dat$variables$JQ_Index_HE_Score * 4
summary(JQ$variables$JQ_Index_HE_Score)
summary(Employees$variables$JQ_Index_HE_Score)
summary(SelfEmployed$variables$JQ_Index_AF_Score)

#* Trends suggest self-employed job quality declined, but inverts the difference in 
#* job quality between employees and the self-employed:
svyby(formula = ~JQ_Index_HE_Score, by = ~year,
      design = Employees, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

svyby(formula = ~JQ_Index_HE_Score, by = ~year,
      design = SelfEmployed, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

svyby(formula = ~JQ_Index_HE_Score, by = ~DV_Ethnicity_All,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

#* -----------------------------------------------
#* -----------------------------------------------
#* [f] Save data
#* -----------------------------------------------
#* -----------------------------------------------

#* Saved the above data as of [14.12.23]:
# saveRDS(Dat, file = "0 - Dat.RData")

#######################################################################################
########################### 2 - Frequency-based weighting: ############################
#######################################################################################

#* -----------------------------------------------
#* -----------------------------------------------
#* [a] Create statistics to inform weighting
#* -----------------------------------------------
#* -----------------------------------------------

#* First to give these indicators the same properties as they'd have in fuzzy set
#* theory. This is very simply achieved just by rescaling them to a 0-1 scale:
Dat$variables$Ind_EarningsSufficiency_NAs_Resc <- rescale(Dat$variables$Ind_EarningsSufficiency_NAs)
Dat$variables$Ind_EarningsEquity_Imp_Resc <- rescale(Dat$variables$Ind_EarningsEquity_Imp)
Dat$variables$Ind_Pension_Imp_Resc <- rescale(Dat$variables$Ind_Pension_Imp)
Dat$variables$Ind_ContinuousEmployment_Imp_Resc <- rescale(Dat$variables$Ind_ContinuousEmployment_Imp)
Dat$variables$Ind_CompositeSecurity_Imp_Resc <- rescale(Dat$variables$Ind_CompositeSecurity_Imp)
Dat$variables$Ind_Autonomy_Imp_Resc <- rescale(Dat$variables$Ind_Autonomy_Imp)
Dat$variables$Ind_CollectiveVoice_Imp_Resc <- rescale(Dat$variables$Ind_CollectiveVoice_Imp)
Dat$variables$Ind_Flexibility_Imp_Resc <- rescale(Dat$variables$Ind_Flexibility_Imp)
Dat$variables$Ind_ExcessiveHours_Imp_Resc <- rescale(Dat$variables$Ind_ExcessiveHours_Imp)
Dat$variables$Ind_ManagerialDuties_Imp_Resc <- rescale(Dat$variables$Ind_ManagerialDuties_Imp)
Dat$variables$Ind_ShortTermProspects_Imp_Resc <- rescale(Dat$variables$Ind_ShortTermProspects_Imp)
Dat$variables$Ind_LongTermProspects_Resc <- rescale(Dat$variables$Ind_LongTermProspects)
Dat$variables$Ind_WorkFatalities_Resc <- rescale(Dat$variables$Ind_WorkFatalities)
Dat$variables$Ind_WorkAccidents_Resc <- rescale(Dat$variables$Ind_WorkAccidents)
Dat$variables$Ind_WorkIllness_Resc <- rescale(Dat$variables$Ind_WorkIllness)

#* Get average scores on every indicator as at Wave 4:
svymean(~Ind_EarningsSufficiency_NAs_Resc, Wave4, na.rm = TRUE)
svymean(~Ind_EarningsEquity_Imp_Resc, Wave4, na.rm = TRUE)
svymean(~Ind_Pension_Imp_Resc, Wave4, na.rm = TRUE)
svymean(~Ind_ContinuousEmployment_Imp_Resc, Wave4, na.rm = TRUE)
svymean(~Ind_CompositeSecurity_Imp_Resc, Wave4, na.rm = TRUE)
svymean(~Ind_Autonomy_Imp_Resc, Wave4, na.rm = TRUE)
svymean(~Ind_CollectiveVoice_Imp_Resc, Wave4, na.rm = TRUE)
svymean(~Ind_Flexibility_Imp_Resc, Wave4, na.rm = TRUE)
svymean(~Ind_ExcessiveHours_Imp_Resc, Wave4, na.rm = TRUE)
svymean(~Ind_ManagerialDuties_Imp_Resc, Wave4, na.rm = TRUE)
svymean(~Ind_ShortTermProspects_Imp_Resc, Wave4, na.rm = TRUE)
svymean(~Ind_LongTermProspects_Resc, Wave4, na.rm = TRUE)
svymean(~Ind_WorkFatalities_Resc, Wave4, na.rm = TRUE)
svymean(~Ind_WorkAccidents_Resc, Wave4, na.rm = TRUE)
svymean(~Ind_WorkIllness_Resc, Wave4, na.rm = TRUE)

#* -----------------------------------------------
#* -----------------------------------------------
#* [b] Apply the weights
#* -----------------------------------------------
#* -----------------------------------------------

#* Apply the weights:
Dat$variables$Ind_EarningsSufficiency_FR <- (Dat$variables$Ind_EarningsSufficiency_NAs / 100) * 5.62
Dat$variables$Ind_EarningsEquity_FR <- (Dat$variables$Ind_EarningsEquity_Imp / 100) * 6.32
Dat$variables$Ind_Pension_FR <- (Dat$variables$Ind_Pension_Imp / 100) * 5.67
Dat$variables$Ind_ContinuousEmployment_FR <- (Dat$variables$Ind_ContinuousEmployment_Imp / 100) * 7.02
Dat$variables$Ind_CompositeSecurity_FR <- (Dat$variables$Ind_CompositeSecurity_Imp / 100) * 8.29
Dat$variables$Ind_Autonomy_FR <- (Dat$variables$Ind_Autonomy_Imp / 100) * 7.06
Dat$variables$Ind_CollectiveVoice_FR <- (Dat$variables$Ind_CollectiveVoice_Imp / 100) * 5.42 
Dat$variables$Ind_Flexibility_FR <- case_when(Dat$variables$DV_SelfEmployed == 0 ~ (Dat$variables$Ind_Flexibility_Imp / 100) * 5.88,
                                              Dat$variables$DV_SelfEmployed == 1 ~ 0)
Dat$variables$Ind_ExcessiveHours_FR <- case_when(Dat$variables$DV_SelfEmployed == 0 ~ (Dat$variables$Ind_ExcessiveHours_Imp / 100) * 6.61,
                                                 (Dat$variables$DV_SelfEmployed == 1 ~ (Dat$variables$Ind_ExcessiveHours_Imp / 100) * (6.61 + 5.88)))
Dat$variables$Ind_ManagerialDuties_FR <- (Dat$variables$Ind_ManagerialDuties_Imp / 100) * 5.10
Dat$variables$Ind_ShortTermProspects_FR <- (Dat$variables$Ind_ShortTermProspects_Imp / 100) * 5.11
Dat$variables$Ind_LongTermProspects_FR <- (Dat$variables$Ind_LongTermProspects / 100) * 8.15
Dat$variables$Ind_WorkFatalities_FR <- (Dat$variables$Ind_WorkFatalities / 100) * 11.36
Dat$variables$Ind_WorkAccidents_FR <- (Dat$variables$Ind_WorkAccidents / 100) * 6.27
Dat$variables$Ind_WorkIllness_FR <- (Dat$variables$Ind_WorkIllness / 100) * 6.14

#* Sum together:
Dat$variables$JQ_Index_FR_Score <- Dat$variables$Ind_EarningsSufficiency_FR + Dat$variables$Ind_EarningsEquity_FR +
  Dat$variables$Ind_Pension_FR + Dat$variables$Ind_ContinuousEmployment_FR + Dat$variables$Ind_CompositeSecurity_FR + 
  Dat$variables$Ind_Autonomy_FR + Dat$variables$Ind_CollectiveVoice_FR + Dat$variables$Ind_Flexibility_FR + 
  Dat$variables$Ind_ExcessiveHours_FR + Dat$variables$Ind_ManagerialDuties_FR + Dat$variables$Ind_ShortTermProspects_FR +
  Dat$variables$Ind_LongTermProspects_FR + Dat$variables$Ind_WorkFatalities_FR + Dat$variables$Ind_WorkAccidents_FR +
  Dat$variables$Ind_WorkIllness_FR

#* Times by 4 so it's on a 0-8 scale: 
# Dat$variables$JQ_Index_FR_Score <- Dat$variables$JQ_Index_FR_Score * 4

#* Trends show self-employed job quality still declined, but it inverts the difference
#* in job quality between employees and the self-employed:
svyby(formula = ~JQ_Index_FR_Score, by = ~year,
      design = Employees, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

svyby(formula = ~JQ_Index_FR_Score, by = ~year,
      design = SelfEmployed, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

#* -----------------------------------------------
#* -----------------------------------------------
#* [c] Save data
#* -----------------------------------------------
#* -----------------------------------------------

#* Saved the above data as of [03.12.23]:
# saveRDS(Dat, file = "0 - Dat.RData")

#######################################################################################
############################ 3 - Statistical weighting: ###############################
#######################################################################################

#* Download packages:
library(corrr)
library(ggcorrplot)
library(FactoMineR)
library(Factoshiny)
library(plotly)
# library(ggbiplot)
library(factoextra)

#* -----------------------------------------------
#* -----------------------------------------------
#* [a] Prepare the data
#* -----------------------------------------------
#* -----------------------------------------------

#* First create an adjusted version of the flexibility indicator with the self-employed
#* given a 'dummy' code: 
Dat$variables$Ind_Flexibility_Imp_SEAdj <- case_when(Dat$variables$DV_SelfEmployed == 1 ~ 2,
                                                            TRUE ~ as.numeric(as.character(Dat$variables$Ind_Flexibility_Imp))) 
length(which(is.na(JQ$variables$Ind_Flexibility_Imp_SEAdj)))

#* Take out of survey design and filter only to the indicators I need: 
JQ_PCA <- JQ$variables |> 
  select(Ind_EarningsSufficiency, Ind_EarningsEquity_Imp,
         Ind_Pension_Imp,
         Ind_ContinuousEmployment_Imp, Ind_CompositeSecurity_Imp,
         Ind_Autonomy_Imp, Ind_CollectiveVoice_Imp,
         Ind_Flexibility_Imp_SEAdj, Ind_ExcessiveHours_Imp,
         Ind_ManagerialDuties_Imp, Ind_ShortTermProspects_Imp, Ind_LongTermProspects,
         Ind_WorkFatalities, Ind_WorkAccidents, Ind_WorkIllness)

#* There are some remaining NAs in the data, for both (a) any who are missing for employee and self-employed
#* where the indicator is contingent on knowing whether they are and (b) the four SIC and SOC-based indicators:
colSums(is.na(JQ_PCA))

#* Some things need to be done beforehand to make the PCA work effectively. First, any indicators
#* which have the same values across the board need removing. The self-employed are automatically
#* coded the worst scores for continuous employment and collective voice, so this needs removing
#* from the index (see above). Second, any NAs need to be removed through listwise deletion,
#* as any indicators which still have NAs (namely the health and safety and long-term prospects
#* indicators) will not be analysed:
JQ_PCA <- JQ_PCA |> drop_na()

#* Rename columns:
JQ_PCA <- JQ_PCA |> rename(Earnings.Sufficiency = Ind_EarningsSufficiency,
                                               Earnings.Equity = Ind_EarningsEquity_Imp,
                                               Pension = Ind_Pension_Imp,
                                               Continuous.Employment = Ind_ContinuousEmployment_Imp,
                                               Composite.Security = Ind_CompositeSecurity_Imp,
                                               Autonomy = Ind_Autonomy_Imp,
                                               Collective.Voice = Ind_CollectiveVoice_Imp,
                                               Flexibility = Ind_Flexibility_Imp_SEAdj,
                                               Excessive.Hours = Ind_ExcessiveHours_Imp,
                                               Managerial.Duties = Ind_ManagerialDuties_Imp,
                                               Short.Term.Prospects = Ind_ShortTermProspects_Imp,
                                               Long.Term.Prospects = Ind_LongTermProspects,
                                               Work.Fatalities = Ind_WorkFatalities,
                                               Work.Accidents = Ind_WorkAccidents,
                                               Work.Illnesses = Ind_WorkIllness)

#* Normalise the data along a standard scale:
JQ_PCA_Scale <- scale(JQ_PCA)
summary(JQ_PCA_Scale)

#* -----------------------------------------------
#* -----------------------------------------------
#* [b] Correlation matrix
#* -----------------------------------------------
#* -----------------------------------------------

#* Note that the default correlation matrix is Pearson. This isn't appropriate for this kind
#* of data so I force it to Spearman:

corr_matrix <- cor(JQ_PCA_Scale, method = "spearman")
ggcorrplot(corr_matrix, show.legend = FALSE, lab = TRUE, type = "upper")

#* -----------------------------------------------
#* -----------------------------------------------
#* [c] Do PCA
#* -----------------------------------------------
#* -----------------------------------------------

pca_jq <- princomp(corr_matrix)
summary(pca_jq)

#* -----------------------------------------------
#* -----------------------------------------------
#* [d] Create a scree plot
#* -----------------------------------------------
#* -----------------------------------------------

#* Complementing the above, this shows that essentialy 9 principal components
#* should be retained:

fviz_eig(pca_jq, addlabels = TRUE)

#* -----------------------------------------------
#* -----------------------------------------------
#* [e] Show contribution of variables to each component
#* -----------------------------------------------
#* -----------------------------------------------

#* First present a loading matrix. 

#* 90% of the variation is explained by the first 8 components. The 
#* below code shows how these relate to the indicators themselves:

Tab <- pca_jq$loadings[, 1:8] |> as.data.frame()

#* As can be seen, there's pretty good representation of many of the
#* indicators in each of these components, both for employees and (even moreso)
#* self-employed. The weakest association is for Collective Voice for employees,
#* and to a lesser extent Flexibility. But even in these cases, there is fairly
#* strong representation. 

#* Then show a visualisation of squared cosines to show the contribution of 
#* each variable to the selected principal components.

#* This shows that there is good-quality representation of each of the indicators
#* in the principal components:
fviz_cos2(pca_employees, choice = "var", axes = 1:8)
fviz_cos2(pca_selfemployed, choice = "var", axes = 1:8)

#* -----------------------------------------------
#* -----------------------------------------------
#* [f] Biplot of the variables with respect to the principal components
#* -----------------------------------------------
#* -----------------------------------------------

#* Overall this reinforces the encouraging picture, with few indicators
#* close to the centre. Again this is especially the case for the 
#* self-employed:
fviz_pca_var(pca_employees, col.var = "black")
fviz_pca_var(pca_selfemployed, col.var = "black")

#* -----------------------------------------------
#* -----------------------------------------------
#* [g] Combine biplot with cos2
#* -----------------------------------------------
#* -----------------------------------------------

#* This function doesn't seem to be able to select the number of components
#* to visualise, so it shows an artificially low level of variance by 
#* selecting too few components:

fviz_pca_var(pca_employees, col.var = "cos2",
             gradient.cols = c("red", "orange", "green"),
             repel = TRUE)

fviz_pca_var(pca_selfemployed, col.var = "cos2",
             gradient.cols = c("red", "orange", "green"),
             repel = TRUE)

#* REFERENCES:
#* [1] RPubs (2020), 'PCA for survey analysis', 25 April 2020,
#* https://rpubs.com/Shreyansh_Shivam/604562 
#* [2] DataCamp (2023), 'Principal component analysis in R tutorial', updated February 2023, 
#* https://www.datacamp.com/tutorial/pca-analysis-r

#* -----------------------------------------------
#* -----------------------------------------------
#* [h] Apply the weights
#* -----------------------------------------------
#* -----------------------------------------------

#* Apply the weights:
Dat$variables$Ind_EarningsSufficiency_PCA <- (Dat$variables$Ind_EarningsSufficiency_NAs / 100) * 14.7
Dat$variables$Ind_EarningsEquity_PCA <- (Dat$variables$Ind_EarningsEquity_Imp / 100) * 12.1
Dat$variables$Ind_Pension_PCA <- (Dat$variables$Ind_Pension_Imp / 100) * 7.5
Dat$variables$Ind_ContinuousEmployment_PCA <- (Dat$variables$Ind_ContinuousEmployment_Imp / 100) * 6.3
Dat$variables$Ind_CompositeSecurity_PCA <- (Dat$variables$Ind_CompositeSecurity_Imp / 100) * 4.3
Dat$variables$Ind_Autonomy_PCA <- (Dat$variables$Ind_Autonomy_Imp / 100) * 6.0
Dat$variables$Ind_CollectiveVoice_PCA <- (Dat$variables$Ind_CollectiveVoice_Imp / 100) * 7.0
Dat$variables$Ind_Flexibility_PCA <- case_when(Dat$variables$DV_SelfEmployed == 0 ~ (Dat$variables$Ind_Flexibility_Imp / 100) * 5.5,
                                               Dat$variables$DV_SelfEmployed == 1 ~ 0)
Dat$variables$Ind_ExcessiveHours_PCA <- case_when(Dat$variables$DV_SelfEmployed == 0 ~ (Dat$variables$Ind_ExcessiveHours_Imp / 100) * 1.4,
                                                  (Dat$variables$DV_SelfEmployed == 1 ~ (Dat$variables$Ind_ExcessiveHours_Imp / 100) * (1.4 + 5.5)))
Dat$variables$Ind_ManagerialDuties_PCA <- (Dat$variables$Ind_ManagerialDuties_Imp / 100) * 9.0
Dat$variables$Ind_ShortTermProspects_PCA <- (Dat$variables$Ind_ShortTermProspects_Imp / 100) * 4.7
Dat$variables$Ind_LongTermProspects_PCA <- (Dat$variables$Ind_LongTermProspects / 100) * 5.8
Dat$variables$Ind_WorkFatalities_PCA <- (Dat$variables$Ind_WorkFatalities / 100) * 4.5
Dat$variables$Ind_WorkAccidents_PCA <- (Dat$variables$Ind_WorkAccidents / 100) * 3.7
Dat$variables$Ind_WorkIllness_PCA <- (Dat$variables$Ind_WorkIllness / 100) * 7.5

#* Sum together:
Dat$variables$JQ_Index_PCA_Score <- Dat$variables$Ind_EarningsSufficiency_PCA + Dat$variables$Ind_EarningsEquity_PCA +
  Dat$variables$Ind_Pension_PCA + Dat$variables$Ind_ContinuousEmployment_PCA + Dat$variables$Ind_CompositeSecurity_PCA + 
  Dat$variables$Ind_Autonomy_PCA + Dat$variables$Ind_CollectiveVoice_PCA + Dat$variables$Ind_Flexibility_PCA + 
  Dat$variables$Ind_ExcessiveHours_PCA + Dat$variables$Ind_ManagerialDuties_PCA + Dat$variables$Ind_ShortTermProspects_PCA +
  Dat$variables$Ind_LongTermProspects_PCA + Dat$variables$Ind_WorkFatalities_PCA + Dat$variables$Ind_WorkAccidents_PCA +
  Dat$variables$Ind_WorkIllness_PCA

#* Times by 4 so it's on a 0-8 scale: 
# Dat$variables$JQ_Index_PCA_Score <- Dat$variables$JQ_Index_PCA_Score * 4

#* Trends show self-employed job quality still declined, but it inverts the difference
#* in job quality between employees and the self-employed:
svyby(formula = ~JQ_Index_PCA_Score, by = ~year,
      design = Employees, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

svyby(formula = ~JQ_Index_PCA_Score, by = ~year,
      design = SelfEmployed, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

#* -----------------------------------------------
#* -----------------------------------------------
#* [i] Save data
#* -----------------------------------------------
#* -----------------------------------------------

#* Saved the above data as of [18.12.23]:
# saveRDS(Dat, file = "0 - Dat.RData")
