
#######################################################################################
################ 1 - Cultural and human capital - Create indicators ###################
#######################################################################################

#* ----------------------------------------------------------------
#* -------------- [CC.1 - Highest Qualification:]
#* ----------------------------------------------------------------

#* For this, I create a 4-level variable with the following scores:
#* [0] No Qualifications
#* [0.33] GCSE and "Other", or equivalent
#* [0.66] A-Level or equivalent
#* [1] Degree, Other Higher Degree, or equivalent

#* I face a choice over how to treat those who report "other qualifications." Based 
#* on Understanding Society's answers to the user support forum, "other qualifications" 
#* seems to mostly consist of various vocational qualifications, old GCSE equivalent 
#* (ie CSEs). Whilst some of these will be higher than GCSE-equivalent, they will 
#* predominantly not be, and they are therefore coded the same as GCSEs.[1]  

#* Further note that this includes the equivalent qualifications of people from the
#* IEMB who obtained their qualifications outside the UK. It is a derived variable which
#* combines, from various sources, the data on the highest qualifications of respondents,
#* with the original questions answered tailored based on whether they said they obtained
#* their highest qualification in the UK, or abroad.[2]

Dat$variables$CS_CC1_HighestQual <- case_when(Dat$variables$hiqual_dv == 9 ~ 0,
                                              (Dat$variables$hiqual_dv ==  4 | Dat$variables$hiqual_dv == 5) ~ 0.33,
                                              Dat$variables$hiqual_dv == 3 ~ 0.66,
                                              (Dat$variables$hiqual_dv == 1 | Dat$variables$hiqual_dv == 2) ~ 1)

#* Data check [14.04.24]: 
svytable(~CS_CC1_HighestQual + year, Dat) |> prop.table(2)

#* REFERENCES:
#* [1] Understanding Society User Support Forum (2022), 
#* 'Support Ticket #1723: Other Qualifications Category in hiqual_dv', 7 July 2022,
#* https://iserredex.essex.ac.uk/support/issues/1723
#* [2] Understanding Society User Support Forum (2022), 
#* 'Support Ticket #1832: 'Highest qualification variables - query about correct variable
#* and coverage of non-UK qualifications', 16 December 2022,
#* https://iserredex.essex.ac.uk/support/issues/1832 
  
#* ----------------------------------------------------------------
#* -------------- [CC.2 - Perceived self-efficacy:]
#* ----------------------------------------------------------------

#* For this I use the Liekert scale of the General Health Questionnaire (GHQ). There are 
#* a large number of missings for this in earlier waves but there are far fewer in later waves.
#* I start by adjusting it to recode the missings to NAs. Note that higher values = more distressed so
#* this will need to be inverted too:
xtabs(~scghq1_dv + year, Dat)
Dat$variables$scghq1_dv_adj <- replace(Dat$variables$scghq1_dv, Dat$variables$scghq1_dv %in% c(-9, -8, -7), NA)
Dat$variables$scghq1_dv_adj <- case_when(TRUE ~ as.numeric(as.character(Dat$variables$scghq1_dv_adj)))
Dat$variables$scghq1_dv_adj_rescaled <- rescale(Dat$variables$scghq1_dv_adj, to = c(0,1))

#* Create the indicator. Note that it's not possible to use rescale on Haven labelled variables, so in the 
#* case_when statement above I remove the labels from the variable to make the rescale work:
Dat$variables$CS_CC2_PerceivedSelfEfficacy <- item.reverse(Dat$variables$scghq1_dv_adj_rescaled, min = 0, max = 1)

#* Data check [14.04.24]:
svytable(~CS_CC2_PerceivedSelfEfficacy + year, Dat)
svytable(~scghq1_dv_adj + year, Dat)

#* ----------------------------------------------------------------
#* -------------- [CC.3 - Civil society participation (Waves 6 and 12 only):]
#* ----------------------------------------------------------------

#* To create this indicator I combine data on sixteen sets of indicators. These are in
#* mirrored pairs for both the online/in-person survey (orga1-16) and the telephone survey (orgat1-16). 
#* Crosstabs show any inapplicables in either have recorded data for the other, but (a) the -10s and -7s
#* are completely consistent across both pairs and (b) being -8 doesn't mean you won't answer don't know (-1)
#* or would refuse to answer the question (-1): 
xtabs(~orga1 + orgat1 + year, Dat)
xtabs(~orga2 + orgat2 + year, Dat)
xtabs(~orga3 + orgat3 + year, Dat)
xtabs(~orga4 + orgat4 + year, Dat)
xtabs(~orga5 + orgat5 + year, Dat)
xtabs(~orga6 + orgat6 + year, Dat)
xtabs(~orga7 + orgat7 + year, Dat)
xtabs(~orga8 + orgat8 + year, Dat)
xtabs(~orga9 + orgat9 + year, Dat)
xtabs(~orga10 + orgat10 + year, Dat)
xtabs(~orga11 + orgat11 + year, Dat)
xtabs(~orga12 + orgat12 + year, Dat)
xtabs(~orga13 + orgat13 + year, Dat)
xtabs(~orga14 + orgat14 + year, Dat)
xtabs(~orga15 + orgat15 + year, Dat)
xtabs(~orga16 + orgat16 + year, Dat)

#* This can be solved quite simply through the following case_when statements. Anything that doesn't fit these
#* criteria is automatically coded NA by virtue of exclusion from the case_when statement, which is correct:
Dat$variables$OrgaOrgat1 <- case_when(Dat$variables$orga1 == 1 ~ 1,
                                      Dat$variables$orgat1 == 1 ~ 1, 
                                      Dat$variables$orga1 == 0 ~ 0, 
                                      Dat$variables$orgat1 == 0 ~ 0)
Dat$variables$OrgaOrgat2 <- case_when(Dat$variables$orga2 == 1 ~ 1,
                                      Dat$variables$orgat2 == 1 ~ 1, 
                                      Dat$variables$orga2 == 0 ~ 0, 
                                      Dat$variables$orgat2 == 0 ~ 0)
Dat$variables$OrgaOrgat3 <- case_when(Dat$variables$orga3 == 1 ~ 1,
                                      Dat$variables$orgat3 == 1 ~ 1, 
                                      Dat$variables$orga3 == 0 ~ 0, 
                                      Dat$variables$orgat3 == 0 ~ 0)
Dat$variables$OrgaOrgat4 <- case_when(Dat$variables$orga4 == 1 ~ 1,
                                      Dat$variables$orgat4 == 1 ~ 1, 
                                      Dat$variables$orga4 == 0 ~ 0, 
                                      Dat$variables$orgat4 == 0 ~ 0)
Dat$variables$OrgaOrgat5 <- case_when(Dat$variables$orga5 == 1 ~ 1,
                                      Dat$variables$orgat5 == 1 ~ 1, 
                                      Dat$variables$orga5 == 0 ~ 0, 
                                      Dat$variables$orgat5 == 0 ~ 0)
Dat$variables$OrgaOrgat6 <- case_when(Dat$variables$orga6 == 1 ~ 1,
                                      Dat$variables$orgat6 == 1 ~ 1, 
                                      Dat$variables$orga6 == 0 ~ 0, 
                                      Dat$variables$orgat6 == 0 ~ 0)
Dat$variables$OrgaOrgat7 <- case_when(Dat$variables$orga7 == 1 ~ 1,
                                      Dat$variables$orgat7 == 1 ~ 1, 
                                      Dat$variables$orga7 == 0 ~ 0, 
                                      Dat$variables$orgat7 == 0 ~ 0)
Dat$variables$OrgaOrgat8 <- case_when(Dat$variables$orga8 == 1 ~ 1,
                                      Dat$variables$orgat8 == 1 ~ 1, 
                                      Dat$variables$orga8 == 0 ~ 0, 
                                      Dat$variables$orgat8 == 0 ~ 0)
Dat$variables$OrgaOrgat9 <- case_when(Dat$variables$orga9 == 1 ~ 1,
                                      Dat$variables$orgat9 == 1 ~ 1, 
                                      Dat$variables$orga9 == 0 ~ 0, 
                                      Dat$variables$orgat9 == 0 ~ 0)
Dat$variables$OrgaOrgat10 <- case_when(Dat$variables$orga10 == 1 ~ 1,
                                      Dat$variables$orgat10 == 1 ~ 1, 
                                      Dat$variables$orga10 == 0 ~ 0, 
                                      Dat$variables$orgat10 == 0 ~ 0)
Dat$variables$OrgaOrgat11 <- case_when(Dat$variables$orga11 == 1 ~ 1,
                                      Dat$variables$orgat11 == 1 ~ 1, 
                                      Dat$variables$orga11 == 0 ~ 0, 
                                      Dat$variables$orgat11 == 0 ~ 0)
Dat$variables$OrgaOrgat12 <- case_when(Dat$variables$orga12 == 1 ~ 1,
                                      Dat$variables$orgat12 == 1 ~ 1, 
                                      Dat$variables$orga12 == 0 ~ 0, 
                                      Dat$variables$orgat12 == 0 ~ 0)
Dat$variables$OrgaOrgat13 <- case_when(Dat$variables$orga13 == 1 ~ 1,
                                       Dat$variables$orgat13 == 1 ~ 1, 
                                       Dat$variables$orga13 == 0 ~ 0, 
                                       Dat$variables$orgat13 == 0 ~ 0)
Dat$variables$OrgaOrgat14 <- case_when(Dat$variables$orga14 == 1 ~ 1,
                                       Dat$variables$orgat14 == 1 ~ 1, 
                                       Dat$variables$orga14 == 0 ~ 0, 
                                       Dat$variables$orgat14 == 0 ~ 0)
Dat$variables$OrgaOrgat15 <- case_when(Dat$variables$orga15 == 1 ~ 1,
                                       Dat$variables$orgat15 == 1 ~ 1, 
                                       Dat$variables$orga15 == 0 ~ 0, 
                                       Dat$variables$orgat15 == 0 ~ 0)
Dat$variables$OrgaOrgat16 <- case_when(Dat$variables$orga16 == 1 ~ 1,
                                       Dat$variables$orgat16 == 1 ~ 1, 
                                       Dat$variables$orga16 == 0 ~ 0, 
                                       Dat$variables$orgat16 == 0 ~ 0)

#* Data check [14.04.24]. The most commons wants are sports clubs, religions/church orgs, voluntary services
#* groups and "other":
xtabs(~OrgaOrgat1 + year, Dat)
xtabs(~OrgaOrgat2 + year, Dat)
xtabs(~OrgaOrgat3 + year, Dat)
xtabs(~OrgaOrgat4 + year, Dat)
xtabs(~OrgaOrgat5 + year, Dat)
xtabs(~OrgaOrgat6 + year, Dat)
xtabs(~OrgaOrgat7 + year, Dat)
xtabs(~OrgaOrgat8 + year, Dat)
xtabs(~OrgaOrgat9 + year, Dat)
xtabs(~OrgaOrgat10 + year, Dat)
xtabs(~OrgaOrgat11 + year, Dat)
xtabs(~OrgaOrgat12 + year, Dat)
xtabs(~OrgaOrgat13 + year, Dat)
xtabs(~OrgaOrgat14 + year, Dat)
xtabs(~OrgaOrgat15 + year, Dat)
xtabs(~OrgaOrgat16 + year, Dat)

#* I then add these together:
Dat$variables$OrgaOrgatSum <- Dat$variables$OrgaOrgat1 + Dat$variables$OrgaOrgat2 + Dat$variables$OrgaOrgat3 +
  Dat$variables$OrgaOrgat4 + Dat$variables$OrgaOrgat5 + Dat$variables$OrgaOrgat6 + Dat$variables$OrgaOrgat7 + 
  Dat$variables$OrgaOrgat8 + Dat$variables$OrgaOrgat9 + Dat$variables$OrgaOrgat10 + Dat$variables$OrgaOrgat11 +
  Dat$variables$OrgaOrgat12 + Dat$variables$OrgaOrgat13 + Dat$variables$OrgaOrgat14 + Dat$variables$OrgaOrgat15 +
  Dat$variables$OrgaOrgat16 
summary(Dat$variables$OrgaOrgatSum)

#* I then recode so that anyone involved with two or more groups is given a max value of 2:
xtabs(~OrgaOrgatSum + year, Dat)
Dat$variables$CS_CC3_CivilParticipation <- case_when(Dat$variables$OrgaOrgatSum >= 2 ~ 1, 
                                            Dat$variables$OrgaOrgatSum == 1 ~ 0.5,
                                            Dat$variables$OrgaOrgatSum == 0 ~ 0)
svytable(~CS_CC3_CivilParticipation + year, Dat) |> prop.table(2)

#######################################################################################
################################# 2 - Save Data #######################################
#######################################################################################

#* Saved the above as of [14.04.24]:
# saveRDS(Dat, file = "0 - Dat.RData")
