
#######################################################################################
#######################################################################################
############################ 1 - Children and Childcare ###############################
#######################################################################################
#######################################################################################

#* ----------------------------------------------------------------
#* -------------- [CF.1 - Dependent children:]
#* ----------------------------------------------------------------

#* Distinguishes between the following. This is designed to reflect the declining marginal effect of having more children, and the 
#* distribution in the data (where in practice there are very few families with more than 3 dependent children):
#* [0] Zero dependent children;
#* [0.25] 1 dependent child;
#* [0.5] 2 dependent children;
#* [0.75] 3 dependent children;
#* [1] 4 or more dependent children

# svyby(formula = ~JQ_Index_AF_Score, by = ~ndepchl_dv,
#       design = JQ,
#       FUN = svymean,
#       na.rm = TRUE,
#       row.names = FALSE)

Dat$variables$CF_DependentChildren <- case_when(Dat$variables$ndepchl_dv == 0 ~ 0,
                                                Dat$variables$ndepchl_dv == 1 ~ 0.25,
                                                Dat$variables$ndepchl_dv == 2 ~  0.5,
                                                Dat$variables$ndepchl_dv == 3 ~ 0.75,
                                                Dat$variables$ndepchl_dv >= 4 ~ 1)

#* There are missing values which are turned to NAs through this process [20.08.24]: 
# Dat$variables$CF_DependentChildren <- case_when(Dat$variables$ndepchl_dv == 0 ~ 0,
#                                                 Dat$variables$ndepchl_dv == 1 ~ 0.25,
#                                                 Dat$variables$ndepchl_dv == 2 ~  0.5,
#                                                 Dat$variables$ndepchl_dv == 3 ~ 0.75,
#                                                 Dat$variables$ndepchl_dv >= 4 ~ 1,
#                                                 TRUE ~ -1)
# xtabs(~ndepchl_dv + year, Dat)
# xtabs(~CF_DependentChildren + year, Dat)

#* At this point I also create a variable which converts any missing data on dependent children to NA, as this helps with
#* future analysis:
Dat$variables$ndepchl_dv_NAs <- case_when(Dat$variables$ndepchl_dv >= 0 ~ as.numeric(Dat$variables$ndepchl_dv))

#* ----------------------------------------------------------------
#* -------------- [CF.2 - Childcare:]
#* ----------------------------------------------------------------

#* This variable has a lot of 'missing' values. The missing values consist entirely of people with dependent children who don't
#* report having childcare. Where these are missing I assume that it's because the respondent isn't directly responsible for the 
#* children and so wasn't asked this question - i.e. it's their dependent child, but someone else is responsible for the care and 
#* so the duty of caring for the child doesn't fall so heavily on them:
Dat$variables$CF_Childcare <- case_when(Dat$variables$ndepchl_dv <= 0 ~ 0, 
                                        Dat$variables$ndepchl_dv > 0 & Dat$variables$ccare == 1 ~ 0.5,
                                        Dat$variables$ndepchl_dv > 0 & (Dat$variables$ccare != 1 & Dat$variables$ccare != 2) ~ 0.5, #* This is an assumption (asked USoc - [20.08.24]); 
                                        Dat$variables$ndepchl_dv > 0 & Dat$variables$ccare == 2 & (Dat$variables$ccwork == 1 | Dat$variables$ccwork == 2) ~ 0.5,
                                        Dat$variables$ndepchl_dv > 0 & Dat$variables$ccare == 2 & (Dat$variables$ccwork != 1 | Dat$variables$ccwork != 2) ~ 1)
xtabs(~CF_Childcare + ndepchl_dv + year, Dat)
xtabs(~CF_Childcare + nkids05 + year, Dat)
xtabs(~CF_Childcare + year, Dat)

#* To test this [20.08], overwhelmingly the missing respondents split (80/40) towards men. The mean QoW score of this groupis also virtually identical (within the margin of 
#* error) of the 0.5 group:
# Dat$variables$CF_Childcare <- case_when(Dat$variables$ndepchl_dv <= 0 ~ 0,
#                                         Dat$variables$ndepchl_dv > 0 & Dat$variables$ccare == 1 ~ 0.5,
#                                         Dat$variables$ndepchl_dv > 0 & Dat$variables$ccare == 2 & (Dat$variables$ccwork == 1 | Dat$variables$ccwork == 2) ~ 0.5,
#                                         Dat$variables$ndepchl_dv > 0 & Dat$variables$ccare == 2 & (Dat$variables$ccwork != 1 | Dat$variables$ccwork != 2) ~ 1,
#                                         TRUE ~ -1)
# xtabs(~CF_Childcare + ndepchl_dv, JQ)
# xtabs(~CF_Childcare + sex_dv, Dat) |> prop.table(1) |> round(3)
# svyby(formula = ~JQ_Index_AF_Score, by = ~CF_Childcare,
#       design = JQ, 
#       FUN = svymean, 
#       na.rm = TRUE, 
#       row.names = FALSE)

#######################################################################################
#######################################################################################
################################ 2 - Care and Support #################################
#######################################################################################
#######################################################################################

#* ----------------------------------------------------------------
#* -------------- [CF.3 - Unpaid Care:]
#* ----------------------------------------------------------------

#* First create a more descriptive caring responsibilities indicator:
Dat$variables$CF_CaringResponsibilities_Desc <- case_when(Dat$variables$aidhh == 1 | Dat$variables$aidxhh == 1 ~ 1,
                                                          Dat$variables$aidhh == 2 & Dat$variables$aidxhh == 2 ~ 0,
                                                          TRUE ~ 0)

#* The only missing values around hours of unpaid care occur in the Wave 6 IEMB sample. The rest align entirely
#* with the population of people with within- or outside- household caring responsibilities:
# xtabs(~CF_CaringResponsibilities_Desc + aidhrs, Dat)
# 
# svyby(formula = ~JQ_Index_AF_Score, by = ~aidhrs,
#       design = JQ,
#       FUN = svymean,
#       na.rm = TRUE,
#       row.names = FALSE)
  
Dat$variables$CF_UnpaidCare <- case_when(Dat$variables$CF_CaringResponsibilities_Desc == 0 ~ 0, 
                                         Dat$variables$aidhrs == 1 ~ 0.25, 
                                         Dat$variables$aidhrs == 2 ~ 0.5,
                                         (Dat$variables$aidhrs == 3 | Dat$variables$aidhrs == 4 | Dat$variables$aidhrs == 8 | Dat$variables$aidhrs == 9) ~ 0.75,
                                         (Dat$variables$aidhrs == 5 | Dat$variables$aidhrs == 6 | Dat$variables$aidhrs == 7) ~ 1)

#* ----------------------------------------------------------------
#* -------------- [CF.4 - Adults with long-standing illness, impairment or disability in HH:]
#* ----------------------------------------------------------------

#* First create both individual and household-level long-standing illness variable. The cross-tabs show that 
#* everyone who reports a long-standing illness themselves has at least one other HH member with a long-standing 
#* illness: 
Dat$variables$HHCF_LongStandingIllness_Dummy <- case_when(Dat$variables$HHCF_LongStandingIllness_Desc >= 1 ~ 1, Dat$variables$HHCF_LongStandingIllness_Desc == 0 ~ 0)
Dat$variables$CF_LongStandingIllness <- case_when(Dat$variables$health == 1 ~ 1,
                                                  Dat$variables$health == 2 ~ 0)
xtabs(~HHCF_LongStandingIllness_Desc + CF_LongStandingIllness, Dat)

#* Create variable: 
Dat$variables$CF_OtherHHIllness <- Dat$variables$HHCF_LongStandingIllness_Desc - Dat$variables$CF_LongStandingIllness
Dat$variables$CF_OtherHHIllness_dummy <- case_when(Dat$variables$CF_OtherHHIllness > 0 ~ 1, Dat$variables$CF_OtherHHIllness == 0 ~ 0)

xtabs(~CF_OtherHHIllness + year, Dat)

Dat$variables$CF_OtherHHIllness <- case_when(Dat$variables$CF_OtherHHIllness == 0 ~ 0, 
                                             Dat$variables$CF_OtherHHIllness == 1 ~ 0.5,
                                             Dat$variables$CF_OtherHHIllness >= 2 ~ 1)

svyby(formula = ~JQ_Index_AF_Score, by = ~CF_OtherHHIllness,
      design = JQ,
      FUN = svymean,
      na.rm = TRUE,
      row.names = FALSE)

#* ----------------------------------------------------------------
#* -------------- [CF.5 - Non-working adults in household:]
#* ----------------------------------------------------------------

#* Descriptive variable on number of adults in household:
Dat$variables$CF_HHAdults_Desc <- Dat$variables$hhsize - Dat$variables$CF_Children_Desc
Dat$variables$CF_HHAdults_Desc <- case_when(Dat$variables$CF_HHAdults_Desc >= 1 ~ as.numeric(Dat$variables$CF_HHAdults_Desc))
xtabs(~CF_HHAdults_Desc, Dat)

#* Descriptive variable on number of non-working adults in the household:
Dat$variables$CF_NonWorkingHHMembers_desc <- Dat$variables$CF_HHAdults_Desc - Dat$variables$HHNum_QoW_Index_Member
Dat$variables$CF_NonWorkingHHMembers_desc <- case_when(Dat$variables$CF_NonWorkingHHMembers_desc >= 0 ~ as.numeric(Dat$variables$CF_NonWorkingHHMembers_desc))
summary(Dat$variables$CF_NonWorkingHHMembers)

svyby(formula = ~JQ_Index_AF_Score, by = ~CF_NonWorkingHHMembers,
      design = JQ,
      FUN = svymean,
      na.rm = TRUE,
      row.names = FALSE)

#* Both these variables require some slight adjustment for values which don't make sense (where they don't make sense I convert them to NAs using
#* the above case_when statements. This only affects several dozen respondents).

#* Create final indicator:
Dat$variables$CF_NonWorkingHHMembers <- case_when(Dat$variables$CF_NonWorkingHHMembers_desc == 0 ~ 0,
                                                  Dat$variables$CF_NonWorkingHHMembers_desc == 1 ~ 0.25,
                                                  Dat$variables$CF_NonWorkingHHMembers_desc == 2 ~ 0.5,
                                                    Dat$variables$CF_NonWorkingHHMembers_desc == 3 ~ 0.75,
                                                  Dat$variables$CF_NonWorkingHHMembers_desc >= 4 ~ 1)

#######################################################################################
#######################################################################################
######################### 3 - Personal Disability and Health ##########################
#######################################################################################
#######################################################################################

#* ----------------------------------------------------------------
#* -------------- [CF.6 - Long-standing illness, impairment or disability:]
#* ----------------------------------------------------------------

#* For this I use the same variable as before:
Dat$variables$CF_LongStandingIllness

#* ----------------------------------------------------------------
#* -------------- [CF.7 - Recent work-limiting physical health:]
#* ----------------------------------------------------------------

#* The data are fairly well-correlated, but not as strongly as you 
#* might think: there are a handful of important exceptions. Further,
#* whilst there is a correlation with long-standing illness, the most
#* common score for those who do report a long-standing illness is 5 
#* on all measures of recent work-limiting physical health. Finally,
#* there's an almost perfect correlation with all of the missing 
#* values:
xtabs(~scsf3a + scsf3b + CF_LongStandingIllness_AF, data = Dat)
xtabs(~scsf3a + scsf3b, data = JQ)

#* [a - Desc:] I invert the scores so that lower = better, and 
#* in the process automatically convert the misising values to NA.
#* The possible values are:
#* [0] "None of the time" on both measures;
#* [0.25] Worst score on either measure is "a little of the time" 
#* [0.50] Worst score on either measure is "some of the time"
#* [0.75] Worst score on either measure "most of the time"
#* [1] Worst score on either measure "all of the time" 

#* I start by inverting the scores and adding them together. Any variable
#* which is NA in any one measure is automatically coded as NA through
#* this process (so the NA will be carried through to the combined variable):

Dat$variables$scsf3a_adj <- case_when(Dat$variables$scsf3a == 1 ~ 5,
                                      Dat$variables$scsf3a == 2 ~ 4,
                                      Dat$variables$scsf3a == 3 ~ 3,
                                      Dat$variables$scsf3a == 4 ~ 2,
                                      Dat$variables$scsf3a == 5 ~ 1)

Dat$variables$scsf3b_adj <- case_when(Dat$variables$scsf3b == 1 ~ 0.5,
                                      Dat$variables$scsf3b == 2 ~ 0.4,
                                      Dat$variables$scsf3b == 3 ~ 0.3,
                                      Dat$variables$scsf3b == 4 ~ 0.2,
                                      Dat$variables$scsf3b == 5 ~ 0.1)

Dat$variables$scsf3a3b_combined <- Dat$variables$scsf3a_adj + Dat$variables$scsf3b_adj

#* Create variable:
Dat$variables$CF_RecentPhysicalHealth <- case_when(Dat$variables$scsf3a3b_combined == 1.1 ~ 0,
                                                   (Dat$variables$scsf3a3b_combined == 1.2 | Dat$variables$scsf3a3b_combined == 2.1 | 
                                                      Dat$variables$scsf3a3b_combined == 2.2) ~ 0.25,
                                                   (Dat$variables$scsf3a3b_combined == 1.3 | Dat$variables$scsf3a3b_combined == 2.3 |
                                                      Dat$variables$scsf3a3b_combined == 3.1 | Dat$variables$scsf3a3b_combined == 3.2 | Dat$variables$scsf3a3b_combined == 3.3) ~ 0.5, 
                                                   (Dat$variables$scsf3a3b_combined == 1.4 | Dat$variables$scsf3a3b_combined == 2.4 | Dat$variables$scsf3a3b_combined == 3.4 | 
                                                      Dat$variables$scsf3a3b_combined == 4.1 | Dat$variables$scsf3a3b_combined == 4.2 | Dat$variables$scsf3a3b_combined == 4.3 | Dat$variables$scsf3a3b_combined == 4.4) ~ 0.75,
                                                   (Dat$variables$scsf3a3b_combined == 1.5 | Dat$variables$scsf3a3b_combined == 2.5 | Dat$variables$scsf3a3b_combined == 3.5 | Dat$variables$scsf3a3b_combined == 4.5 |
                                                      Dat$variables$scsf3a3b_combined == 5.1 | Dat$variables$scsf3a3b_combined == 5.2 | Dat$variables$scsf3a3b_combined == 5.3 | Dat$variables$scsf3a3b_combined == 5.4 | Dat$variables$scsf3a3b_combined == 5.5) ~ 1)

#* Create single unit version of the variable, where every level up the scale = 1. This is useful for the creation of equivalence scales later on. Note that you can't really create
#* this using some easy workaround (e.g. creating a factor and then converting to numeric), because sometimes the aggregated data misses levels. So for now [14.07.24], it's best to
#* do this manually: 
Dat$variables$CF_RecentPhysicalHealth_SingleUnit <- case_when(Dat$variables$CF_RecentPhysicalHealth_Desc == 0 ~ 0,
                                                              Dat$variables$CF_RecentPhysicalHealth_Desc == 0.25 ~ 1,
                                                              Dat$variables$CF_RecentPhysicalHealth_Desc == 0.5 ~ 2,
                                                              Dat$variables$CF_RecentPhysicalHealth_Desc == 0.75 ~ 3,
                                                              Dat$variables$CF_RecentPhysicalHealth_Desc == 1 ~ 4) 

xtabs(~CF_RecentPhysicalHealth_Desc, Dat)
xtabs(~CF_RecentPhysicalHealth_SingleUnit, Dat)

#* [b - AF:] As with some other indicators, the _AF version of this is the same as the
#* descriptive version:
Dat$variables$CF_RecentPhysicalHealth_AF <- Dat$variables$CF_RecentPhysicalHealth_Desc

#* Data check: passes. As noted earlier, the most common score for those with a long-standing
#* illness is actually 0 on work-limiting physical health: 
xtabs(~scsf3a3b_combined + CF_RecentPhysicalHealth_Desc, data = Dat)
xtabs(~CF_RecentPhysicalHealth_Desc + year, data = Dat)
xtabs(~CF_RecentPhysicalHealth_Desc + CF_LongStandingIllness_Desc, data = Dat)
xtabs(~CF_RecentPhysicalHealth_AF + year, data = Dat)

#* ----------------------------------------------------------------
#* -------------- [CF.8 - Recent work-limiting mental health:]
#* ----------------------------------------------------------------

#* As with physical health, the data are correlated, but with a great
#* deal of exceptions. Eg those who score worst (=1) on recent physical
#* health actually split >60/40 for worst scores on recent mental health: 
xtabs(~scsf4a + scsf4b + CF_LongStandingIllness_AF, data = Dat)
xtabs(~scsf4a + scsf4b + CF_RecentPhysicalHealth_AF, data = Dat)
xtabs(~scsf4a + scsf4b, data = JQ)

#* [a - Desc:] Data creation process exactly the same as for recent physical health:

Dat$variables$scsf4a_adj <- case_when(Dat$variables$scsf4a == 1 ~ 5,
                                      Dat$variables$scsf4a == 2 ~ 4,
                                      Dat$variables$scsf4a == 3 ~ 3,
                                      Dat$variables$scsf4a == 4 ~ 2,
                                      Dat$variables$scsf4a == 5 ~ 1)

Dat$variables$scsf4b_adj <- case_when(Dat$variables$scsf4b == 1 ~ 0.5,
                                      Dat$variables$scsf4b == 2 ~ 0.4,
                                      Dat$variables$scsf4b == 3 ~ 0.3,
                                      Dat$variables$scsf4b == 4 ~ 0.2,
                                      Dat$variables$scsf4b == 5 ~ 0.1)

Dat$variables$scsf4a4b_combined <- Dat$variables$scsf4a_adj + Dat$variables$scsf4b_adj

Dat$variables$CF_RecentMentalHealth <- case_when(Dat$variables$scsf4a4b_combined == 1.1 ~ 0,
                                                      (Dat$variables$scsf4a4b_combined == 1.2 | Dat$variables$scsf4a4b_combined == 2.1 | 
                                                         Dat$variables$scsf4a4b_combined == 2.2) ~ 0.25,
                                                      (Dat$variables$scsf4a4b_combined == 1.3 | Dat$variables$scsf4a4b_combined == 2.3 |
                                                         Dat$variables$scsf4a4b_combined == 3.1 | Dat$variables$scsf4a4b_combined == 3.2 | Dat$variables$scsf4a4b_combined == 3.3) ~ 0.5, 
                                                      (Dat$variables$scsf4a4b_combined == 1.4 | Dat$variables$scsf4a4b_combined == 2.4 | Dat$variables$scsf4a4b_combined == 3.4 | 
                                                         Dat$variables$scsf4a4b_combined == 4.1 | Dat$variables$scsf4a4b_combined == 4.2 | Dat$variables$scsf4a4b_combined == 4.3 | Dat$variables$scsf4a4b_combined == 4.4) ~ 0.75,
                                                      (Dat$variables$scsf4a4b_combined == 1.5 | Dat$variables$scsf4a4b_combined == 2.5 | Dat$variables$scsf4a4b_combined == 3.5 | Dat$variables$scsf4a4b_combined == 4.5 |
                                                         Dat$variables$scsf4a4b_combined == 5.1 | Dat$variables$scsf4a4b_combined == 5.2 | Dat$variables$scsf4a4b_combined == 5.3 | Dat$variables$scsf4a4b_combined == 5.4 | Dat$variables$scsf4a4b_combined == 5.5) ~ 1)

#* Create single unit version of mental health, as above:
Dat$variables$CF_RecentMentalHealth_SingleUnit <- case_when(Dat$variables$CF_RecentMentalHealth_Desc == 0 ~ 0,
                                                              Dat$variables$CF_RecentMentalHealth_Desc == 0.25 ~ 1,
                                                              Dat$variables$CF_RecentMentalHealth_Desc == 0.5 ~ 2,
                                                              Dat$variables$CF_RecentMentalHealth_Desc == 0.75 ~ 3,
                                                              Dat$variables$CF_RecentMentalHealth_Desc == 1 ~ 4) 

xtabs(~CF_RecentMentalHealth_Desc, Dat)
xtabs(~CF_RecentMentalHealth_SingleUnit, Dat)

#* [b - AF:] As with physical health, the _AF version of the data is the same:
Dat$variables$CF_RecentMentalHealth_AF <- Dat$variables$CF_RecentMentalHealth_Desc

#* Data check. Whilst the most common score across mental and physical health is 
#* 0 (ie no reported issues), and whilst there's a lot of correlation between them,
#* they are doing different things and there are exceptions:
xtabs(~scsf4a4b_combined + CF_RecentMentalHealth_Desc, data = Dat)
xtabs(~CF_RecentMentalHealth_Desc + year, data = Dat)
xtabs(~CF_RecentMentalHealth_Desc + CF_RecentPhysicalHealth_Desc, data = Dat)
xtabs(~CF_RecentMentalHealth_Desc + CF_LongStandingIllness_AF, data = Dat)

#* REFERENCES:
#* [1] Understanding Society variables [accessed 18.10.23], 'employ: in paid employment',
#* https://www.understandingsociety.ac.uk/documentation/mainstage/dataset-documentation/variable/employ

#######################################################################################
#######################################################################################
############################# 4 - Household-level CF scores ###########################
#######################################################################################
#######################################################################################

#* I now convert the above into household-level versions. Some of these variables are exactly the same at the household level, so aren't changed. Others need to be summed first. 
Dat$variables <- Dat$variables |> group_by(hidp, year) |>
  mutate(HHCF_CaringResponsibilities_Desc = sum(CF_CaringResponsibilities_Desc))

Dat$variables$CF_Children_Desc #* Kept the same;
Dat$variables$CF_HHAdults_Desc #* Kept the same;

Dat$variables <- Dat$variables |> group_by(hidp, year) |>
  mutate(HHCF_LongStandingIllness_Desc = sum(CF_LongStandingIllness_Desc))

Dat$variables <- Dat$variables |> group_by(hidp, year) |>
  mutate(HHCF_RecentPhysicalHealth_Desc = sum(CF_RecentPhysicalHealth_Desc))

Dat$variables <- Dat$variables |> group_by(hidp, year) |>
  mutate(HHCF_RecentMentalHealth_Desc = sum(CF_RecentMentalHealth_Desc))

Dat$variables <- Dat$variables |> group_by(hidp, year) |>
  mutate(HHCF_RecentPhysicalHealth_SingleUnit = sum(CF_RecentPhysicalHealth_SingleUnit))

Dat$variables <- Dat$variables |> group_by(hidp, year) |>
  mutate(HHCF_RecentMentalHealth_SingleUnit = sum(CF_RecentMentalHealth_SingleUnit))

#* In case needed I also create dummy versions of some of these variables so that a household with any *one* responsibility is coded appropriately. This may help
#* account for cases where (though logging it can also help): 
Dat$variables$HHCF_CaringResponsibilities_Dummy <- case_when(Dat$variables$HHCF_CaringResponsibilities_Desc >= 1 ~ 1, Dat$variables$HHCF_CaringResponsibilities_Desc == 0 ~ 0)
Dat$variables$HHCF_LongStandingIllness_Dummy <- case_when(Dat$variables$HHCF_LongStandingIllness_Desc >= 1 ~ 1, Dat$variables$HHCF_LongStandingIllness_Desc == 0 ~ 0)

#* Note [20.08.24] at a household level, of HHs who have someone with a long-standing illnesses in the household just 37%  have caring responsibilities. Of those 
#* who have caring responsibilities 70% live in a HH with someone with a long-standing illness. At an individual-level; over 8 in 10 of those who have caring responsibilities
#* live in a household with someone with a long-standing illness, but of those with someone with a long-standing illness in the HH the vast majority don't have those caring
#* responsibilities themselves (this is the case even when, as here, I filter to those in the QoW index): 
xtabs(~HHCF_CaringResponsibilities_Dummy + HHCF_LongStandingIllness_Dummy, Dat) |> prop.table(2)
xtabs(~HHCF_CaringResponsibilities_Dummy + HHCF_LongStandingIllness_Dummy, Dat) |> prop.table(1)
xtabs(~CF_CaringResponsibilities_AF + HHCF_LongStandingIllness_Dummy, JQ) |> prop.table(2)
xtabs(~CF_CaringResponsibilities_AF + HHCF_LongStandingIllness_Dummy, JQ) |> prop.table(1)

#* You find a strong relationship between caring responsibilities and the presence of non-working HH members, but - again - not between non-working HH members and caring 
#* responsibilities. The strength of association is weaker for those who:
xtabs(~CF_NonWorkingHHMembers_Desc + CF_CaringResponsibilities_AF, JQ) |> prop.table(2)
xtabs(~CF_NonWorkingHHMembers_Desc + CF_CaringResponsibilities_AF, JQ) |> prop.table(1)

xtabs(~CF_NonWorkingHHMembers_Desc + HHCF_LongStandingIllness_Dummy, JQ) |> prop.table(2)
xtabs(~CF_NonWorkingHHMembers_Desc + HHCF_LongStandingIllness_Dummy, JQ) |> prop.table(1)


xtabs(~CF_NonWorkingHHMembers_Desc + CF_CaringResponsibilities_AF, JQ)

CF_NonWorkingHHMembers_Desc

#######################################################################################
################################# 5 - Save Data #######################################
#######################################################################################

#* Saved the above as of [21.08.24]: 
# saveRDS(Dat, file = "0 - Dat.RData")
