
#######################################################################################
############################## 1 - Data pre-preparation: ##############################
#######################################################################################

#* The below code does a lot of things at the same time. It creates binary variables for each of the indicators, 
#* and codes any missing data as 0.1. Note that for job security in next 12 months, "don't know" is coded
#* worst. Coding missing as a decimal point allows me to follow the missing data in the combined variables:

Dat$variables$jbsec_adjusted <- case_when((Dat$variables$jbsec == 1 | Dat$variables$jbsec == 2 | Dat$variables$jbsec == -1) ~ 1,
                                          (Dat$variables$jbsec == 3 | Dat$variables$jbsec == 4) ~ 0,
                                          Dat$variables$jbsemp == 2 ~ 0,
                                          TRUE ~ 0.1)

Dat$variables$jbterm1_adjusted <- case_when(Dat$variables$jbterm1 == 2  ~ 1, 
                                            Dat$variables$jbterm1 == 1 ~ 0,
                                            TRUE ~ 0.1)

Dat$variables$jbstat_adjusted <- case_when((Dat$variables$jbstat == 3 | Dat$variables$jbstat == 9 | Dat$variables$jbstat == 10 | 
                                              Dat$variables$jbstat == 11 | Dat$variables$jbstat == 12 | Dat$variables$jbstat == 13) ~ 1,
                                           (Dat$variables$jbstat == 1 | Dat$variables$jbstat == 2 | Dat$variables$jbstat == 4 | 
                                              Dat$variables$jbstat == 5 | Dat$variables$jbstat == 6 | Dat$variables$jbstat == 7 |
                                              Dat$variables$jbstat == 8 | Dat$variables$jbstat == 97) ~ 0,
                                           TRUE ~ 0.1)

#* Then add together:
Dat$variables$combinedsecurity <- Dat$variables$jbsec_adjusted + Dat$variables$jbterm1_adjusted + Dat$variables$jbstat_adjusted

#######################################################################################
################################# 2 - Create indicator: ###############################
#######################################################################################

#* ------------ [a] Create Ind_CompositeSecurity:

#* Re indicator creation, note that I follow a harsh approach to the treatment of any missing 
#* values. Whilst we can infer that someone who reports == 1 on any one variable should be 
#* graded "worst" (since even if they score well on the ones that are missing, that won't change
#* that score), we can't make the same assumption for people who score 0 on one but not all variables.
#* I therefore grade these as missing, pending them being solved at the imputation stage.

#* Absolutely none of the variables score a 0.3. The most missing variable is for jbsec, especially in
#* Waves 4-6 due to proxies and (for Wave 6...) the fact this question wasn't asked in the IEMB. But
#* once you exclude self-employed from this indicator (as they are not asked the question) the number of
#* missing goes down, and the weighted number of missings goes markedly down except for a small blip 
#* in Wave 6:
Dat$variables$Ind_CompositeSecurity <- case_when(Dat$variables$combinedsecurity >= 1 ~ 0,
                                                       Dat$variables$combinedsecurity == 0 ~ 2,
                                                       TRUE ~ -1)

#* ------------ [b] Test for variable accuracy and trends:

#* Create filters:
JQ <- Dat |> filter(Dat$variables$index == "Quality of Work")
Employees <- Dat |> filter(Dat$variables$jbsemp == 1)
SelfEmployed <- Dat |> filter(Dat$variables$jbsemp == 2)

#* Proportional table time series:
prop.table(svytable((~Ind_CompositeSecurity + year),JQ), margin=2)
prop.table(svytable((~Ind_CompositeSecurity + year),Employees), margin=2)
prop.table(svytable((~Ind_CompositeSecurity + year),SelfEmployed), margin=2)

#* Below code shows filters work:
svytable(~jbterm1 + jbterm1_adjusted, design = JQ)
svytable(~jbsec + jbsec_adjusted, design = JQ)
svytable(~jbstat + jbstat_adjusted, design = JQ)
svytable(~Ind_CompositeSecurity + combinedsecurity, design = JQ)

#* Whilst there are quite a few missing/etc these don't have so much prominence
#* in the weighted data. Ie a lot of them (esp in Wave 6 IEMB) have a low 
#* weighting: 
xtabs(~jbsec_adjusted + year, data = JQ)
svytable(~jbsec_adjusted + year, design = JQ)

#######################################################################################
###################### 3 - Save the indicator into the survey: ########################
#######################################################################################

#* Saved the above as of [26.09.23]:
saveRDS(Dat, file = "0 - Dat.RData")

Dat <- readRDS("0 - Dat.RData")
Dat$variables$Ind_CompositeSecurity
