
#######################################################################################
############################### 1 - Create indicator: #################################
#######################################################################################

#* Amendment [24.11.23]. This can now consist of a family of questions put together into 
#* a matrix, all in the jbxpch variable:
#* jbxpcha = Expects a better job with same employer in next 12 months;
#* jbxpchb = Expects work-related training in next 12 months;
#* jbxpchc = Expects a new job with a new employer in next 12 months;
#* jbxpchd = Expects to start own business in next 12 months.

#* It's unreasonable to simply add these together to create a combined score: it's odd
#* to imagine someone would want and expect *all* of these things. Instead, it's more reasonable 
#* to code in a binary way based on whether (a) they have 1 of these things (middle) or (b) they
#* have more then 1 of these things (best) - and see what happens then? Alternatively code on a 
#* similar scale as eg work fatalities.

#* This can be put into a composite. Note that (a) there's also a fifth question on whether
#* the worker expects to give up paid work and (b) each of these have an equivalent prior question
#* on whether they'd actually like this to happen (jblkcha-e), but they are asked the above
#* questions regardless of whether they say they'd like it or not. 

#* These variables have a good coverage for both employees and the self-employed, with only a
#* small number of missing values otherwise. Note there is a "doesn't apply:" 
svytable(~ Dat$variables$jbxpcha + Dat$variables$jbsemp, design = Dat)
svytable(~ Dat$variables$jblkchc + Dat$variables$jbsemp, design = Dat)
svytable(~ Dat$variables$jbxpchc + Dat$variables$jbsemp, design = Dat)

#* -----------------------------------------------
#* -----------------------------------------------
#* [a] Adjust the variables
#* -----------------------------------------------
#* -----------------------------------------------

#* I create adjusted versions of each of the four variables. In all cases some value 
#* judgements are made here. First, someone who reports "don't know" in any of the variables 
#* is coded lowest (0), since I assume not knowing about your prospects means a lack of availability
#* of them, or a lack of confidence that they'd occur. This is different to how I treat don't knows
#* in other indicators (eg pension) but I consider it justifiable by the nature of the indicator in
#* question. Second, for the variable on whether the worker expects a better job with the same employer,
#* there's uniquely a "doesn't apply" option here (jbxpcha = 3). I automatically code these as the worst
#* score too. The below code demonstrates thatself-employed are disproportionately coded as "doesn't apply",
#* and that very few of those coded this way are actually out of paid work (and thus out of the QoW index):
#* it therefore suggests that for self-employed workers, this is disproportionately interpreted by them as 
#* asking whether in reality their employer/contractor could get them a better job.

Dat$variables$jbxpcha_adj <- case_when(Dat$variables$jbxpcha == 1 ~ 1,
                                       Dat$variables$jbxpcha == 2 | Dat$variables$jbxpcha == 3 | Dat$variables$jbxpcha == -1 ~ 0,
                                       Dat$variables$jbxpcha < -1 ~ 0.1,
                                       TRUE ~ -1)

Dat$variables$jbxpchb_adj <- case_when(Dat$variables$jbxpchb == 1  ~ 1,
                                       Dat$variables$jbxpchb == 2 | Dat$variables$jbxpchb == -1 ~ 0,
                                       Dat$variables$jbxpchb < -1 ~ 0.1,
                                       TRUE ~ -1)

Dat$variables$jbxpchc_adj <- case_when(Dat$variables$jbxpchc == 1 ~ 1,
                                       Dat$variables$jbxpchc == 2 | Dat$variables$jbxpchc == -1 ~ 0,
                                       Dat$variables$jbxpchc < -1 ~ 0.1,
                                       TRUE ~ -1)

Dat$variables$jbxpchd_adj <- case_when(Dat$variables$jbxpchd == 1 ~ 1,
                                       Dat$variables$jbxpchd == 2 | Dat$variables$jbxpchd == -1 ~ 0,
                                       Dat$variables$jbxpchd < -1 ~ 0.1,
                                       TRUE ~ -1)

#* -----------------------------------------------
#* -----------------------------------------------
#* [b] Combine the variables
#* -----------------------------------------------
#* -----------------------------------------------

#* Combine the two together:
Dat$variables$combinedprospects <- Dat$variables$jbxpcha_adj + Dat$variables$jbxpchb_adj + 
  Dat$variables$jbxpchc_adj + Dat$variables$jbxpchd_adj

#* Most people who are missing are missing on all of them. Missingness goes
#* down over the course of the time series, but is still high. A large number of
#* respondents have 1 of these, but a significant minority have 2. It trails off at
#* 3-4:
xtabs(~combinedprospects + year, JQ)

#######################################################################################
################################# 2 - Create indicator: ###############################
#######################################################################################

#* Create the indicator:
Dat$variables$Ind_ShortTermProspects <- case_when(Dat$variables$combinedprospects >= 2 ~ 2,
                                                         Dat$variables$combinedprospects < 2 & Dat$variables$combinedprospects >= 1 ~ 1,
                                                        Dat$variables$combinedprospects < 0.4 & Dat$variables$combinedprospects >= 0 ~ 0,
                                                        Dat$variables$combinedprospects == 0.4 ~ -1,
                                                         TRUE ~ -1)

################################################# ######################################
########################## 3 - VISUALISATION AND TABULATION: ##########################
#######################################################################################

#* Then re-add filters:
JQ <- Dat |> filter(Dat$variables$index == "Quality of Work")
Employees <- Dat |> filter(Dat$variables$jbsemp == 1)
SelfEmployed <- Dat |> filter(Dat$variables$jbsemp == 2)

#* Proportional table time series:
prop.table(svytable((~Ind_ShortTermProspects + year),JQ), margin=2) |> round(2)
prop.table(svytable((~Ind_ShortTermProspects + year),Employees), margin=2) |> round(2)
prop.table(svytable((~Ind_ShortTermProspects + year),SelfEmployed), margin=2) |> round(2)

#######################################################################################
###################### 4 - Save the indicator into the survey: ########################
#######################################################################################

#* Saved the above as of [26.09.23]:
saveRDS(Dat, file = "0 - Dat.RData")

Dat <- readRDS("0 - Dat.RData")
Dat$variables$Ind_ShortTermProspects
