
#######################################################################################
################################# 1 - Pre-preparation: ################################
#######################################################################################

#* First install some API scraping apps:
setwd("INSERT UKHLS WORKING DIRECTORY HERE")
library(httr) #* For accessing APIs;
library(jsonlite) #* For reading data from the API;
library(haven) #* For read_dta();
library(dplyr) #* For select();
library(stats) #* For logistic regressions and other models;
library(pollster) #* For summary stats / time series / cross-tabs when using weights (not survey design objects).

#* Download all SOCs, and convert into a vector. Note this spreadsheet is supplied in a separate 'working directory' 
#* folder but it can easily be created manually from existing ONS data on SOC 2010s:
SOCs <- read.csv("0 - SOC 2010 Vector.csv")
SOCs <- SOCs$SOC

#######################################################################################
########################### 2 - Download data from APIs: ##############################
#######################################################################################

#* ----------------------------------------------------------------
#* -------------- [a - Future employment predictions:]
#* ----------------------------------------------------------------

#* Create a function:
getLMI.FutureEmployment <- function(object) {
  request <- GET(url = "http://api.lmiforall.org.uk/api/v1/wf/predict",
                 query = list(soc = object,
                              minYear = 2017,
                              maxYear = 2027))
  
  df <- content(request, as = "text", encoding = "UTF-8") |> 
    fromJSON(flatten = TRUE) |>
    data.frame()   
}

#* Execute the function and save the data:
SOC.Employment <- lapply(SOCs, getLMI.FutureEmployment)
SOC.Employment.Data <- list_rbind(SOC.Employment)  

#* ----------------------------------------------------------------
#* -------------- [b - Replacement demand predictions:]
#* ----------------------------------------------------------------

#* Create a function:
getLMI.ReplacementDemand <- function(object) {
  request <- GET(url = "http://api.lmiforall.org.uk/api/v1/wf/replacement_demand",
                 query = list(soc = object,
                              startYear = 2017,
                              endYear = 2027))
  
  df <- content(request, as = "text", encoding = "UTF-8") |> 
    fromJSON(flatten = TRUE) |>
    data.frame()   
}

#* Execute the function and save the data:
SOC.ReplacementDemand <- lapply(SOCs, getLMI.ReplacementDemand)
SOC.ReplacementDemand.Data <- list_rbind(SOC.ReplacementDemand)  

#* ----------------------------------------------------------------
#* -------------- [c - Merge into single data frame:]
#* ----------------------------------------------------------------

#* Merge by SOC:
SOC.Prospects.Data <- full_join(SOC.Employment.Data, 
                                SOC.ReplacementDemand.Data,
                                by = "soc")

#* Filter away the data and prepare for wider data format:
SOC.Prospects.Data.Filter <- SOC.Prospects.Data |> filter(predictedEmployment.year == 2017 |
                                                            predictedEmployment.year == 2027)

SOC.Prospects.Data.Filter$Employment.2017 <- case_when(SOC.Prospects.Data.Filter$predictedEmployment.year == 2017 ~ 
                                                         as.numeric(SOC.Prospects.Data.Filter$predictedEmployment.employment))
                                                         
SOC.Prospects.Data.Filter$Employment.2027 <- case_when(SOC.Prospects.Data.Filter$predictedEmployment.year == 2027 ~ 
                                                         as.numeric(SOC.Prospects.Data.Filter$predictedEmployment.employment))

#* Save the data:
write.csv(SOC.Prospects.Data.Filter, "0 - Prospects by SOC 2010.csv")

#######################################################################################
####################### 3 - Apply Prospects data to LFS: ##############################
#######################################################################################

#* The Working Futures data is in practice by 2-digit not 4-digit 2010 SOCs. Once you convert the job numbers 
#* into percentage change, you find there is no variation in future % prospects by 2-digit SOC. So effectively 
#* we are therefore dealing with 2-digit 2010 SOCs. This makes sense anyway, and is useful: where the prospects 
#* for one (4-digit) SOC job are poor, a reasonable argument could be made that a worker could re-skill into a 
#* (notionally similar) job with the same 2-digit SOC. This argument becomes more and more tenuous the 
#* higher the level of aggregation you go. This leaves us with the question of how to plug these 2-digit
#* SOC job prospects data into Understanding Society.

#* Because Understanding Society uses SOCs from 2000 and Working Futures uses SOCs from 2010, a direct 
#* read-across isn't possible. You can't easily convert 2000 SOCs into 2010 SOCs, as there are lots
#* of cases where a single even 2-digit code in the 2000 SOCs splits into different 2-digit
#* code options in the 2010 SOCs (and vice-versa). This problem with SOC coding updates is acknowledged
#* by the ONS's own Classifications Unit, who have said (with respect to comparing 2010 and 2020 SOCs) that 
#* "the data are limited by various factors including diverse dual-coding methodologies across datasets and 
#* different sources of error."[1] My own analysis of the ONS's separate SOC 2000-2010 matching spreadsheets[2]
#* backs this up. The LFS could have solved this by running both sets of SOCs concurrently once a decade, but
#* unfortunately they don't do this.

#* Instead, I therefore use a similar process as with the Health and Safety dimension to create the indicator.
#* I pool data from the Labour Force Survey from across the decade 2011-2020 to calculate job prospects by 
#* 2010 SOC. I then use this to create a matrix of prospects by a common variable used in both the LFS and
#* Understanding Society: 2007 Standard Industrial Classifications. The data from this matrix is then used to
#* create job prospects scores in Understanding Society, based on the SIC (and thus not the SOC) of the respondent. 
#* This is obviously not the ideal solution, since the SIC prospects are essentially an aggregate of the prospects
#* of the SOCs of all the workers with that industrial classification. However, I consider it to be significantly
#* superior to any alternative - such as using crosswalks with American O*NET data (which is never exact, and
#* with studies showing wide variations in UK vs. US aggregate data using this approach, eg with green jobs), 
#* or using the Working Futures data directly on Understanding Society (which will systematically mis-code a
#* small but important number of occupations).

#* REFERENCES:
#* [1] Office for National Statistics [accessed 09.11.23], 
#* 'The relationship between Standard Occupational Classification 2010 and Standard Occupational Classification 2020',
#* https://www.ons.gov.uk/methodology/classificationsandstandards/standardoccupationalclassificationsoc/soc2020/therelationshipbetweenstandardoccupationalclassification2010andstandardoccupationalclassification2020 
#* [2] Office for National Statistics [accessed 09.11.23], 
#* 'SOC2010 volume 2: the structure and coding index (Volume 7)', 
#* https://www.ons.gov.uk/methodology/classificationsandstandards/standardoccupationalclassificationsoc/soc2010/soc2010volume2thestructureandcodingindex

#* ----------------------------------------------------------------
#* -------------- [a - Download LFS data and merge together:]
#* ----------------------------------------------------------------

#* Same process as with the Health and Safety data (see 7.1). However you don't get 2010 SOCs pre- Q1 2011 or post-2020, so 
#* I use a smaller time period for reference:

LFS_2011_Q1 <- read_dta("lfsp_jm11_end_user.dta") |> 
  select(PWT14, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, ICDM, INDC07M, INDS07M, INDC07S, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         SEX, AGE, GOVTOF, #* Individual characteristics;
         ACCDNT, ILLWRK, HOW1CAUS, HOW2CAUS, HOW3CAUS, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2012_Q1 <- read_dta("lfsp_jm12_end_user.dta") |> 
  select(PWT18, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, ICDM, INDC07M, INDS07M, INDC07S, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, GOVTOF, #* Individual characteristics;
         ACCDNT, ILLWRK, HOW1CAUS, HOW2CAUS, HOW3CAUS, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2013_Q1 <- read_dta("lfsp_jm13_end_user.dta") |> 
  select(PWT18, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, ICDM, INDC07M, INDS07M, INDC07S, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, GOVTOF, #* Individual characteristics;
         ACCDNT, HOW1CAUS, HOW2CAUS, HOW3CAUS, WCHJB) #* Work accidents and illness.

LFS_2014_Q1 <- read_dta("lfsp_jm14_end_user.dta") |> 
  select(PWT18, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, ICDM, INDC07M, INDS07M, INDC07S, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, GOVTOF, #* Individual characteristics;
         ACCDNT, ILLWRK, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2015_Q1 <- read_dta("lfsp_jm15_eul.dta") |> 
  select(PWT18, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, INDC07M, INDS07M, INDC07S, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, GOVTOF, #* Individual characteristics;
         ACCDNT, ILLWRK, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2016_Q1 <- read_dta("lfsp_jm16_eul.dta") |> 
  select(PWT18, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, INDC07M, INDS07M, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, #* Individual characteristics;
         ACCDNT, ILLWRK, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2017_Q1 <- read_dta("lfsp_jm17_eul.dta") |> 
  select(PWT18, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, INDC07M, INDS07M, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, #* Individual characteristics;
         ACCDNT, ILLWRK, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2018_Q1 <- read_dta("lfsp_jm18_eul.dta") |> 
  select(PWT18, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, INDC07M, INDS07M, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, #* Individual characteristics;
         ACCDNT, ILLWRK, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2019_Q1 <- read_dta("lfsp_jm19_eul_pwt18.dta") |> 
  select(PWT18, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, INDC07M, INDS07M, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, #* Individual characteristics;
         ACCDNT, ILLWRK, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2020_Q1 <- read_dta("lfsp_jm20_eul_pwt22.dta") |> 
  select(PWT22, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, INDC07M, INDS07M, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, #* Individual characteristics;
         ACCDNT, ILLWRK, WCHJB, WCHJB3) #* Work accidents and illness.

#* Add a year variable: 
LFS_2011_Q1$year <- "2011"
LFS_2012_Q1$year <- "2012"
LFS_2013_Q1$year <- "2013"
LFS_2014_Q1$year <- "2014"
LFS_2015_Q1$year <- "2015"
LFS_2016_Q1$year <- "2016"
LFS_2017_Q1$year <- "2017"
LFS_2018_Q1$year <- "2018"
LFS_2019_Q1$year <- "2019"
LFS_2020_Q1$year <- "2020"

#* Make weight names consistent:
LFS_2011_Q1 <- LFS_2011_Q1 |> rename(PWT = PWT14)
LFS_2012_Q1 <- LFS_2012_Q1 |> rename(PWT = PWT18)
LFS_2013_Q1 <- LFS_2013_Q1 |> rename(PWT = PWT18)
LFS_2014_Q1 <- LFS_2014_Q1 |> rename(PWT = PWT18)
LFS_2015_Q1 <- LFS_2015_Q1 |> rename(PWT = PWT18)
LFS_2016_Q1 <- LFS_2016_Q1 |> rename(PWT = PWT18)
LFS_2017_Q1 <- LFS_2017_Q1 |> rename(PWT = PWT18)
LFS_2018_Q1 <- LFS_2018_Q1 |> rename(PWT = PWT18)
LFS_2019_Q1 <- LFS_2019_Q1 |> rename(PWT = PWT18)
LFS_2020_Q1 <- LFS_2020_Q1 |> rename(PWT = PWT22)

#* Merge data together:
LFS <- bind_rows(LFS_2011_Q1, LFS_2012_Q1, LFS_2013_Q1, LFS_2014_Q1, 
                 LFS_2015_Q1, LFS_2016_Q1, LFS_2017_Q1, LFS_2018_Q1,
                 LFS_2019_Q1, LFS_2020_Q1)

#* Remove data:
rm(LFS_2011_Q1, LFS_2012_Q1, LFS_2013_Q1,
   LFS_2014_Q1, LFS_2015_Q1, LFS_2016_Q1, LFS_2017_Q1, LFS_2018_Q1,
   LFS_2019_Q1, LFS_2020_Q1)
gc()

#* ----------------------------------------------------------------
#* -------------- [b - Prepare the LFS data:]
#* ----------------------------------------------------------------

#* Create QoW Index Member variables: 
LFS$QoW_Index_Member <- case_when(LFS$WRKING == 1 | LFS$JBAWAY == 1 ~ 1,
                                  LFS$WRKING == 2 | LFS$WRKING == -9 | LFS$JBAWAY == 2 | LFS$JBAWAY == 3 ~ 0,
                                  TRUE ~ -1)

#* Similar to health and safety, I filter here only to QoW index members. The code below
#* shows this only actually removes a few thousand SOCs across the whole sample:
LFS_Filter <- filter(LFS, QoW_Index_Member == 1)
length(which(LFS$SOC10M > 0))
length(which(LFS_Filter$SOC10M > 0))
rm(LFS)
gc()

#* Create shortened SICs:
LFS_Filter$INDC07M_Char <- as.character(LFS_Filter$INDC07M)
LFS_Filter$INDC07M_Amend <- case_when(nchar(LFS_Filter$INDC07M_Char) == 3 ~ str_pad(LFS_Filter$INDC07M_Char, width = 4, pad = "0"),
                                      TRUE ~ as.character(LFS_Filter$INDC07M_Char))
LFS_Filter$INDC07M_3Digit <- substr(LFS_Filter$INDC07M_Amend, 1,3)
LFS_Filter$INDC07M_2Digit <- substr(LFS_Filter$INDC07M_Amend, 1,2)
LFS_Filter$INDC07M_1Digit <- substr(LFS_Filter$INDC07M_Amend, 1,1)

#* The same issues with small sample size for SICs will apply here, so I merge some low-sample 
#* SICs together in a way which is consistent with how the Health and Safety Executive report
#* on these data:

LFS_Filter$INDC07M_2Digit_Merge <- case_when(LFS_Filter$INDC07M_2Digit == "01" ~ "01to03",
                                             LFS_Filter$INDC07M_2Digit == "02" ~ "01to03",
                                             LFS_Filter$INDC07M_2Digit == "03" ~ "01to03",
                                             LFS_Filter$INDC07M_2Digit == "05" ~ "05to09",
                                             LFS_Filter$INDC07M_2Digit == "06" ~ "05to09",
                                             LFS_Filter$INDC07M_2Digit == "07" ~ "05to09",
                                             LFS_Filter$INDC07M_2Digit == "08" ~ "05to09",
                                             LFS_Filter$INDC07M_2Digit == "09" ~ "05to09",
                                             LFS_Filter$INDC07M_2Digit == "12" ~ "12and15and32",
                                             LFS_Filter$INDC07M_2Digit == "15" ~ "12and15and32",
                                             LFS_Filter$INDC07M_2Digit == "32" ~ "12and15and32",
                                             LFS_Filter$INDC07M_2Digit == "36" ~ "36and37",
                                             LFS_Filter$INDC07M_2Digit == "37" ~ "36and37",
                                             LFS_Filter$INDC07M_2Digit == "38" ~ "38and39",
                                             LFS_Filter$INDC07M_2Digit == "39" ~ "38and39",
                                             LFS_Filter$INDC07M_2Digit == "97" ~ "97and98",
                                             LFS_Filter$INDC07M_2Digit == "98" ~ "97and98",
                                             TRUE ~ as.character(LFS_Filter$INDC07M_2Digit))

LFS_Filter$INDS07M <- as.character(LFS_Filter$INDS07M)
LFS_Filter$INDS07M_Merge <- case_when(LFS_Filter$INDS07M == "18" ~ "18to21",
                                      LFS_Filter$INDS07M == "19" ~ "18to21",
                                      LFS_Filter$INDS07M == "20" ~ "18to21",
                                      LFS_Filter$INDS07M == "21" ~ "18to21",
                                      TRUE ~ as.character(LFS_Filter$INDS07M))

#* Data saved as of [09.11.23]:
saveRDS(LFS_Filter, file = "0 - LFS_Prospects_Filter.RData")

#* ----------------------------------------------------------------
#* -------------- [c - Download data into the LFS:]
#* ----------------------------------------------------------------

#* Download file:
LFS_Filter <- readRDS("0 - LFS_Prospects_Filter.RData")

#* Download Prospects table: 
Prospects_Table <- read.csv("0 - Prospects by SOC 2010.csv")
Prospects_Table <- Prospects_Table |> rename(SOC10M = soc.4digit)

#* Read Prospects data into LFS:
LFS_Filter_Join <- left_join(LFS_Filter, Prospects_Table, by = "SOC10M")
rm(LFS_Filter)
gc()

#* The process creates 533 NAs. These are simply the 533 people across the sample
#* who don't have valid SOCs. In other words, there's a full transfer of data for
#* all the others:
length(which(LFS_Filter_Join$SOC10M < 0))
length(which(is.na(LFS_Filter_Join$TotalRequirement.Percentage.PerAnnum)))

#* ----------------------------------------------------------------
#* -------------- [d - Create a matrix of Prospects data by SIC:]
#* ----------------------------------------------------------------

#* For this I need a weighted mean by SIC:
Tab1 <- LFS_Filter_Join |> 
  group_by(INDC07M_2Digit_Merge) |> 
  summarise(TotalRequirement.Percentage.PerAnnum = weighted.mean(TotalRequirement.Percentage.PerAnnum, PWT, na.rm = TRUE))
Tab1 |> print(n = 300)

write.csv(Tab1, "0 - Prospects by 2-digit SIC.csv")

#* The LFS data shows a slight improvement in mean prospects over time. London has
#* the best prospects, the North has the worst prospects. Women have better prospects than
#* men, which may be explained by their predominance in the health and social care industry:
LFS_Filter_Join |> 
  group_by(year) |> 
  summarise(weighted.mean(TotalRequirement.Percentage.PerAnnum, PWT, na.rm = TRUE))

LFS_Filter_Join |> 
  group_by(GOVTOF) |> 
  summarise(weighted.mean(TotalRequirement.Percentage.PerAnnum, PWT, na.rm = TRUE))

LFS_Filter_Join |> 
  group_by(SEX) |> 
  summarise(weighted.mean(TotalRequirement.Percentage.PerAnnum, PWT, na.rm = TRUE))

#######################################################################################
################## 3 - Create indicator in Understanding Society: #####################
#######################################################################################

#* ----------------------------------------------------------------
#* -------------- [a - Create data in Understanding Society:]
#* ----------------------------------------------------------------

#* Download data:
Prospects_Matrix <- read.csv("0 - Prospects by 2-digit SIC.csv")

#* Separate out Dat from the survey design, and merge the data. Then add it
#* back in:
Dat_AllWaves <- Dat$variables
Dat_AllWaves_Join <- left_join(Dat_AllWaves, Prospects_Matrix, by = "INDC07M_2Digit_Merge")
Dat$variables <- Dat_AllWaves_Join

#* ----------------------------------------------------------------
#* -------------- [b - Check data:]
#* ----------------------------------------------------------------

#* The data shows a slight improvement over time, but not as pronounced as in the 
#* LFS. Overall however the differences are consistent with LFS, but with lower variance 
#* (which can be addressed in the creation of the indicator itself). London continues
#* to have higher prospects than eg the north. The differences by ethnicity (which I 
#* don't create for LFS) seem to go in the opposite direction to what might be assumed,
#* with black and minority ethnic groups scoring higher on prospects than others. The 
#* self-employed have lower prospects than employees, but not markedly so. The relationship
#* with parental NS-SEC is also not as pronounced, although - again - still with most
#* showing reasonable differences:

svyby(formula = ~TotalRequirement.Percentage.PerAnnum_SICs, by = ~year,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~TotalRequirement.Percentage.PerAnnum_SICs, by = ~DV_Region_All,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~TotalRequirement.Percentage.PerAnnum_SICs, by = ~DV_Sex,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~TotalRequirement.Percentage.PerAnnum_SICs, by = ~DV_Ethnicity_All,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~TotalRequirement.Percentage.PerAnnum_SICs, by = ~DV_SelfEmployed,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~TotalRequirement.Percentage.PerAnnum_SICs, by = ~CS_ParentalNSSEC,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

#* ----------------------------------------------------------------
#* -------------- [c - Create indicator:]
#* ----------------------------------------------------------------

#* Create standard units prospects data:
ProspectsMean <- svymean(Dat$variables$TotalRequirement.Percentage.PerAnnum, design = Dat, na.rm = TRUE)
ProspectsSD <- svysd(~ Dat$variables$TotalRequirement.Percentage.PerAnnum, design = Dat, na.rm = TRUE)
Dat$variables$ProspectsStandardUnits <- (Dat$variables$TotalRequirement.Percentage.PerAnnum - ProspectsMean) / ProspectsSD

#* Create indicators:
Dat$variables$AltInd_LongTermProspects_SICs <- rescale(Dat$variables$ProspectsStandardUnits) * 2

#* Same analysis as above by the standardised Long-Term Prospects indicator:
svyby(formula = ~Ind_LongTermProspects, by = ~year,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~Ind_LongTermProspects, by = ~DV_Region_All,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~Ind_LongTermProspects, by = ~DV_Sex,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~Ind_LongTermProspects, by = ~DV_Ethnicity_All,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~Ind_LongTermProspects, by = ~DV_SelfEmployed,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~Ind_LongTermProspects, by = ~CS_ParentalNSSEC,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

#* ----------------------------------------------------------------
#* -------------- [d - Save data:]
#* ----------------------------------------------------------------

#* Saved the above as of [09.11.23]:
# saveRDS(Dat, file = "0 - Dat.RData")

#######################################################################################
######################### 4 - Alternative indicator: ##################################
#######################################################################################

#* ----------------------------------------------------------------
#* -------------- [a - Prepare the population and variables:]
#* ----------------------------------------------------------------

#* First, to check the data, I look at the crossover between:
Dat$variables$SOC00_Missing <- case_when(Dat$variables$jbsoc00_cc <= 0 ~ 1, Dat$variables$jbsoc00_cc > 0 ~ 0)
Dat$variables$SOC10_Missing <- case_when(Dat$variables$jbsoc10_cc <= 0 ~ 1, Dat$variables$jbsoc10_cc > 0 ~ 0)

#* There is actually an encouraging number of cases where people share 2000 and 2010 SOCs. 
#* As one would expect, the respondents with both SOCs improves over time as people move jobs
#* and the SOC codes are updated. Missingness for the 2000 SOCs remains very low throughout
#* the time series:
xtabs(~SOC00_Missing + SOC10_Missing + year, JQ)

#* I then create a 2-digit version of both codes:
Dat$variables$jbsoc00_cc_2Digit <- as.numeric(substr(Dat$variables$jbsoc00_cc, 1,2))
Dat$variables$jbsoc10_cc_2Digit <- as.numeric(substr(Dat$variables$jbsoc10_cc, 1,2))

#* Finally, I rename the existing total requirement percentage variable so it doesn't conflict
#* with the others: 
Dat <- Dat |> rename(TotalRequirement.Percentage.PerAnnum_SICs = TotalRequirement.Percentage.PerAnnum)

#* I then filter to a specific population, within the JQ index, who have both 2000 and 2010 SOCs. 
#* There is also an argument for filtering only to 1 wave (or at least sticking to unique cases 
#* across all waves), but for the initial exercise I do not do this:
JQ_SOC0010 <- JQ |> filter(SOC00_Missing == 0 & SOC10_Missing == 0)

#* Saved the above new variables as of [10.11.23]:
# saveRDS(Dat, file = "0 - Dat.RData")

#* ----------------------------------------------------------------
#* -------------- [b - Create prospects matrix using Understanding Society data:]
#* ----------------------------------------------------------------

#* Download data and align variable name for the prospects matrix:
Prospects_Matrix <- read.csv("0 - Prospects by 2-digit SOC 2010.csv")
Prospects_Matrix <- Prospects_Matrix |> rename(jbsoc10_cc_2Digit = soc.2digit,
                                               TotalRequirement.Percentage.PerAnnum_SOCs = TotalRequirement.Percentage.PerAnnum)

#* Separate out Dat from the survey design, and merge the data. Then add it back in:
JQ_SOC0010_AllWaves <- JQ_SOC0010$variables
JQ_SOC0010_AllWaves_Join <- left_join(JQ_SOC0010_AllWaves, Prospects_Matrix, by = "jbsoc10_cc_2Digit")
JQ_SOC0010$variables <- JQ_SOC0010_AllWaves_Join

#* The process creates no NAs:
length(which(is.na(JQ_SOC0010_AllWaves$variables$TotalRequirement.Percentage.PerAnnum_SOCs)))

#* Create the matrix of prospects data by 2-digit 2000 SOCs. This effectively means taking the 2010
#* SIC data and populating it with percentages based on the average of the 2010 SOCs within them:
Tab1 <- svyby(formula = ~TotalRequirement.Percentage.PerAnnum_SOCs, by = ~jbsoc00_cc_2Digit,
      design = JQ_SOC0010, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

#* Save the data:
write.csv(Tab1, "0 - Prospects by 2-digit SOC 2000.csv")

#* ----------------------------------------------------------------
#* -------------- [c - Create the indicator:]
#* ----------------------------------------------------------------

Prospects_Matrix <- read.csv("0 - Prospects by 2-digit SOC 2000.csv")

#* Separate out Dat from the survey design, and merge the data. Then add it
#* back in:
Dat_AllWaves <- Dat$variables
Dat_AllWaves_Join <- left_join(Dat_AllWaves, Prospects_Matrix, by = "jbsoc00_cc_2Digit")
Dat$variables <- Dat_AllWaves_Join

#* Create standard units prospects data:
ProspectsMean <- svymean(Dat$variables$TotalRequirement.Percentage.PerAnnum_SOCs, design = Dat, na.rm = TRUE)
ProspectsSD <- svysd(~ Dat$variables$TotalRequirement.Percentage.PerAnnum_SOCs, design = Dat, na.rm = TRUE)
Dat$variables$ProspectsStandardUnits <- (Dat$variables$TotalRequirement.Percentage.PerAnnum_SOCs - ProspectsMean) / ProspectsSD

#* Create indicators:
Dat$variables$Ind_LongTermProspects <- rescale(Dat$variables$ProspectsStandardUnits) * 2

#* ----------------------------------------------------------------
#* -------------- [d - Check data:]
#* ----------------------------------------------------------------

#* Using the 'raw' percentages, the time series pretty closely matches with what we see 
#* in the Labour Force Survey. The regional data is more similar to the SIC data in the sense that
#* whilst (consistent with the LFS) it shows London scoring highest, it's actually the East Midlands
#* and Wales (not the north of England) which score worst:

svyby(formula = ~TotalRequirement.Percentage.PerAnnum_SOCs, by = ~year,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~TotalRequirement.Percentage.PerAnnum_SOCs, by = ~DV_Region_All,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~TotalRequirement.Percentage.PerAnnum_SOCs, by = ~DV_Sex,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~TotalRequirement.Percentage.PerAnnum_SOCs, by = ~DV_Ethnicity_All,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~TotalRequirement.Percentage.PerAnnum_SOCs, by = ~DV_SelfEmployed,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~TotalRequirement.Percentage.PerAnnum_SOCs, by = ~CS_ParentalNSSEC,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

#* Similar data by the indicator itself:
svyby(formula = ~Ind_LongTermProspects, by = ~year,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

#* Both self-employed and employees see a slight improvement in prospects over the 
#* course of the time series:
svyby(formula = ~Ind_LongTermProspects, by = ~year,
      design = Employees, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~Ind_LongTermProspects, by = ~year,
      design = SelfEmployed, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

#* ----------------------------------------------------------------
#* -------------- [e - Compare LFS and Understanding Society time series:]
#* ----------------------------------------------------------------

#* Create the data in the Labour Force Survey, based on SOC 2010:
LFS_Filter <- readRDS("0 - LFS_Prospects_Filter.RData")
Prospects_Table <- read.csv("0 - Prospects by SOC 2010.csv")
Prospects_Table <- Prospects_Table |> rename(SOC10M = soc.4digit)
LFS_Filter_Join <- left_join(LFS_Filter, Prospects_Table, by = "SOC10M")
rm(LFS_Filter)
gc()

#* Filter only to Understanding Society years and merge years to align with
#* Understanding Society:
LFS_Filter_USoc <- filter(LFS_Filter_Join, 
                          year == 2012 | year == 2013 | 
                            year == 2014 | year == 2015 | 
                            year == 2016 | year == 2017 | 
                            year == 2018 | year == 2019 |
                            year == 2020 | year == 2021)
LFS_Filter_USoc$USoc_Year <- case_when(LFS_Filter_USoc$year == 2012 | LFS_Filter_USoc$year == 2013 ~ "2012-13",
                                       LFS_Filter_USoc$year == 2014 | LFS_Filter_USoc$year == 2015 ~ "2014-15",
                                       LFS_Filter_USoc$year == 2016 | LFS_Filter_USoc$year == 2017 ~ "2016-17",
                                       LFS_Filter_USoc$year == 2018 | LFS_Filter_USoc$year == 2019 ~ "2018-19",
                                       LFS_Filter_USoc$year == 2020 | LFS_Filter_USoc$year == 2021 ~ "2020-21")

#* Generate data for both Understanding Society and Labour Force Survey:
LFS_Filter_USoc |> group_by(USoc_Year) |> summarise(TotalRequirement.Percentage.PerAnnum = weighted.mean(TotalRequirement.Percentage.PerAnnum, PWT, na.rm = TRUE))

svyby(formula = ~TotalRequirement.Percentage.PerAnnum_SOCs, by = ~year,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

Viz <- read.csv("Z - Long Term Prospects Comparison.csv")
ggplot(Viz, aes(x = Year, y = Prospects, colour = Survey, group = Survey)) +
  geom_line() +
  geom_point(size = 2) +
  scale_y_continuous(labels = scales::percent, limits = c(0.035,0.045)) + 
  geom_text(aes(label = paste0(Prospects*100, "%"), vjust = -0.5),
            position = position_dodge(width = 0.5)) +
  labs(y = "",
       fill = "",
       x = "",
       title = "") +
  theme_economist()

#* ----------------------------------------------------------------
#* -------------- [f - Save data:]
#* ----------------------------------------------------------------

#* Saved the above as of [10.11.23]:
# saveRDS(Dat, file = "0 - Dat.RData")
